Class: GetStream::Generated::Models::ActivityProcessorConfig

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/getstream_ruby/generated/models/activity_processor_config.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#==, #inspect, omit_empty_fields, #to_h, #to_json

Constructor Details

#initialize(attributes = {}) ⇒ ActivityProcessorConfig

Initialize with attributes



23
24
25
26
27
28
# File 'lib/getstream_ruby/generated/models/activity_processor_config.rb', line 23

def initialize(attributes = {})
  super(attributes)
  @type = attributes[:type] || attributes['type']
  @min_text_length = attributes[:min_text_length] || attributes['min_text_length'] || nil
  @min_word_count = attributes[:min_word_count] || attributes['min_word_count'] || nil
end

Instance Attribute Details

#min_text_lengthInteger

Returns Minimum number of characters the activity text must have before this processor runs. 0 (the default) disables the check. Only applies to text_interest_tags.

Returns:

  • (Integer)

    Minimum number of characters the activity text must have before this processor runs. 0 (the default) disables the check. Only applies to text_interest_tags.



17
18
19
# File 'lib/getstream_ruby/generated/models/activity_processor_config.rb', line 17

def min_text_length
  @min_text_length
end

#min_word_countInteger

Returns Minimum number of words the activity text must have before this processor runs. 0 (the default) disables the check. Only applies to text_interest_tags. Words are whitespace-separated, so scripts written without word spacing (Chinese, Japanese, Thai) always count as 1 word regardless of length — use min_text_length for those.

Returns:

  • (Integer)

    Minimum number of words the activity text must have before this processor runs. 0 (the default) disables the check. Only applies to text_interest_tags. Words are whitespace-separated, so scripts written without word spacing (Chinese, Japanese, Thai) always count as 1 word regardless of length — use min_text_length for those.



20
21
22
# File 'lib/getstream_ruby/generated/models/activity_processor_config.rb', line 20

def min_word_count
  @min_word_count
end

#typeString

Returns Type of activity processor (required).

Returns:

  • (String)

    Type of activity processor (required)



14
15
16
# File 'lib/getstream_ruby/generated/models/activity_processor_config.rb', line 14

def type
  @type
end

Class Method Details

.json_field_mappingsObject

Override field mappings for JSON serialization



31
32
33
34
35
36
37
# File 'lib/getstream_ruby/generated/models/activity_processor_config.rb', line 31

def self.json_field_mappings
  {
    type: 'type',
    min_text_length: 'min_text_length',
    min_word_count: 'min_word_count'
  }
end