Class: GetStream::Generated::Models::ActivityResponse

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/getstream_ruby/generated/models/activity_response.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#==, #inspect, omit_empty_fields, #to_h, #to_json

Constructor Details

#initialize(attributes = {}) ⇒ ActivityResponse

Initialize with attributes



155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
# File 'lib/getstream_ruby/generated/models/activity_response.rb', line 155

def initialize(attributes = {})
  super(attributes)
  @bookmark_count = attributes[:bookmark_count] || attributes['bookmark_count']
  @comment_count = attributes[:comment_count] || attributes['comment_count']
  @created_at = attributes[:created_at] || attributes['created_at']
  @hidden = attributes[:hidden] || attributes['hidden']
  @id = attributes[:id] || attributes['id']
  @popularity = attributes[:popularity] || attributes['popularity']
  @preview = attributes[:preview] || attributes['preview']
  @reaction_count = attributes[:reaction_count] || attributes['reaction_count']
  @restrict_replies = attributes[:restrict_replies] || attributes['restrict_replies']
  @score = attributes[:score] || attributes['score']
  @share_count = attributes[:share_count] || attributes['share_count']
  @type = attributes[:type] || attributes['type']
  @updated_at = attributes[:updated_at] || attributes['updated_at']
  @visibility = attributes[:visibility] || attributes['visibility']
  @attachments = attributes[:attachments] || attributes['attachments']
  @comments = attributes[:comments] || attributes['comments']
  @feeds = attributes[:feeds] || attributes['feeds']
  @filter_tags = attributes[:filter_tags] || attributes['filter_tags']
  @interest_tags = attributes[:interest_tags] || attributes['interest_tags']
  @latest_reactions = attributes[:latest_reactions] || attributes['latest_reactions']
  @mentioned_users = attributes[:mentioned_users] || attributes['mentioned_users']
  @own_bookmarks = attributes[:own_bookmarks] || attributes['own_bookmarks']
  @own_reactions = attributes[:own_reactions] || attributes['own_reactions']
  @collections = attributes[:collections] || attributes['collections']
  @custom = attributes[:custom] || attributes['custom']
  @reaction_groups = attributes[:reaction_groups] || attributes['reaction_groups']
  @search_data = attributes[:search_data] || attributes['search_data']
  @user = attributes[:user] || attributes['user']
  @deleted_at = attributes[:deleted_at] || attributes['deleted_at'] || nil
  @edited_at = attributes[:edited_at] || attributes['edited_at'] || nil
  @expires_at = attributes[:expires_at] || attributes['expires_at'] || nil
  @friend_reaction_count = attributes[:friend_reaction_count] || attributes['friend_reaction_count'] || nil
  @is_read = attributes[:is_read] || attributes['is_read'] || nil
  @is_seen = attributes[:is_seen] || attributes['is_seen'] || nil
  @is_watched = attributes[:is_watched] || attributes['is_watched'] || nil
  @moderation_action = attributes[:moderation_action] || attributes['moderation_action'] || nil
  @selector_source = attributes[:selector_source] || attributes['selector_source'] || nil
  @text = attributes[:text] || attributes['text'] || nil
  @visibility_tag = attributes[:visibility_tag] || attributes['visibility_tag'] || nil
  @friend_reactions = attributes[:friend_reactions] || attributes['friend_reactions'] || nil
  @current_feed = attributes[:current_feed] || attributes['current_feed'] || nil
  @location = attributes[:location] || attributes['location'] || nil
  @metrics = attributes[:metrics] || attributes['metrics'] || nil
  @moderation = attributes[:moderation] || attributes['moderation'] || nil
  @notification_context = attributes[:notification_context] || attributes['notification_context'] || nil
  @parent = attributes[:parent] || attributes['parent'] || nil
  @poll = attributes[:poll] || attributes['poll'] || nil
end

Instance Attribute Details

#attachmentsArray<Attachment>

Returns Media attachments for the activity.

Returns:

  • (Array<Attachment>)

    Media attachments for the activity



56
57
58
# File 'lib/getstream_ruby/generated/models/activity_response.rb', line 56

def attachments
  @attachments
end

#bookmark_countInteger

Returns Number of bookmarks on the activity.

Returns:

  • (Integer)

    Number of bookmarks on the activity



14
15
16
# File 'lib/getstream_ruby/generated/models/activity_response.rb', line 14

def bookmark_count
  @bookmark_count
end

#collectionsHash<String, EnrichedCollectionResponse>

Returns Enriched collection data referenced by this activity.

Returns:



83
84
85
# File 'lib/getstream_ruby/generated/models/activity_response.rb', line 83

def collections
  @collections
end

#comment_countInteger

Returns Number of comments on the activity.

Returns:

  • (Integer)

    Number of comments on the activity



17
18
19
# File 'lib/getstream_ruby/generated/models/activity_response.rb', line 17

def comment_count
  @comment_count
end

#commentsArray<CommentResponse>

Returns Latest 5 comments of this activity (comment replies excluded).

Returns:

  • (Array<CommentResponse>)

    Latest 5 comments of this activity (comment replies excluded)



59
60
61
# File 'lib/getstream_ruby/generated/models/activity_response.rb', line 59

def comments
  @comments
end

#created_atDateTime

Returns When the activity was created.

Returns:

  • (DateTime)

    When the activity was created



20
21
22
# File 'lib/getstream_ruby/generated/models/activity_response.rb', line 20

def created_at
  @created_at
end

#current_feedFeedResponse

Returns:



134
135
136
# File 'lib/getstream_ruby/generated/models/activity_response.rb', line 134

def current_feed
  @current_feed
end

#customObject

Returns Custom data for the activity.

Returns:

  • (Object)

    Custom data for the activity



86
87
88
# File 'lib/getstream_ruby/generated/models/activity_response.rb', line 86

def custom
  @custom
end

#deleted_atDateTime

Returns When the activity was deleted.

Returns:

  • (DateTime)

    When the activity was deleted



98
99
100
# File 'lib/getstream_ruby/generated/models/activity_response.rb', line 98

def deleted_at
  @deleted_at
end

#edited_atDateTime

Returns When the activity was last edited.

Returns:

  • (DateTime)

    When the activity was last edited



101
102
103
# File 'lib/getstream_ruby/generated/models/activity_response.rb', line 101

def edited_at
  @edited_at
end

#expires_atDateTime

Returns When the activity will expire.

Returns:

  • (DateTime)

    When the activity will expire



104
105
106
# File 'lib/getstream_ruby/generated/models/activity_response.rb', line 104

def expires_at
  @expires_at
end

#feedsArray<String>

Returns List of feed IDs containing this activity.

Returns:

  • (Array<String>)

    List of feed IDs containing this activity



62
63
64
# File 'lib/getstream_ruby/generated/models/activity_response.rb', line 62

def feeds
  @feeds
end

#filter_tagsArray<String>

Returns Tags for filtering.

Returns:

  • (Array<String>)

    Tags for filtering



65
66
67
# File 'lib/getstream_ruby/generated/models/activity_response.rb', line 65

def filter_tags
  @filter_tags
end

#friend_reaction_countInteger

Returns Total count of reactions from friends on this activity.

Returns:

  • (Integer)

    Total count of reactions from friends on this activity



107
108
109
# File 'lib/getstream_ruby/generated/models/activity_response.rb', line 107

def friend_reaction_count
  @friend_reaction_count
end

#friend_reactionsArray<FeedsReactionResponse>

Returns Reactions from users the current user follows or has mutual follows with.

Returns:

  • (Array<FeedsReactionResponse>)

    Reactions from users the current user follows or has mutual follows with



131
132
133
# File 'lib/getstream_ruby/generated/models/activity_response.rb', line 131

def friend_reactions
  @friend_reactions
end

#hiddenBoolean

Returns If this activity is hidden by this user (using activity feedback).

Returns:

  • (Boolean)

    If this activity is hidden by this user (using activity feedback)



23
24
25
# File 'lib/getstream_ruby/generated/models/activity_response.rb', line 23

def hidden
  @hidden
end

#idString

Returns Unique identifier for the activity.

Returns:

  • (String)

    Unique identifier for the activity



26
27
28
# File 'lib/getstream_ruby/generated/models/activity_response.rb', line 26

def id
  @id
end

#interest_tagsArray<String>

Returns Tags for user interests.

Returns:

  • (Array<String>)

    Tags for user interests



68
69
70
# File 'lib/getstream_ruby/generated/models/activity_response.rb', line 68

def interest_tags
  @interest_tags
end

#is_readBoolean

Returns Whether this activity has been read. Only set for feed groups with notification config (track_seen/track_read enabled).

Returns:

  • (Boolean)

    Whether this activity has been read. Only set for feed groups with notification config (track_seen/track_read enabled).



110
111
112
# File 'lib/getstream_ruby/generated/models/activity_response.rb', line 110

def is_read
  @is_read
end

#is_seenBoolean

Returns Whether this activity has been seen. Only set for feed groups with notification config (track_seen/track_read enabled).

Returns:

  • (Boolean)

    Whether this activity has been seen. Only set for feed groups with notification config (track_seen/track_read enabled).



113
114
115
# File 'lib/getstream_ruby/generated/models/activity_response.rb', line 113

def is_seen
  @is_seen
end

#is_watchedBoolean

Returns:

  • (Boolean)


116
117
118
# File 'lib/getstream_ruby/generated/models/activity_response.rb', line 116

def is_watched
  @is_watched
end

#latest_reactionsArray<FeedsReactionResponse>

Returns Recent reactions to the activity.

Returns:



71
72
73
# File 'lib/getstream_ruby/generated/models/activity_response.rb', line 71

def latest_reactions
  @latest_reactions
end

#locationActivityLocation

Returns:



137
138
139
# File 'lib/getstream_ruby/generated/models/activity_response.rb', line 137

def location
  @location
end

#mentioned_usersArray<UserResponse>

Returns Users mentioned in the activity.

Returns:



74
75
76
# File 'lib/getstream_ruby/generated/models/activity_response.rb', line 74

def mentioned_users
  @mentioned_users
end

#metricsHash<String, Integer>

Returns:

  • (Hash<String, Integer>)


140
141
142
# File 'lib/getstream_ruby/generated/models/activity_response.rb', line 140

def metrics
  @metrics
end

#moderationModerationV2Response



143
144
145
# File 'lib/getstream_ruby/generated/models/activity_response.rb', line 143

def moderation
  @moderation
end

#moderation_actionString

Returns:

  • (String)


119
120
121
# File 'lib/getstream_ruby/generated/models/activity_response.rb', line 119

def moderation_action
  @moderation_action
end

#notification_contextNotificationContext

Returns:



146
147
148
# File 'lib/getstream_ruby/generated/models/activity_response.rb', line 146

def notification_context
  @notification_context
end

#own_bookmarksArray<BookmarkResponse>

Returns Current user’s bookmarks for this activity.

Returns:



77
78
79
# File 'lib/getstream_ruby/generated/models/activity_response.rb', line 77

def own_bookmarks
  @own_bookmarks
end

#own_reactionsArray<FeedsReactionResponse>

Returns Current user’s reactions to this activity.

Returns:



80
81
82
# File 'lib/getstream_ruby/generated/models/activity_response.rb', line 80

def own_reactions
  @own_reactions
end

#parentActivityResponse

Returns:



149
150
151
# File 'lib/getstream_ruby/generated/models/activity_response.rb', line 149

def parent
  @parent
end

#pollPollResponseData

Returns:



152
153
154
# File 'lib/getstream_ruby/generated/models/activity_response.rb', line 152

def poll
  @poll
end

#popularityInteger

Returns Popularity score of the activity.

Returns:

  • (Integer)

    Popularity score of the activity



29
30
31
# File 'lib/getstream_ruby/generated/models/activity_response.rb', line 29

def popularity
  @popularity
end

#previewBoolean

Returns If this activity is obfuscated for this user. For premium content where you want to show a preview.

Returns:

  • (Boolean)

    If this activity is obfuscated for this user. For premium content where you want to show a preview



32
33
34
# File 'lib/getstream_ruby/generated/models/activity_response.rb', line 32

def preview
  @preview
end

#reaction_countInteger

Returns Number of reactions to the activity.

Returns:

  • (Integer)

    Number of reactions to the activity



35
36
37
# File 'lib/getstream_ruby/generated/models/activity_response.rb', line 35

def reaction_count
  @reaction_count
end

#reaction_groupsHash<String, FeedsReactionGroupResponse>

Returns Grouped reactions by type.

Returns:



89
90
91
# File 'lib/getstream_ruby/generated/models/activity_response.rb', line 89

def reaction_groups
  @reaction_groups
end

#restrict_repliesString

Returns Controls who can add comments/replies to this activity. One of: everyone, people_i_follow, nobody.

Returns:

  • (String)

    Controls who can add comments/replies to this activity. One of: everyone, people_i_follow, nobody



38
39
40
# File 'lib/getstream_ruby/generated/models/activity_response.rb', line 38

def restrict_replies
  @restrict_replies
end

#scoreFloat

Returns Ranking score for this activity.

Returns:

  • (Float)

    Ranking score for this activity



41
42
43
# File 'lib/getstream_ruby/generated/models/activity_response.rb', line 41

def score
  @score
end

#search_dataObject

Returns Data for search indexing.

Returns:

  • (Object)

    Data for search indexing



92
93
94
# File 'lib/getstream_ruby/generated/models/activity_response.rb', line 92

def search_data
  @search_data
end

#selector_sourceString

Returns Which activity selector provided this activity (e.g., ‘following’, ‘popular’, ‘interest’). Only set when using multiple activity selectors with ranking.

Returns:

  • (String)

    Which activity selector provided this activity (e.g., ‘following’, ‘popular’, ‘interest’). Only set when using multiple activity selectors with ranking.



122
123
124
# File 'lib/getstream_ruby/generated/models/activity_response.rb', line 122

def selector_source
  @selector_source
end

#share_countInteger

Returns Number of times the activity was shared.

Returns:

  • (Integer)

    Number of times the activity was shared



44
45
46
# File 'lib/getstream_ruby/generated/models/activity_response.rb', line 44

def share_count
  @share_count
end

#textString

Returns Text content of the activity.

Returns:

  • (String)

    Text content of the activity



125
126
127
# File 'lib/getstream_ruby/generated/models/activity_response.rb', line 125

def text
  @text
end

#typeString

Returns Type of activity.

Returns:

  • (String)

    Type of activity



47
48
49
# File 'lib/getstream_ruby/generated/models/activity_response.rb', line 47

def type
  @type
end

#updated_atDateTime

Returns When the activity was last updated.

Returns:

  • (DateTime)

    When the activity was last updated



50
51
52
# File 'lib/getstream_ruby/generated/models/activity_response.rb', line 50

def updated_at
  @updated_at
end

#userUserResponse

Returns:



95
96
97
# File 'lib/getstream_ruby/generated/models/activity_response.rb', line 95

def user
  @user
end

#visibilityString

Returns Visibility setting for the activity. One of: public, private, tag.

Returns:

  • (String)

    Visibility setting for the activity. One of: public, private, tag



53
54
55
# File 'lib/getstream_ruby/generated/models/activity_response.rb', line 53

def visibility
  @visibility
end

#visibility_tagString

Returns If visibility is ‘tag’, this is the tag name.

Returns:

  • (String)

    If visibility is ‘tag’, this is the tag name



128
129
130
# File 'lib/getstream_ruby/generated/models/activity_response.rb', line 128

def visibility_tag
  @visibility_tag
end

Class Method Details

.json_field_mappingsObject

Override field mappings for JSON serialization



207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
# File 'lib/getstream_ruby/generated/models/activity_response.rb', line 207

def self.json_field_mappings
  {
    bookmark_count: 'bookmark_count',
    comment_count: 'comment_count',
    created_at: 'created_at',
    hidden: 'hidden',
    id: 'id',
    popularity: 'popularity',
    preview: 'preview',
    reaction_count: 'reaction_count',
    restrict_replies: 'restrict_replies',
    score: 'score',
    share_count: 'share_count',
    type: 'type',
    updated_at: 'updated_at',
    visibility: 'visibility',
    attachments: 'attachments',
    comments: 'comments',
    feeds: 'feeds',
    filter_tags: 'filter_tags',
    interest_tags: 'interest_tags',
    latest_reactions: 'latest_reactions',
    mentioned_users: 'mentioned_users',
    own_bookmarks: 'own_bookmarks',
    own_reactions: 'own_reactions',
    collections: 'collections',
    custom: 'custom',
    reaction_groups: 'reaction_groups',
    search_data: 'search_data',
    user: 'user',
    deleted_at: 'deleted_at',
    edited_at: 'edited_at',
    expires_at: 'expires_at',
    friend_reaction_count: 'friend_reaction_count',
    is_read: 'is_read',
    is_seen: 'is_seen',
    is_watched: 'is_watched',
    moderation_action: 'moderation_action',
    selector_source: 'selector_source',
    text: 'text',
    visibility_tag: 'visibility_tag',
    friend_reactions: 'friend_reactions',
    current_feed: 'current_feed',
    location: 'location',
    metrics: 'metrics',
    moderation: 'moderation',
    notification_context: 'notification_context',
    parent: 'parent',
    poll: 'poll'
  }
end