Class: GetStream::Generated::Models::AddActivityRequest
- Defined in:
- lib/getstream_ruby/generated/models/add_activity_request.rb
Instance Attribute Summary collapse
-
#attachments ⇒ Array<Attachment>
List of attachments for the activity.
-
#collection_refs ⇒ Array<String>
Collections that this activity references.
-
#copy_custom_to_notification ⇒ Object
deprecated
Deprecated.
This field is deprecated. @return [Boolean] Whether to copy custom data to the notification activity (only applies when create_notification_activity is true) Deprecated: use notification_context.trigger.custom and notification_context.target.custom instead
-
#create_notification_activity ⇒ Boolean
Whether to create notification activities for mentioned users.
- #create_users ⇒ Boolean
-
#custom ⇒ Object
Custom data for the activity.
- #enrich_own_fields ⇒ Boolean
-
#expires_at ⇒ String
Expiration time for the activity.
-
#feeds ⇒ Array<String>
List of feeds to add the activity to with a default max limit of 25 feeds.
-
#filter_tags ⇒ Array<String>
Tags for filtering activities.
- #force_moderation ⇒ Boolean
-
#id ⇒ String
Optional ID for the activity.
-
#interest_tags ⇒ Array<String>
Tags for indicating user interests.
- #location ⇒ Location
-
#mentioned_user_ids ⇒ Array<String>
List of users mentioned in the activity.
-
#parent_id ⇒ String
ID of parent activity for replies/comments.
-
#poll_id ⇒ String
ID of a poll to attach to activity.
-
#restrict_replies ⇒ String
Controls who can add comments/replies to this activity.
-
#search_data ⇒ Object
Additional data for search indexing.
-
#skip_enrich_url ⇒ Boolean
Whether to skip URL enrichment for the activity.
-
#skip_push ⇒ Boolean
Whether to skip push notifications.
-
#text ⇒ String
Text content of the activity.
-
#type ⇒ String
Type of activity.
-
#user_id ⇒ String
ID of the user creating the activity.
-
#visibility ⇒ String
Visibility setting for the activity.
-
#visibility_tag ⇒ String
If visibility is 'tag', this is the tag name and is required.
Class Method Summary collapse
-
.json_field_mappings ⇒ Object
Override field mappings for JSON serialization.
Instance Method Summary collapse
-
#initialize(attributes = {}) ⇒ AddActivityRequest
constructor
Initialize with attributes.
Methods inherited from BaseModel
#==, #inspect, omit_empty_fields, #to_h, #to_json
Constructor Details
#initialize(attributes = {}) ⇒ AddActivityRequest
Initialize with attributes
93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 |
# File 'lib/getstream_ruby/generated/models/add_activity_request.rb', line 93 def initialize(attributes = {}) super(attributes) @type = attributes[:type] || attributes['type'] @feeds = attributes[:feeds] || attributes['feeds'] @copy_custom_to_notification = attributes[:copy_custom_to_notification] || attributes['copy_custom_to_notification'] || nil @create_notification_activity = attributes[:create_notification_activity] || attributes['create_notification_activity'] || nil @create_users = attributes[:create_users] || attributes['create_users'] || nil @enrich_own_fields = attributes[:enrich_own_fields] || attributes['enrich_own_fields'] || nil @expires_at = attributes[:expires_at] || attributes['expires_at'] || nil @force_moderation = attributes[:force_moderation] || attributes['force_moderation'] || nil @id = attributes[:id] || attributes['id'] || nil @parent_id = attributes[:parent_id] || attributes['parent_id'] || nil @poll_id = attributes[:poll_id] || attributes['poll_id'] || nil @restrict_replies = attributes[:restrict_replies] || attributes['restrict_replies'] || nil @skip_enrich_url = attributes[:skip_enrich_url] || attributes['skip_enrich_url'] || nil @skip_push = attributes[:skip_push] || attributes['skip_push'] || nil @text = attributes[:text] || attributes['text'] || nil @user_id = attributes[:user_id] || attributes['user_id'] || nil @visibility = attributes[:visibility] || attributes['visibility'] || nil @visibility_tag = attributes[:visibility_tag] || attributes['visibility_tag'] || nil = attributes[:attachments] || attributes['attachments'] || nil @collection_refs = attributes[:collection_refs] || attributes['collection_refs'] || nil = attributes[:filter_tags] || attributes['filter_tags'] || nil = attributes[:interest_tags] || attributes['interest_tags'] || nil @mentioned_user_ids = attributes[:mentioned_user_ids] || attributes['mentioned_user_ids'] || nil @custom = attributes[:custom] || attributes['custom'] || nil @location = attributes[:location] || attributes['location'] || nil @search_data = attributes[:search_data] || attributes['search_data'] || nil end |
Instance Attribute Details
#attachments ⇒ Array<Attachment>
69 70 71 |
# File 'lib/getstream_ruby/generated/models/add_activity_request.rb', line 69 def end |
#collection_refs ⇒ Array<String>
72 73 74 |
# File 'lib/getstream_ruby/generated/models/add_activity_request.rb', line 72 def collection_refs @collection_refs end |
#copy_custom_to_notification ⇒ Object
This field is deprecated. @return [Boolean] Whether to copy custom data to the notification activity (only applies when create_notification_activity is true) Deprecated: use notification_context.trigger.custom and notification_context.target.custom instead
21 22 23 |
# File 'lib/getstream_ruby/generated/models/add_activity_request.rb', line 21 def copy_custom_to_notification @copy_custom_to_notification end |
#create_notification_activity ⇒ Boolean
24 25 26 |
# File 'lib/getstream_ruby/generated/models/add_activity_request.rb', line 24 def create_notification_activity @create_notification_activity end |
#create_users ⇒ Boolean
27 28 29 |
# File 'lib/getstream_ruby/generated/models/add_activity_request.rb', line 27 def create_users @create_users end |
#custom ⇒ Object
84 85 86 |
# File 'lib/getstream_ruby/generated/models/add_activity_request.rb', line 84 def custom @custom end |
#enrich_own_fields ⇒ Boolean
30 31 32 |
# File 'lib/getstream_ruby/generated/models/add_activity_request.rb', line 30 def enrich_own_fields @enrich_own_fields end |
#expires_at ⇒ String
33 34 35 |
# File 'lib/getstream_ruby/generated/models/add_activity_request.rb', line 33 def expires_at @expires_at end |
#feeds ⇒ Array<String>
17 18 19 |
# File 'lib/getstream_ruby/generated/models/add_activity_request.rb', line 17 def feeds @feeds end |
#filter_tags ⇒ Array<String>
75 76 77 |
# File 'lib/getstream_ruby/generated/models/add_activity_request.rb', line 75 def end |
#force_moderation ⇒ Boolean
36 37 38 |
# File 'lib/getstream_ruby/generated/models/add_activity_request.rb', line 36 def force_moderation @force_moderation end |
#id ⇒ String
39 40 41 |
# File 'lib/getstream_ruby/generated/models/add_activity_request.rb', line 39 def id @id end |
#interest_tags ⇒ Array<String>
78 79 80 |
# File 'lib/getstream_ruby/generated/models/add_activity_request.rb', line 78 def end |
#location ⇒ Location
87 88 89 |
# File 'lib/getstream_ruby/generated/models/add_activity_request.rb', line 87 def location @location end |
#mentioned_user_ids ⇒ Array<String>
81 82 83 |
# File 'lib/getstream_ruby/generated/models/add_activity_request.rb', line 81 def mentioned_user_ids @mentioned_user_ids end |
#parent_id ⇒ String
42 43 44 |
# File 'lib/getstream_ruby/generated/models/add_activity_request.rb', line 42 def parent_id @parent_id end |
#poll_id ⇒ String
45 46 47 |
# File 'lib/getstream_ruby/generated/models/add_activity_request.rb', line 45 def poll_id @poll_id end |
#restrict_replies ⇒ String
48 49 50 |
# File 'lib/getstream_ruby/generated/models/add_activity_request.rb', line 48 def restrict_replies @restrict_replies end |
#search_data ⇒ Object
90 91 92 |
# File 'lib/getstream_ruby/generated/models/add_activity_request.rb', line 90 def search_data @search_data end |
#skip_enrich_url ⇒ Boolean
51 52 53 |
# File 'lib/getstream_ruby/generated/models/add_activity_request.rb', line 51 def skip_enrich_url @skip_enrich_url end |
#skip_push ⇒ Boolean
54 55 56 |
# File 'lib/getstream_ruby/generated/models/add_activity_request.rb', line 54 def skip_push @skip_push end |
#text ⇒ String
57 58 59 |
# File 'lib/getstream_ruby/generated/models/add_activity_request.rb', line 57 def text @text end |
#type ⇒ String
14 15 16 |
# File 'lib/getstream_ruby/generated/models/add_activity_request.rb', line 14 def type @type end |
#user_id ⇒ String
60 61 62 |
# File 'lib/getstream_ruby/generated/models/add_activity_request.rb', line 60 def user_id @user_id end |
#visibility ⇒ String
63 64 65 |
# File 'lib/getstream_ruby/generated/models/add_activity_request.rb', line 63 def visibility @visibility end |
#visibility_tag ⇒ String
66 67 68 |
# File 'lib/getstream_ruby/generated/models/add_activity_request.rb', line 66 def visibility_tag @visibility_tag end |
Class Method Details
.json_field_mappings ⇒ Object
Override field mappings for JSON serialization
124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 |
# File 'lib/getstream_ruby/generated/models/add_activity_request.rb', line 124 def self.json_field_mappings { type: 'type', feeds: 'feeds', copy_custom_to_notification: 'copy_custom_to_notification', create_notification_activity: 'create_notification_activity', create_users: 'create_users', enrich_own_fields: 'enrich_own_fields', expires_at: 'expires_at', force_moderation: 'force_moderation', id: 'id', parent_id: 'parent_id', poll_id: 'poll_id', restrict_replies: 'restrict_replies', skip_enrich_url: 'skip_enrich_url', skip_push: 'skip_push', text: 'text', user_id: 'user_id', visibility: 'visibility', visibility_tag: 'visibility_tag', attachments: 'attachments', collection_refs: 'collection_refs', filter_tags: 'filter_tags', interest_tags: 'interest_tags', mentioned_user_ids: 'mentioned_user_ids', custom: 'custom', location: 'location', search_data: 'search_data' } end |