Class: GetStream::Generated::Models::AnalyzeResponse

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/getstream_ruby/generated/models/analyze_response.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#==, #inspect, omit_empty_fields, #to_h, #to_json

Constructor Details

#initialize(attributes = {}) ⇒ AnalyzeResponse

Initialize with attributes



26
27
28
29
30
31
32
# File 'lib/getstream_ruby/generated/models/analyze_response.rb', line 26

def initialize(attributes = {})
  super(attributes)
  @duration = attributes[:duration] || attributes['duration']
  @status = attributes[:status] || attributes['status']
  @images = attributes[:images] || attributes['images'] || nil
  @texts = attributes[:texts] || attributes['texts'] || nil
end

Instance Attribute Details

#durationString

Returns:

  • (String)


14
15
16
# File 'lib/getstream_ruby/generated/models/analyze_response.rb', line 14

def duration
  @duration
end

#imagesHash<String, AnalyzeImageField>

Returns Per-image moderation verdicts keyed by caller label.

Returns:

  • (Hash<String, AnalyzeImageField>)

    Per-image moderation verdicts keyed by caller label.



20
21
22
# File 'lib/getstream_ruby/generated/models/analyze_response.rb', line 20

def images
  @images
end

#statusString

Returns Always ‘complete` — /analyze is sync-only and the full verdict is in the response.

Returns:

  • (String)

    Always ‘complete` — /analyze is sync-only and the full verdict is in the response.



17
18
19
# File 'lib/getstream_ruby/generated/models/analyze_response.rb', line 17

def status
  @status
end

#textsHash<String, AnalyzeTextField>

Returns Per-text-field moderation verdicts keyed by caller label.

Returns:

  • (Hash<String, AnalyzeTextField>)

    Per-text-field moderation verdicts keyed by caller label.



23
24
25
# File 'lib/getstream_ruby/generated/models/analyze_response.rb', line 23

def texts
  @texts
end

Class Method Details

.json_field_mappingsObject

Override field mappings for JSON serialization



35
36
37
38
39
40
41
42
# File 'lib/getstream_ruby/generated/models/analyze_response.rb', line 35

def self.json_field_mappings
  {
    duration: 'duration',
    status: 'status',
    images: 'images',
    texts: 'texts'
  }
end