Class: GetStream::Generated::Models::BlockedUserEvent

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/getstream_ruby/generated/models/blocked_user_event.rb

Overview

This event is sent to call participants to notify when a user is blocked on a call, clients can use this event to show a notification.If the user is the current user, the client should leave the call screen as well

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#==, #inspect, omit_empty_fields, #to_h, #to_json

Constructor Details

#initialize(attributes = {}) ⇒ BlockedUserEvent

Initialize with attributes



29
30
31
32
33
34
35
36
# File 'lib/getstream_ruby/generated/models/blocked_user_event.rb', line 29

def initialize(attributes = {})
  super(attributes)
  @call_cid = attributes[:call_cid] || attributes['call_cid']
  @created_at = attributes[:created_at] || attributes['created_at']
  @user = attributes[:user] || attributes['user']
  @type = attributes[:type] || attributes['type'] || "call.blocked_user"
  @blocked_by_user = attributes[:blocked_by_user] || attributes['blocked_by_user'] || nil
end

Instance Attribute Details

#blocked_by_user ⇒ UserResponse

Returns:



26
27
28
# File 'lib/getstream_ruby/generated/models/blocked_user_event.rb', line 26

def blocked_by_user
  @blocked_by_user
end

#call_cid ⇒ String

Returns:

  • (String)


14
15
16
# File 'lib/getstream_ruby/generated/models/blocked_user_event.rb', line 14

def call_cid
  @call_cid
end

#created_at ⇒ DateTime

Returns:

  • (DateTime)


17
18
19
# File 'lib/getstream_ruby/generated/models/blocked_user_event.rb', line 17

def created_at
  @created_at
end

#type ⇒ String

Returns The type of event: "call.blocked_user" in this case.

Returns:

  • (String) —

    The type of event: "call.blocked_user" in this case



23
24
25
# File 'lib/getstream_ruby/generated/models/blocked_user_event.rb', line 23

def type
  @type
end

#user ⇒ UserResponse

Returns:



20
21
22
# File 'lib/getstream_ruby/generated/models/blocked_user_event.rb', line 20

def user
  @user
end

Class Method Details

.json_field_mappings ⇒ Object

Override field mappings for JSON serialization



39
40
41
42
43
44
45
46
47
# File 'lib/getstream_ruby/generated/models/blocked_user_event.rb', line 39

def self.json_field_mappings
  {
    call_cid: 'call_cid',
    created_at: 'created_at',
    user: 'user',
    type: 'type',
    blocked_by_user: 'blocked_by_user'
  }
end