Class: GetStream::Generated::Models::CallDTMFEvent

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/getstream_ruby/generated/models/call_dtmf_event.rb

Overview

This event is sent asynchronously when a single DTMF digit is received from a SIP participant. The event is broadcast after the digit press ends. Use seq_number for ordering within a session and timestamp for the actual detection time.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#==, #inspect, omit_empty_fields, #to_h, #to_json

Constructor Details

#initialize(attributes = {}) ⇒ CallDTMFEvent

Initialize with attributes



38
39
40
41
42
43
44
45
46
47
48
# File 'lib/getstream_ruby/generated/models/call_dtmf_event.rb', line 38

def initialize(attributes = {})
  super(attributes)
  @call_cid = attributes[:call_cid] || attributes['call_cid']
  @created_at = attributes[:created_at] || attributes['created_at']
  @digit = attributes[:digit] || attributes['digit']
  @duration_ms = attributes[:duration_ms] || attributes['duration_ms']
  @seq_number = attributes[:seq_number] || attributes['seq_number']
  @timestamp = attributes[:timestamp] || attributes['timestamp']
  @user = attributes[:user] || attributes['user']
  @type = attributes[:type] || attributes['type'] || "call.dtmf"
end

Instance Attribute Details

#call_cidString

Returns:

  • (String)


14
15
16
# File 'lib/getstream_ruby/generated/models/call_dtmf_event.rb', line 14

def call_cid
  @call_cid
end

#created_atDateTime

Returns:

  • (DateTime)


17
18
19
# File 'lib/getstream_ruby/generated/models/call_dtmf_event.rb', line 17

def created_at
  @created_at
end

#digitString

Returns The DTMF digit (0-9, *, #, A-D).

Returns:

  • (String)

    The DTMF digit (0-9, *, #, A-D)



20
21
22
# File 'lib/getstream_ruby/generated/models/call_dtmf_event.rb', line 20

def digit
  @digit
end

#duration_msInteger

Returns Duration of the digit press in milliseconds.

Returns:

  • (Integer)

    Duration of the digit press in milliseconds



23
24
25
# File 'lib/getstream_ruby/generated/models/call_dtmf_event.rb', line 23

def duration_ms
  @duration_ms
end

#seq_numberInteger

Returns Monotonically increasing sequence number for ordering DTMF events within a session.

Returns:

  • (Integer)

    Monotonically increasing sequence number for ordering DTMF events within a session



26
27
28
# File 'lib/getstream_ruby/generated/models/call_dtmf_event.rb', line 26

def seq_number
  @seq_number
end

#timestampDateTime

Returns When the digit press ended and was detected.

Returns:

  • (DateTime)

    When the digit press ended and was detected



29
30
31
# File 'lib/getstream_ruby/generated/models/call_dtmf_event.rb', line 29

def timestamp
  @timestamp
end

#typeString

Returns The type of event: “call.dtmf” in this case.

Returns:

  • (String)

    The type of event: “call.dtmf” in this case



35
36
37
# File 'lib/getstream_ruby/generated/models/call_dtmf_event.rb', line 35

def type
  @type
end

#userUserResponse

Returns:



32
33
34
# File 'lib/getstream_ruby/generated/models/call_dtmf_event.rb', line 32

def user
  @user
end

Class Method Details

.json_field_mappingsObject

Override field mappings for JSON serialization



51
52
53
54
55
56
57
58
59
60
61
62
# File 'lib/getstream_ruby/generated/models/call_dtmf_event.rb', line 51

def self.json_field_mappings
  {
    call_cid: 'call_cid',
    created_at: 'created_at',
    digit: 'digit',
    duration_ms: 'duration_ms',
    seq_number: 'seq_number',
    timestamp: 'timestamp',
    user: 'user',
    type: 'type'
  }
end