Class: GetStream::Generated::Models::CallEndedEvent

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/getstream_ruby/generated/models/call_ended_event.rb

Overview

This event is sent when a call is mark as ended for all its participants. Clients receiving this event should leave the call screen

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#==, #inspect, omit_empty_fields, #to_h, #to_json

Constructor Details

#initialize(attributes = {}) ⇒ CallEndedEvent

Initialize with attributes



35
36
37
38
39
40
41
42
43
44
# File 'lib/getstream_ruby/generated/models/call_ended_event.rb', line 35

def initialize(attributes = {})
  super(attributes)
  @call_cid = attributes[:call_cid] || attributes['call_cid']
  @created_at = attributes[:created_at] || attributes['created_at']
  @call = attributes[:call] || attributes['call']
  @type = attributes[:type] || attributes['type'] || "call.ended"
  @reason = attributes[:reason] || attributes['reason'] || nil
  @members = attributes[:members] || attributes['members'] || nil
  @user = attributes[:user] || attributes['user'] || nil
end

Instance Attribute Details

#call ⇒ CallResponse

Returns:



20
21
22
# File 'lib/getstream_ruby/generated/models/call_ended_event.rb', line 20

def call
  @call
end

#call_cid ⇒ String

Returns:

  • (String)


14
15
16
# File 'lib/getstream_ruby/generated/models/call_ended_event.rb', line 14

def call_cid
  @call_cid
end

#created_at ⇒ DateTime

Returns:

  • (DateTime)


17
18
19
# File 'lib/getstream_ruby/generated/models/call_ended_event.rb', line 17

def created_at
  @created_at
end

#members ⇒ Array<MemberResponse>

Returns The list of members in the call.

Returns:



29
30
31
# File 'lib/getstream_ruby/generated/models/call_ended_event.rb', line 29

def members
  @members
end

#reason ⇒ String

Returns The reason why the call ended, if available.

Returns:

  • (String) —

    The reason why the call ended, if available



26
27
28
# File 'lib/getstream_ruby/generated/models/call_ended_event.rb', line 26

def reason
  @reason
end

#type ⇒ String

Returns The type of event: "call.ended" in this case.

Returns:

  • (String) —

    The type of event: "call.ended" in this case



23
24
25
# File 'lib/getstream_ruby/generated/models/call_ended_event.rb', line 23

def type
  @type
end

#user ⇒ UserResponse

Returns:



32
33
34
# File 'lib/getstream_ruby/generated/models/call_ended_event.rb', line 32

def user
  @user
end

Class Method Details

.json_field_mappings ⇒ Object

Override field mappings for JSON serialization



47
48
49
50
51
52
53
54
55
56
57
# File 'lib/getstream_ruby/generated/models/call_ended_event.rb', line 47

def self.json_field_mappings
  {
    call_cid: 'call_cid',
    created_at: 'created_at',
    call: 'call',
    type: 'type',
    reason: 'reason',
    members: 'members',
    user: 'user'
  }
end