Class: GetStream::Generated::Models::ChannelBatchUpdateRequest

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/getstream_ruby/generated/models/channel_batch_update_request.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#==, #inspect, omit_empty_fields, #to_h, #to_json

Constructor Details

#initialize(attributes = {}) ⇒ ChannelBatchUpdateRequest

Initialize with attributes



35
36
37
38
39
40
41
42
43
44
# File 'lib/getstream_ruby/generated/models/channel_batch_update_request.rb', line 35

def initialize(attributes = {})
  super(attributes)
  @operation = attributes[:operation] || attributes['operation']
  @filter = attributes[:filter] || attributes['filter']
  @hide_history_before = attributes[:hide_history_before] || attributes['hide_history_before'] || nil
  @custom_unset = attributes[:custom_unset] || attributes['custom_unset'] || nil
  @members = attributes[:members] || attributes['members'] || nil
  @custom_set = attributes[:custom_set] || attributes['custom_set'] || nil
  @data = attributes[:data] || attributes['data'] || nil
end

Instance Attribute Details

#custom_setObject

Returns updateData only. Merges these keys into each channel's existing custom object, leaving every other custom key untouched. Keys are dot-paths, so a.b sets key b inside object a (the parent object must already exist). Cannot be combined with data.custom.

Returns:

  • updateData only. Merges these keys into each channel's existing custom object, leaving every other custom key untouched. Keys are dot-paths, so a.b sets key b inside object a (the parent object must already exist). Cannot be combined with data.custom



29
30
31
# File 'lib/getstream_ruby/generated/models/channel_batch_update_request.rb', line 29

def custom_set
  @custom_set
end

#custom_unsetArray<String>

Returns updateData only. Deletes these keys from each channel's existing custom object, leaving every other custom key untouched. Keys are dot-paths; deleting a key that does not exist is a no-op. Cannot be combined with data.custom.

Returns:

  • updateData only. Deletes these keys from each channel's existing custom object, leaving every other custom key untouched. Keys are dot-paths; deleting a key that does not exist is a no-op. Cannot be combined with data.custom



23
24
25
# File 'lib/getstream_ruby/generated/models/channel_batch_update_request.rb', line 23

def custom_unset
  @custom_unset
end

#dataChannelDataUpdate

Returns:



32
33
34
# File 'lib/getstream_ruby/generated/models/channel_batch_update_request.rb', line 32

def data
  @data
end

#filterObject

Returns Filter to apply to the query.

Returns:

  • Filter to apply to the query



17
18
19
# File 'lib/getstream_ruby/generated/models/channel_batch_update_request.rb', line 17

def filter
  @filter
end

#hide_history_beforeDateTime

Returns Required with the addMembersHideHistory operation, and rejected with every other operation including addMembers. Hides each matched channel's history before this time from the members the operation adds. Members that already belong to a matched channel are never affected. Must be in RFC3339 format (e.g., "2024-01-01T10:00:00Z") and in the past.

Returns:

  • Required with the addMembersHideHistory operation, and rejected with every other operation including addMembers. Hides each matched channel's history before this time from the members the operation adds. Members that already belong to a matched channel are never affected. Must be in RFC3339 format (e.g., "2024-01-01T10:00:00Z") and in the past.



20
21
22
# File 'lib/getstream_ruby/generated/models/channel_batch_update_request.rb', line 20

def hide_history_before
  @hide_history_before
end

#membersArray<ChannelBatchMemberRequest>

Returns:



26
27
28
# File 'lib/getstream_ruby/generated/models/channel_batch_update_request.rb', line 26

def members
  @members
end

#operationString

Returns:



14
15
16
# File 'lib/getstream_ruby/generated/models/channel_batch_update_request.rb', line 14

def operation
  @operation
end

Class Method Details

.json_field_mappingsObject

Override field mappings for JSON serialization



47
48
49
50
51
52
53
54
55
56
57
# File 'lib/getstream_ruby/generated/models/channel_batch_update_request.rb', line 47

def self.json_field_mappings
  {
    operation: 'operation',
    filter: 'filter',
    hide_history_before: 'hide_history_before',
    custom_unset: 'custom_unset',
    members: 'members',
    custom_set: 'custom_set',
    data: 'data'
  }
end