Class: GetStream::Generated::Models::ChannelMemberResponse
- Defined in:
- lib/getstream_ruby/generated/models/channel_member_response.rb
Instance Attribute Summary collapse
- #archived_at ⇒ DateTime
-
#ban_expires ⇒ DateTime
Expiration date of the ban.
-
#ban_from_future_channels ⇒ Boolean
Whether the member's ban also applies to channels the channel's creator will create in the future (an active future channel ban by the creator targets this member).
-
#banned ⇒ Boolean
Whether member is banned this channel or not.
-
#channel_role ⇒ String
Role of the member in the channel.
-
#created_at ⇒ DateTime
Date/time of creation.
- #custom ⇒ Object
- #deleted_at ⇒ DateTime
- #deleted_messages ⇒ Array<String>
-
#future_channel_ban_expires ⇒ DateTime
Expiration date of the future channel ban; absent when the future channel ban is permanent.
-
#invite_accepted_at ⇒ DateTime
Date when invite was accepted.
-
#invite_rejected_at ⇒ DateTime
Date when invite was rejected.
-
#invited ⇒ Boolean
Whether member was invited or not.
-
#is_moderator ⇒ Boolean
Whether member is channel moderator or not.
- #notifications_muted ⇒ Boolean
- #pinned_at ⇒ DateTime
-
#role ⇒ String
Permission level of the member in the channel (DEPRECATED: use channel_role instead).
-
#shadow_banned ⇒ Boolean
Whether member is shadow banned in this channel or not.
- #status ⇒ String
-
#updated_at ⇒ DateTime
Date/time of the last update.
-
#user ⇒ UserResponse
User response object.
- #user_id ⇒ String
Class Method Summary collapse
-
.json_field_mappings ⇒ Object
Override field mappings for JSON serialization.
Instance Method Summary collapse
-
#initialize(attributes = {}) ⇒ ChannelMemberResponse
constructor
Initialize with attributes.
Methods inherited from BaseModel
#==, #inspect, omit_empty_fields, #to_h, #to_json
Constructor Details
#initialize(attributes = {}) ⇒ ChannelMemberResponse
Initialize with attributes
80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 |
# File 'lib/getstream_ruby/generated/models/channel_member_response.rb', line 80 def initialize(attributes = {}) super(attributes) @banned = attributes[:banned] || attributes['banned'] @channel_role = attributes[:channel_role] || attributes['channel_role'] @created_at = attributes[:created_at] || attributes['created_at'] @notifications_muted = attributes[:notifications_muted] || attributes['notifications_muted'] @shadow_banned = attributes[:shadow_banned] || attributes['shadow_banned'] @updated_at = attributes[:updated_at] || attributes['updated_at'] @custom = attributes[:custom] || attributes['custom'] @archived_at = attributes[:archived_at] || attributes['archived_at'] || nil @ban_expires = attributes[:ban_expires] || attributes['ban_expires'] || nil @ban_from_future_channels = attributes[:ban_from_future_channels] || attributes['ban_from_future_channels'] || nil @deleted_at = attributes[:deleted_at] || attributes['deleted_at'] || nil @future_channel_ban_expires = attributes[:future_channel_ban_expires] || attributes['future_channel_ban_expires'] || nil @invite_accepted_at = attributes[:invite_accepted_at] || attributes['invite_accepted_at'] || nil @invite_rejected_at = attributes[:invite_rejected_at] || attributes['invite_rejected_at'] || nil @invited = attributes[:invited] || attributes['invited'] || nil @is_moderator = attributes[:is_moderator] || attributes['is_moderator'] || nil @pinned_at = attributes[:pinned_at] || attributes['pinned_at'] || nil @role = attributes[:role] || attributes['role'] || nil @status = attributes[:status] || attributes['status'] || nil @user_id = attributes[:user_id] || attributes['user_id'] || nil @deleted_messages = attributes[:deleted_messages] || attributes['deleted_messages'] || nil @user = attributes[:user] || attributes['user'] || nil end |
Instance Attribute Details
#archived_at ⇒ DateTime
35 36 37 |
# File 'lib/getstream_ruby/generated/models/channel_member_response.rb', line 35 def archived_at @archived_at end |
#ban_expires ⇒ DateTime
Returns Expiration date of the ban.
38 39 40 |
# File 'lib/getstream_ruby/generated/models/channel_member_response.rb', line 38 def ban_expires @ban_expires end |
#ban_from_future_channels ⇒ Boolean
Returns Whether the member's ban also applies to channels the channel's creator will create in the future (an active future channel ban by the creator targets this member).
41 42 43 |
# File 'lib/getstream_ruby/generated/models/channel_member_response.rb', line 41 def ban_from_future_channels @ban_from_future_channels end |
#banned ⇒ Boolean
Returns Whether member is banned this channel or not.
14 15 16 |
# File 'lib/getstream_ruby/generated/models/channel_member_response.rb', line 14 def banned @banned end |
#channel_role ⇒ String
Returns Role of the member in the channel.
17 18 19 |
# File 'lib/getstream_ruby/generated/models/channel_member_response.rb', line 17 def channel_role @channel_role end |
#created_at ⇒ DateTime
Returns Date/time of creation.
20 21 22 |
# File 'lib/getstream_ruby/generated/models/channel_member_response.rb', line 20 def created_at @created_at end |
#custom ⇒ Object
32 33 34 |
# File 'lib/getstream_ruby/generated/models/channel_member_response.rb', line 32 def custom @custom end |
#deleted_at ⇒ DateTime
44 45 46 |
# File 'lib/getstream_ruby/generated/models/channel_member_response.rb', line 44 def deleted_at @deleted_at end |
#deleted_messages ⇒ Array<String>
74 75 76 |
# File 'lib/getstream_ruby/generated/models/channel_member_response.rb', line 74 def @deleted_messages end |
#future_channel_ban_expires ⇒ DateTime
Returns Expiration date of the future channel ban; absent when the future channel ban is permanent.
47 48 49 |
# File 'lib/getstream_ruby/generated/models/channel_member_response.rb', line 47 def future_channel_ban_expires @future_channel_ban_expires end |
#invite_accepted_at ⇒ DateTime
Returns Date when invite was accepted.
50 51 52 |
# File 'lib/getstream_ruby/generated/models/channel_member_response.rb', line 50 def invite_accepted_at @invite_accepted_at end |
#invite_rejected_at ⇒ DateTime
Returns Date when invite was rejected.
53 54 55 |
# File 'lib/getstream_ruby/generated/models/channel_member_response.rb', line 53 def invite_rejected_at @invite_rejected_at end |
#invited ⇒ Boolean
Returns Whether member was invited or not.
56 57 58 |
# File 'lib/getstream_ruby/generated/models/channel_member_response.rb', line 56 def invited @invited end |
#is_moderator ⇒ Boolean
Returns Whether member is channel moderator or not.
59 60 61 |
# File 'lib/getstream_ruby/generated/models/channel_member_response.rb', line 59 def is_moderator @is_moderator end |
#notifications_muted ⇒ Boolean
23 24 25 |
# File 'lib/getstream_ruby/generated/models/channel_member_response.rb', line 23 def notifications_muted @notifications_muted end |
#pinned_at ⇒ DateTime
62 63 64 |
# File 'lib/getstream_ruby/generated/models/channel_member_response.rb', line 62 def pinned_at @pinned_at end |
#role ⇒ String
Returns Permission level of the member in the channel (DEPRECATED: use channel_role instead). One of: member, moderator, admin, owner.
65 66 67 |
# File 'lib/getstream_ruby/generated/models/channel_member_response.rb', line 65 def role @role end |
#shadow_banned ⇒ Boolean
Returns Whether member is shadow banned in this channel or not.
26 27 28 |
# File 'lib/getstream_ruby/generated/models/channel_member_response.rb', line 26 def shadow_banned @shadow_banned end |
#status ⇒ String
68 69 70 |
# File 'lib/getstream_ruby/generated/models/channel_member_response.rb', line 68 def status @status end |
#updated_at ⇒ DateTime
Returns Date/time of the last update.
29 30 31 |
# File 'lib/getstream_ruby/generated/models/channel_member_response.rb', line 29 def updated_at @updated_at end |
#user ⇒ UserResponse
Returns User response object.
77 78 79 |
# File 'lib/getstream_ruby/generated/models/channel_member_response.rb', line 77 def user @user end |
#user_id ⇒ String
71 72 73 |
# File 'lib/getstream_ruby/generated/models/channel_member_response.rb', line 71 def user_id @user_id end |
Class Method Details
.json_field_mappings ⇒ Object
Override field mappings for JSON serialization
107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 |
# File 'lib/getstream_ruby/generated/models/channel_member_response.rb', line 107 def self.json_field_mappings { banned: 'banned', channel_role: 'channel_role', created_at: 'created_at', notifications_muted: 'notifications_muted', shadow_banned: 'shadow_banned', updated_at: 'updated_at', custom: 'custom', archived_at: 'archived_at', ban_expires: 'ban_expires', ban_from_future_channels: 'ban_from_future_channels', deleted_at: 'deleted_at', future_channel_ban_expires: 'future_channel_ban_expires', invite_accepted_at: 'invite_accepted_at', invite_rejected_at: 'invite_rejected_at', invited: 'invited', is_moderator: 'is_moderator', pinned_at: 'pinned_at', role: 'role', status: 'status', user_id: 'user_id', deleted_messages: 'deleted_messages', user: 'user' } end |