Class: GetStream::Generated::Models::ConfigResponse
- Defined in:
- lib/getstream_ruby/generated/models/config_response.rb
Instance Attribute Summary collapse
- #ai_image_config ⇒ AIImageConfig
-
#ai_image_label_definitions ⇒ Array<AIImageLabelDefinition>
Configurable image moderation label definitions for dashboard rendering.
-
#ai_image_subclassifications ⇒ Hash<String, Array<String>>
Available L2 subclassifications per L1 image moderation label, based on the active provider.
- #ai_text_config ⇒ AITextConfig
- #ai_video_config ⇒ AIVideoConfig
-
#async ⇒ Boolean
Whether moderation should be performed asynchronously.
- #automod_platform_circumvention_config ⇒ AutomodPlatformCircumventionConfig
- #automod_semantic_filters_config ⇒ AutomodSemanticFiltersConfig
- #automod_toxicity_config ⇒ AutomodToxicityConfig
-
#available_bodyguard_profiles ⇒ Array<BodyguardProfileSummary>
Names of Bodyguard credential profiles registered on this app.
- #block_list_config ⇒ BlockListConfig
-
#created_at ⇒ DateTime
When the configuration was created.
- #flood_config ⇒ FloodConfig
-
#key ⇒ String
Unique identifier for the moderation configuration.
- #llm_config ⇒ LLMConfig
- #supported_video_call_harm_types ⇒ Array<String>
-
#team ⇒ String
Team associated with the configuration.
-
#updated_at ⇒ DateTime
When the configuration was last updated.
- #velocity_filter_config ⇒ VelocityFilterConfig
- #video_call_rule_config ⇒ VideoCallRuleConfig
Class Method Summary collapse
-
.json_field_mappings ⇒ Object
Override field mappings for JSON serialization.
Instance Method Summary collapse
-
#initialize(attributes = {}) ⇒ ConfigResponse
constructor
Initialize with attributes.
Methods inherited from BaseModel
#==, #inspect, omit_empty_fields, #to_h, #to_json
Constructor Details
#initialize(attributes = {}) ⇒ ConfigResponse
Initialize with attributes
74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 |
# File 'lib/getstream_ruby/generated/models/config_response.rb', line 74 def initialize(attributes = {}) super(attributes) @async = attributes[:async] || attributes['async'] @created_at = attributes[:created_at] || attributes['created_at'] @key = attributes[:key] || attributes['key'] @team = attributes[:team] || attributes['team'] @updated_at = attributes[:updated_at] || attributes['updated_at'] @supported_video_call_harm_types = attributes[:supported_video_call_harm_types] || attributes['supported_video_call_harm_types'] @ai_image_label_definitions = attributes[:ai_image_label_definitions] || attributes['ai_image_label_definitions'] || nil @available_bodyguard_profiles = attributes[:available_bodyguard_profiles] || attributes['available_bodyguard_profiles'] || nil @ai_image_config = attributes[:ai_image_config] || attributes['ai_image_config'] || nil @ai_image_subclassifications = attributes[:ai_image_subclassifications] || attributes['ai_image_subclassifications'] || nil @ai_text_config = attributes[:ai_text_config] || attributes['ai_text_config'] || nil @ai_video_config = attributes[:ai_video_config] || attributes['ai_video_config'] || nil @automod_platform_circumvention_config = attributes[:automod_platform_circumvention_config] || attributes['automod_platform_circumvention_config'] || nil @automod_semantic_filters_config = attributes[:automod_semantic_filters_config] || attributes['automod_semantic_filters_config'] || nil @automod_toxicity_config = attributes[:automod_toxicity_config] || attributes['automod_toxicity_config'] || nil @block_list_config = attributes[:block_list_config] || attributes['block_list_config'] || nil @flood_config = attributes[:flood_config] || attributes['flood_config'] || nil @llm_config = attributes[:llm_config] || attributes['llm_config'] || nil @velocity_filter_config = attributes[:velocity_filter_config] || attributes['velocity_filter_config'] || nil @video_call_rule_config = attributes[:video_call_rule_config] || attributes['video_call_rule_config'] || nil end |
Instance Attribute Details
#ai_image_config ⇒ AIImageConfig
38 39 40 |
# File 'lib/getstream_ruby/generated/models/config_response.rb', line 38 def ai_image_config @ai_image_config end |
#ai_image_label_definitions ⇒ Array<AIImageLabelDefinition>
Returns Configurable image moderation label definitions for dashboard rendering.
32 33 34 |
# File 'lib/getstream_ruby/generated/models/config_response.rb', line 32 def ai_image_label_definitions @ai_image_label_definitions end |
#ai_image_subclassifications ⇒ Hash<String, Array<String>>
Returns Available L2 subclassifications per L1 image moderation label, based on the active provider.
41 42 43 |
# File 'lib/getstream_ruby/generated/models/config_response.rb', line 41 def ai_image_subclassifications @ai_image_subclassifications end |
#ai_text_config ⇒ AITextConfig
44 45 46 |
# File 'lib/getstream_ruby/generated/models/config_response.rb', line 44 def ai_text_config @ai_text_config end |
#ai_video_config ⇒ AIVideoConfig
47 48 49 |
# File 'lib/getstream_ruby/generated/models/config_response.rb', line 47 def ai_video_config @ai_video_config end |
#async ⇒ Boolean
Returns Whether moderation should be performed asynchronously.
14 15 16 |
# File 'lib/getstream_ruby/generated/models/config_response.rb', line 14 def async @async end |
#automod_platform_circumvention_config ⇒ AutomodPlatformCircumventionConfig
50 51 52 |
# File 'lib/getstream_ruby/generated/models/config_response.rb', line 50 def automod_platform_circumvention_config @automod_platform_circumvention_config end |
#automod_semantic_filters_config ⇒ AutomodSemanticFiltersConfig
53 54 55 |
# File 'lib/getstream_ruby/generated/models/config_response.rb', line 53 def automod_semantic_filters_config @automod_semantic_filters_config end |
#automod_toxicity_config ⇒ AutomodToxicityConfig
56 57 58 |
# File 'lib/getstream_ruby/generated/models/config_response.rb', line 56 def automod_toxicity_config @automod_toxicity_config end |
#available_bodyguard_profiles ⇒ Array<BodyguardProfileSummary>
Returns Names of Bodyguard credential profiles registered on this app. The dashboard uses this list to render the profile picker on the AI Text section.
35 36 37 |
# File 'lib/getstream_ruby/generated/models/config_response.rb', line 35 def available_bodyguard_profiles @available_bodyguard_profiles end |
#block_list_config ⇒ BlockListConfig
59 60 61 |
# File 'lib/getstream_ruby/generated/models/config_response.rb', line 59 def block_list_config @block_list_config end |
#created_at ⇒ DateTime
Returns When the configuration was created.
17 18 19 |
# File 'lib/getstream_ruby/generated/models/config_response.rb', line 17 def created_at @created_at end |
#flood_config ⇒ FloodConfig
62 63 64 |
# File 'lib/getstream_ruby/generated/models/config_response.rb', line 62 def flood_config @flood_config end |
#key ⇒ String
Returns Unique identifier for the moderation configuration.
20 21 22 |
# File 'lib/getstream_ruby/generated/models/config_response.rb', line 20 def key @key end |
#llm_config ⇒ LLMConfig
65 66 67 |
# File 'lib/getstream_ruby/generated/models/config_response.rb', line 65 def llm_config @llm_config end |
#supported_video_call_harm_types ⇒ Array<String>
29 30 31 |
# File 'lib/getstream_ruby/generated/models/config_response.rb', line 29 def supported_video_call_harm_types @supported_video_call_harm_types end |
#team ⇒ String
Returns Team associated with the configuration.
23 24 25 |
# File 'lib/getstream_ruby/generated/models/config_response.rb', line 23 def team @team end |
#updated_at ⇒ DateTime
Returns When the configuration was last updated.
26 27 28 |
# File 'lib/getstream_ruby/generated/models/config_response.rb', line 26 def updated_at @updated_at end |
#velocity_filter_config ⇒ VelocityFilterConfig
68 69 70 |
# File 'lib/getstream_ruby/generated/models/config_response.rb', line 68 def velocity_filter_config @velocity_filter_config end |
#video_call_rule_config ⇒ VideoCallRuleConfig
71 72 73 |
# File 'lib/getstream_ruby/generated/models/config_response.rb', line 71 def video_call_rule_config @video_call_rule_config end |
Class Method Details
.json_field_mappings ⇒ Object
Override field mappings for JSON serialization
99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 |
# File 'lib/getstream_ruby/generated/models/config_response.rb', line 99 def self.json_field_mappings { async: 'async', created_at: 'created_at', key: 'key', team: 'team', updated_at: 'updated_at', supported_video_call_harm_types: 'supported_video_call_harm_types', ai_image_label_definitions: 'ai_image_label_definitions', available_bodyguard_profiles: 'available_bodyguard_profiles', ai_image_config: 'ai_image_config', ai_image_subclassifications: 'ai_image_subclassifications', ai_text_config: 'ai_text_config', ai_video_config: 'ai_video_config', automod_platform_circumvention_config: 'automod_platform_circumvention_config', automod_semantic_filters_config: 'automod_semantic_filters_config', automod_toxicity_config: 'automod_toxicity_config', block_list_config: 'block_list_config', flood_config: 'flood_config', llm_config: 'llm_config', velocity_filter_config: 'velocity_filter_config', video_call_rule_config: 'video_call_rule_config' } end |