Class: GetStream::Generated::Models::DeleteChannelsRequest

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/getstream_ruby/generated/models/delete_channels_request.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#==, #inspect, omit_empty_fields, #to_h, #to_json

Constructor Details

#initialize(attributes = {}) ⇒ DeleteChannelsRequest

Initialize with attributes



23
24
25
26
27
28
# File 'lib/getstream_ruby/generated/models/delete_channels_request.rb', line 23

def initialize(attributes = {})
  super(attributes)
  @cids = attributes[:cids] || attributes['cids']
  @hard_delete = attributes[:hard_delete] || attributes['hard_delete'] || nil
  @skip_truncate = attributes[:skip_truncate] || attributes['skip_truncate'] || nil
end

Instance Attribute Details

#cidsArray<String>

Returns All channels that should be deleted.

Returns:

  • (Array<String>)

    All channels that should be deleted



14
15
16
# File 'lib/getstream_ruby/generated/models/delete_channels_request.rb', line 14

def cids
  @cids
end

#hard_deleteBoolean

Returns Server-side only. When true, the channels and all their resources are permanently deleted instead of soft-deleted.

Returns:

  • (Boolean)

    Server-side only. When true, the channels and all their resources are permanently deleted instead of soft-deleted.



17
18
19
# File 'lib/getstream_ruby/generated/models/delete_channels_request.rb', line 17

def hard_delete
  @hard_delete
end

#skip_truncateBoolean

Returns Server-side only. When true, the soft delete preserves message history instead of hiding it, so a later recreation of any of these channel IDs restores the full history. Only supported for distinct channels. Cannot be combined with hard_delete.

Returns:

  • (Boolean)

    Server-side only. When true, the soft delete preserves message history instead of hiding it, so a later recreation of any of these channel IDs restores the full history. Only supported for distinct channels. Cannot be combined with hard_delete.



20
21
22
# File 'lib/getstream_ruby/generated/models/delete_channels_request.rb', line 20

def skip_truncate
  @skip_truncate
end

Class Method Details

.json_field_mappingsObject

Override field mappings for JSON serialization



31
32
33
34
35
36
37
# File 'lib/getstream_ruby/generated/models/delete_channels_request.rb', line 31

def self.json_field_mappings
  {
    cids: 'cids',
    hard_delete: 'hard_delete',
    skip_truncate: 'skip_truncate'
  }
end