Class: GetStream::Generated::Models::EnrichmentOptions

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/getstream_ruby/generated/models/enrichment_options.rb

Overview

Options to skip specific enrichments to improve performance. Default is false (enrichments are included). Setting a field to true skips that enrichment.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#==, #inspect, omit_empty_fields, #to_h, #to_json

Constructor Details

#initialize(attributes = {}) ⇒ EnrichmentOptions

Initialize with attributes



74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
# File 'lib/getstream_ruby/generated/models/enrichment_options.rb', line 74

def initialize(attributes = {})
  super(attributes)
  @enrich_own_followings = attributes[:enrich_own_followings] || attributes['enrich_own_followings'] || nil
  @include_flat_activities = attributes[:include_flat_activities] || attributes['include_flat_activities'] || nil
  @include_score_vars = attributes[:include_score_vars] || attributes['include_score_vars'] || nil
  @skip_activity = attributes[:skip_activity] || attributes['skip_activity'] || nil
  @skip_activity_collections = attributes[:skip_activity_collections] || attributes['skip_activity_collections'] || nil
  @skip_activity_comments = attributes[:skip_activity_comments] || attributes['skip_activity_comments'] || nil
  @skip_activity_current_feed = attributes[:skip_activity_current_feed] || attributes['skip_activity_current_feed'] || nil
  @skip_activity_mentioned_users = attributes[:skip_activity_mentioned_users] || attributes['skip_activity_mentioned_users'] || nil
  @skip_activity_own_bookmarks = attributes[:skip_activity_own_bookmarks] || attributes['skip_activity_own_bookmarks'] || nil
  @skip_activity_parents = attributes[:skip_activity_parents] || attributes['skip_activity_parents'] || nil
  @skip_activity_poll = attributes[:skip_activity_poll] || attributes['skip_activity_poll'] || nil
  @skip_activity_reactions = attributes[:skip_activity_reactions] || attributes['skip_activity_reactions'] || nil
  @skip_activity_refresh_image_urls = attributes[:skip_activity_refresh_image_urls] || attributes['skip_activity_refresh_image_urls'] || nil
  @skip_all = attributes[:skip_all] || attributes['skip_all'] || nil
  @skip_feed_member_user = attributes[:skip_feed_member_user] || attributes['skip_feed_member_user'] || nil
  @skip_followers = attributes[:skip_followers] || attributes['skip_followers'] || nil
  @skip_following = attributes[:skip_following] || attributes['skip_following'] || nil
  @skip_own_capabilities = attributes[:skip_own_capabilities] || attributes['skip_own_capabilities'] || nil
  @skip_own_follows = attributes[:skip_own_follows] || attributes['skip_own_follows'] || nil
  @skip_pins = attributes[:skip_pins] || attributes['skip_pins'] || nil
end

Instance Attribute Details

#enrich_own_followingsBoolean

Returns Default: false. When true, includes fetching and enriching own_followings (follows where activity author’s feeds follow current user’s feeds).

Returns:

  • (Boolean)

    Default: false. When true, includes fetching and enriching own_followings (follows where activity author’s feeds follow current user’s feeds).



14
15
16
# File 'lib/getstream_ruby/generated/models/enrichment_options.rb', line 14

def enrich_own_followings
  @enrich_own_followings
end

#include_flat_activitiesBoolean

Returns Controls the top-level flat ‘activities’ array for aggregated feeds. For new apps, defaults to false (excluded); set to true to include. For older apps, defaults to true (included) for backward compatibility; set to false to exclude.

Returns:

  • (Boolean)

    Controls the top-level flat ‘activities’ array for aggregated feeds. For new apps, defaults to false (excluded); set to true to include. For older apps, defaults to true (included) for backward compatibility; set to false to exclude.



17
18
19
# File 'lib/getstream_ruby/generated/models/enrichment_options.rb', line 17

def include_flat_activities
  @include_flat_activities
end

#include_score_varsBoolean

Returns Default: false. When true, includes score_vars in activity responses containing variable values used at ranking time.

Returns:

  • (Boolean)

    Default: false. When true, includes score_vars in activity responses containing variable values used at ranking time.



20
21
22
# File 'lib/getstream_ruby/generated/models/enrichment_options.rb', line 20

def include_score_vars
  @include_score_vars
end

#skip_activityBoolean

Returns Default: false. When true, skips all activity enrichments.

Returns:

  • (Boolean)

    Default: false. When true, skips all activity enrichments.



23
24
25
# File 'lib/getstream_ruby/generated/models/enrichment_options.rb', line 23

def skip_activity
  @skip_activity
end

#skip_activity_collectionsBoolean

Returns Default: false. When true, skips enriching collections on activities.

Returns:

  • (Boolean)

    Default: false. When true, skips enriching collections on activities.



26
27
28
# File 'lib/getstream_ruby/generated/models/enrichment_options.rb', line 26

def skip_activity_collections
  @skip_activity_collections
end

#skip_activity_commentsBoolean

Returns Default: false. When true, skips enriching comments on activities.

Returns:

  • (Boolean)

    Default: false. When true, skips enriching comments on activities.



29
30
31
# File 'lib/getstream_ruby/generated/models/enrichment_options.rb', line 29

def skip_activity_comments
  @skip_activity_comments
end

#skip_activity_current_feedBoolean

Returns Default: false. When true, skips enriching current_feed on activities. Note: CurrentFeed is still computed for permission checks, but enrichment is skipped.

Returns:

  • (Boolean)

    Default: false. When true, skips enriching current_feed on activities. Note: CurrentFeed is still computed for permission checks, but enrichment is skipped.



32
33
34
# File 'lib/getstream_ruby/generated/models/enrichment_options.rb', line 32

def skip_activity_current_feed
  @skip_activity_current_feed
end

#skip_activity_mentioned_usersBoolean

Returns Default: false. When true, skips enriching mentioned users on activities.

Returns:

  • (Boolean)

    Default: false. When true, skips enriching mentioned users on activities.



35
36
37
# File 'lib/getstream_ruby/generated/models/enrichment_options.rb', line 35

def skip_activity_mentioned_users
  @skip_activity_mentioned_users
end

#skip_activity_own_bookmarksBoolean

Returns Default: false. When true, skips enriching own bookmarks on activities.

Returns:

  • (Boolean)

    Default: false. When true, skips enriching own bookmarks on activities.



38
39
40
# File 'lib/getstream_ruby/generated/models/enrichment_options.rb', line 38

def skip_activity_own_bookmarks
  @skip_activity_own_bookmarks
end

#skip_activity_parentsBoolean

Returns Default: false. When true, skips enriching parent activities.

Returns:

  • (Boolean)

    Default: false. When true, skips enriching parent activities.



41
42
43
# File 'lib/getstream_ruby/generated/models/enrichment_options.rb', line 41

def skip_activity_parents
  @skip_activity_parents
end

#skip_activity_pollBoolean

Returns Default: false. When true, skips enriching poll data on activities.

Returns:

  • (Boolean)

    Default: false. When true, skips enriching poll data on activities.



44
45
46
# File 'lib/getstream_ruby/generated/models/enrichment_options.rb', line 44

def skip_activity_poll
  @skip_activity_poll
end

#skip_activity_reactionsBoolean

Returns Default: false. When true, skips fetching and enriching latest and own reactions on activities. Note: If reactions are already denormalized in the database, they will still be included.

Returns:

  • (Boolean)

    Default: false. When true, skips fetching and enriching latest and own reactions on activities. Note: If reactions are already denormalized in the database, they will still be included.



47
48
49
# File 'lib/getstream_ruby/generated/models/enrichment_options.rb', line 47

def skip_activity_reactions
  @skip_activity_reactions
end

#skip_activity_refresh_image_urlsBoolean

Returns Default: false. When true, skips refreshing image URLs on activities.

Returns:

  • (Boolean)

    Default: false. When true, skips refreshing image URLs on activities.



50
51
52
# File 'lib/getstream_ruby/generated/models/enrichment_options.rb', line 50

def skip_activity_refresh_image_urls
  @skip_activity_refresh_image_urls
end

#skip_allBoolean

Returns Default: false. When true, skips all enrichments.

Returns:

  • (Boolean)

    Default: false. When true, skips all enrichments.



53
54
55
# File 'lib/getstream_ruby/generated/models/enrichment_options.rb', line 53

def skip_all
  @skip_all
end

#skip_feed_member_userBoolean

Returns Default: false. When true, skips enriching user data on feed members.

Returns:

  • (Boolean)

    Default: false. When true, skips enriching user data on feed members.



56
57
58
# File 'lib/getstream_ruby/generated/models/enrichment_options.rb', line 56

def skip_feed_member_user
  @skip_feed_member_user
end

#skip_followersBoolean

Returns Default: false. When true, skips fetching and enriching followers. Note: If followers_pagination is explicitly provided, followers will be fetched regardless of this setting.

Returns:

  • (Boolean)

    Default: false. When true, skips fetching and enriching followers. Note: If followers_pagination is explicitly provided, followers will be fetched regardless of this setting.



59
60
61
# File 'lib/getstream_ruby/generated/models/enrichment_options.rb', line 59

def skip_followers
  @skip_followers
end

#skip_followingBoolean

Returns Default: false. When true, skips fetching and enriching following. Note: If following_pagination is explicitly provided, following will be fetched regardless of this setting.

Returns:

  • (Boolean)

    Default: false. When true, skips fetching and enriching following. Note: If following_pagination is explicitly provided, following will be fetched regardless of this setting.



62
63
64
# File 'lib/getstream_ruby/generated/models/enrichment_options.rb', line 62

def skip_following
  @skip_following
end

#skip_own_capabilitiesBoolean

Returns Default: false. When true, skips computing and including capabilities for feeds.

Returns:

  • (Boolean)

    Default: false. When true, skips computing and including capabilities for feeds.



65
66
67
# File 'lib/getstream_ruby/generated/models/enrichment_options.rb', line 65

def skip_own_capabilities
  @skip_own_capabilities
end

#skip_own_followsBoolean

Returns Default: false. When true, skips fetching and enriching own_follows (follows where user’s feeds follow target feeds).

Returns:

  • (Boolean)

    Default: false. When true, skips fetching and enriching own_follows (follows where user’s feeds follow target feeds).



68
69
70
# File 'lib/getstream_ruby/generated/models/enrichment_options.rb', line 68

def skip_own_follows
  @skip_own_follows
end

#skip_pinsBoolean

Returns Default: false. When true, skips enriching pinned activities.

Returns:

  • (Boolean)

    Default: false. When true, skips enriching pinned activities.



71
72
73
# File 'lib/getstream_ruby/generated/models/enrichment_options.rb', line 71

def skip_pins
  @skip_pins
end

Class Method Details

.json_field_mappingsObject

Override field mappings for JSON serialization



99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
# File 'lib/getstream_ruby/generated/models/enrichment_options.rb', line 99

def self.json_field_mappings
  {
    enrich_own_followings: 'enrich_own_followings',
    include_flat_activities: 'include_flat_activities',
    include_score_vars: 'include_score_vars',
    skip_activity: 'skip_activity',
    skip_activity_collections: 'skip_activity_collections',
    skip_activity_comments: 'skip_activity_comments',
    skip_activity_current_feed: 'skip_activity_current_feed',
    skip_activity_mentioned_users: 'skip_activity_mentioned_users',
    skip_activity_own_bookmarks: 'skip_activity_own_bookmarks',
    skip_activity_parents: 'skip_activity_parents',
    skip_activity_poll: 'skip_activity_poll',
    skip_activity_reactions: 'skip_activity_reactions',
    skip_activity_refresh_image_urls: 'skip_activity_refresh_image_urls',
    skip_all: 'skip_all',
    skip_feed_member_user: 'skip_feed_member_user',
    skip_followers: 'skip_followers',
    skip_following: 'skip_following',
    skip_own_capabilities: 'skip_own_capabilities',
    skip_own_follows: 'skip_own_follows',
    skip_pins: 'skip_pins'
  }
end