Class: GetStream::Generated::Models::EntityCreatorResponse

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/getstream_ruby/generated/models/entity_creator_response.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#==, #inspect, omit_empty_fields, #to_h, #to_json

Constructor Details

#initialize(attributes = {}) ⇒ EntityCreatorResponse

Initialize with attributes



98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
# File 'lib/getstream_ruby/generated/models/entity_creator_response.rb', line 98

def initialize(attributes = {})
  super(attributes)
  @ban_count = attributes[:ban_count] || attributes['ban_count']
  @banned = attributes[:banned] || attributes['banned']
  @created_at = attributes[:created_at] || attributes['created_at']
  @deleted_content_count = attributes[:deleted_content_count] || attributes['deleted_content_count']
  @flagged_count = attributes[:flagged_count] || attributes['flagged_count']
  @id = attributes[:id] || attributes['id']
  @invisible = attributes[:invisible] || attributes['invisible']
  @language = attributes[:language] || attributes['language']
  @online = attributes[:online] || attributes['online']
  @role = attributes[:role] || attributes['role']
  @shadow_banned = attributes[:shadow_banned] || attributes['shadow_banned']
  @updated_at = attributes[:updated_at] || attributes['updated_at']
  @blocked_user_ids = attributes[:blocked_user_ids] || attributes['blocked_user_ids']
  @teams = attributes[:teams] || attributes['teams']
  @custom = attributes[:custom] || attributes['custom']
  @avg_response_time = attributes[:avg_response_time] || attributes['avg_response_time'] || nil
  @ban_expires = attributes[:ban_expires] || attributes['ban_expires'] || nil
  @bypass_moderation = attributes[:bypass_moderation] || attributes['bypass_moderation'] || nil
  @deactivated_at = attributes[:deactivated_at] || attributes['deactivated_at'] || nil
  @deleted_at = attributes[:deleted_at] || attributes['deleted_at'] || nil
  @image = attributes[:image] || attributes['image'] || nil
  @last_active = attributes[:last_active] || attributes['last_active'] || nil
  @name = attributes[:name] || attributes['name'] || nil
  @revoke_tokens_issued_before = attributes[:revoke_tokens_issued_before] || attributes['revoke_tokens_issued_before'] || nil
  @devices = attributes[:devices] || attributes['devices'] || nil
  @privacy_settings = attributes[:privacy_settings] || attributes['privacy_settings'] || nil
  @push_notifications = attributes[:push_notifications] || attributes['push_notifications'] || nil
  @teams_role = attributes[:teams_role] || attributes['teams_role'] || nil
end

Instance Attribute Details

#avg_response_time ⇒ Integer

Returns:

  • (Integer)


59
60
61
# File 'lib/getstream_ruby/generated/models/entity_creator_response.rb', line 59

def avg_response_time
  @avg_response_time
end

#ban_count ⇒ Integer

Returns Number of minor actions performed on the user.

Returns:

  • (Integer) —

    Number of minor actions performed on the user



14
15
16
# File 'lib/getstream_ruby/generated/models/entity_creator_response.rb', line 14

def ban_count
  @ban_count
end

#ban_expires ⇒ DateTime

Returns:

  • (DateTime)


62
63
64
# File 'lib/getstream_ruby/generated/models/entity_creator_response.rb', line 62

def ban_expires
  @ban_expires
end

#banned ⇒ Boolean

Returns:

  • (Boolean)


17
18
19
# File 'lib/getstream_ruby/generated/models/entity_creator_response.rb', line 17

def banned
  @banned
end

#blocked_user_ids ⇒ Array<String>

Returns:

  • (Array<String>)


50
51
52
# File 'lib/getstream_ruby/generated/models/entity_creator_response.rb', line 50

def blocked_user_ids
  @blocked_user_ids
end

#bypass_moderation ⇒ Boolean

Returns:

  • (Boolean)


65
66
67
# File 'lib/getstream_ruby/generated/models/entity_creator_response.rb', line 65

def bypass_moderation
  @bypass_moderation
end

#created_at ⇒ DateTime

Returns:

  • (DateTime)


20
21
22
# File 'lib/getstream_ruby/generated/models/entity_creator_response.rb', line 20

def created_at
  @created_at
end

#custom ⇒ Object

Returns:

  • (Object)


56
57
58
# File 'lib/getstream_ruby/generated/models/entity_creator_response.rb', line 56

def custom
  @custom
end

#deactivated_at ⇒ DateTime

Returns:

  • (DateTime)


68
69
70
# File 'lib/getstream_ruby/generated/models/entity_creator_response.rb', line 68

def deactivated_at
  @deactivated_at
end

#deleted_at ⇒ DateTime

Returns:

  • (DateTime)


71
72
73
# File 'lib/getstream_ruby/generated/models/entity_creator_response.rb', line 71

def deleted_at
  @deleted_at
end

#deleted_content_count ⇒ Integer

Returns Number of major actions performed on the user.

Returns:

  • (Integer) —

    Number of major actions performed on the user



23
24
25
# File 'lib/getstream_ruby/generated/models/entity_creator_response.rb', line 23

def deleted_content_count
  @deleted_content_count
end

#devices ⇒ Array<DeviceResponse>

Returns:



86
87
88
# File 'lib/getstream_ruby/generated/models/entity_creator_response.rb', line 86

def devices
  @devices
end

#flagged_count ⇒ Integer

Returns Number of flag actions performed on the user.

Returns:

  • (Integer) —

    Number of flag actions performed on the user



26
27
28
# File 'lib/getstream_ruby/generated/models/entity_creator_response.rb', line 26

def flagged_count
  @flagged_count
end

#id ⇒ String

Returns:

  • (String)


29
30
31
# File 'lib/getstream_ruby/generated/models/entity_creator_response.rb', line 29

def id
  @id
end

#image ⇒ String

Returns:

  • (String)


74
75
76
# File 'lib/getstream_ruby/generated/models/entity_creator_response.rb', line 74

def image
  @image
end

#invisible ⇒ Boolean

Returns:

  • (Boolean)


32
33
34
# File 'lib/getstream_ruby/generated/models/entity_creator_response.rb', line 32

def invisible
  @invisible
end

#language ⇒ String

Returns:

  • (String)


35
36
37
# File 'lib/getstream_ruby/generated/models/entity_creator_response.rb', line 35

def language
  @language
end

#last_active ⇒ DateTime

Returns:

  • (DateTime)


77
78
79
# File 'lib/getstream_ruby/generated/models/entity_creator_response.rb', line 77

def last_active
  @last_active
end

#name ⇒ String

Returns:

  • (String)


80
81
82
# File 'lib/getstream_ruby/generated/models/entity_creator_response.rb', line 80

def name
  @name
end

#online ⇒ Boolean

Returns:

  • (Boolean)


38
39
40
# File 'lib/getstream_ruby/generated/models/entity_creator_response.rb', line 38

def online
  @online
end

#privacy_settings ⇒ PrivacySettingsResponse



89
90
91
# File 'lib/getstream_ruby/generated/models/entity_creator_response.rb', line 89

def privacy_settings
  @privacy_settings
end

#push_notifications ⇒ PushNotificationSettingsResponse



92
93
94
# File 'lib/getstream_ruby/generated/models/entity_creator_response.rb', line 92

def push_notifications
  @push_notifications
end

#revoke_tokens_issued_before ⇒ DateTime

Returns:

  • (DateTime)


83
84
85
# File 'lib/getstream_ruby/generated/models/entity_creator_response.rb', line 83

def revoke_tokens_issued_before
  @revoke_tokens_issued_before
end

#role ⇒ String

Returns:

  • (String)


41
42
43
# File 'lib/getstream_ruby/generated/models/entity_creator_response.rb', line 41

def role
  @role
end

#shadow_banned ⇒ Boolean

Returns:

  • (Boolean)


44
45
46
# File 'lib/getstream_ruby/generated/models/entity_creator_response.rb', line 44

def shadow_banned
  @shadow_banned
end

#teams ⇒ Array<String>

Returns:

  • (Array<String>)


53
54
55
# File 'lib/getstream_ruby/generated/models/entity_creator_response.rb', line 53

def teams
  @teams
end

#teams_role ⇒ Hash<String, String>

Returns:

  • (Hash<String, String>)


95
96
97
# File 'lib/getstream_ruby/generated/models/entity_creator_response.rb', line 95

def teams_role
  @teams_role
end

#updated_at ⇒ DateTime

Returns:

  • (DateTime)


47
48
49
# File 'lib/getstream_ruby/generated/models/entity_creator_response.rb', line 47

def updated_at
  @updated_at
end

Class Method Details

.json_field_mappings ⇒ Object

Override field mappings for JSON serialization



131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
# File 'lib/getstream_ruby/generated/models/entity_creator_response.rb', line 131

def self.json_field_mappings
  {
    ban_count: 'ban_count',
    banned: 'banned',
    created_at: 'created_at',
    deleted_content_count: 'deleted_content_count',
    flagged_count: 'flagged_count',
    id: 'id',
    invisible: 'invisible',
    language: 'language',
    online: 'online',
    role: 'role',
    shadow_banned: 'shadow_banned',
    updated_at: 'updated_at',
    blocked_user_ids: 'blocked_user_ids',
    teams: 'teams',
    custom: 'custom',
    avg_response_time: 'avg_response_time',
    ban_expires: 'ban_expires',
    bypass_moderation: 'bypass_moderation',
    deactivated_at: 'deactivated_at',
    deleted_at: 'deleted_at',
    image: 'image',
    last_active: 'last_active',
    name: 'name',
    revoke_tokens_issued_before: 'revoke_tokens_issued_before',
    devices: 'devices',
    privacy_settings: 'privacy_settings',
    push_notifications: 'push_notifications',
    teams_role: 'teams_role'
  }
end