Class: GetStream::Generated::Models::FeedGroupScope

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/getstream_ruby/generated/models/feed_group_scope.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#==, #inspect, omit_empty_fields, #to_h, #to_json

Constructor Details

#initialize(attributes = {}) ⇒ FeedGroupScope

Initialize with attributes



20
21
22
23
24
# File 'lib/getstream_ruby/generated/models/feed_group_scope.rb', line 20

def initialize(attributes = {})
  super(attributes)
  @exclude = attributes[:exclude] || attributes['exclude'] || nil
  @include = attributes[:include] || attributes['include'] || nil
end

Instance Attribute Details

#excludeArray<String>

Returns Select activities from every feed group except these. An activity cross-posted to an excluded and a non-excluded group is still selected. Mutually exclusive with include.

Returns:

  • (Array<String>)

    Select activities from every feed group except these. An activity cross-posted to an excluded and a non-excluded group is still selected. Mutually exclusive with include



14
15
16
# File 'lib/getstream_ruby/generated/models/feed_group_scope.rb', line 14

def exclude
  @exclude
end

#includeArray<String>

Returns Select only activities that live in a feed belonging to one of these feed groups. Mutually exclusive with exclude.

Returns:

  • (Array<String>)

    Select only activities that live in a feed belonging to one of these feed groups. Mutually exclusive with exclude



17
18
19
# File 'lib/getstream_ruby/generated/models/feed_group_scope.rb', line 17

def include
  @include
end

Class Method Details

.json_field_mappingsObject

Override field mappings for JSON serialization



27
28
29
30
31
32
# File 'lib/getstream_ruby/generated/models/feed_group_scope.rb', line 27

def self.json_field_mappings
  {
    exclude: 'exclude',
    include: 'include'
  }
end