Class: GetStream::Generated::Models::FriendReactionsOptions

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/getstream_ruby/generated/models/friend_reactions_options.rb

Overview

Options to control fetching reactions from friends (users you follow or have mutual follows with).

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#==, #inspect, omit_empty_fields, #to_h, #to_json

Constructor Details

#initialize(attributes = {}) ⇒ FriendReactionsOptions

Initialize with attributes



23
24
25
26
27
28
# File 'lib/getstream_ruby/generated/models/friend_reactions_options.rb', line 23

def initialize(attributes = {})
  super(attributes)
  @enabled = attributes[:enabled] || attributes['enabled'] || nil
  @limit = attributes[:limit] || attributes['limit'] || nil
  @type = attributes[:type] || attributes['type'] || nil
end

Instance Attribute Details

#enabledBoolean

Returns Default: false. When true, fetches friend reactions for activities.

Returns:

  • (Boolean)

    Default: false. When true, fetches friend reactions for activities.



14
15
16
# File 'lib/getstream_ruby/generated/models/friend_reactions_options.rb', line 14

def enabled
  @enabled
end

#limitInteger

Returns Default: 3, Max: 10. The maximum number of friend reactions to return per activity.

Returns:

  • (Integer)

    Default: 3, Max: 10. The maximum number of friend reactions to return per activity.



17
18
19
# File 'lib/getstream_ruby/generated/models/friend_reactions_options.rb', line 17

def limit
  @limit
end

#typeString

Returns Default: ‘following’. The type of friend relationship to use. ‘following’ = users you follow, ‘mutual’ = users with mutual follows. One of: following, mutual.

Returns:

  • (String)

    Default: ‘following’. The type of friend relationship to use. ‘following’ = users you follow, ‘mutual’ = users with mutual follows. One of: following, mutual



20
21
22
# File 'lib/getstream_ruby/generated/models/friend_reactions_options.rb', line 20

def type
  @type
end

Class Method Details

.json_field_mappingsObject

Override field mappings for JSON serialization



31
32
33
34
35
36
37
# File 'lib/getstream_ruby/generated/models/friend_reactions_options.rb', line 31

def self.json_field_mappings
  {
    enabled: 'enabled',
    limit: 'limit',
    type: 'type'
  }
end