Class: GetStream::Generated::Models::GetOrCreateFollowResponse
- Inherits:
-
BaseModel
- Object
- BaseModel
- GetStream::Generated::Models::GetOrCreateFollowResponse
- Defined in:
- lib/getstream_ruby/generated/models/get_or_create_follow_response.rb
Instance Attribute Summary collapse
-
#created ⇒ Boolean
True if the follow was newly created by this request; false if it already existed.
- #duration ⇒ String
- #follow ⇒ FollowResponse
-
#notification_created ⇒ Boolean
Whether a notification activity was successfully created (only set when the follow was newly created).
Class Method Summary collapse
-
.json_field_mappings ⇒ Object
Override field mappings for JSON serialization.
Instance Method Summary collapse
-
#initialize(attributes = {}) ⇒ GetOrCreateFollowResponse
constructor
Initialize with attributes.
Methods inherited from BaseModel
#==, #inspect, omit_empty_fields, #to_h, #to_json
Constructor Details
#initialize(attributes = {}) ⇒ GetOrCreateFollowResponse
Initialize with attributes
26 27 28 29 30 31 32 |
# File 'lib/getstream_ruby/generated/models/get_or_create_follow_response.rb', line 26 def initialize(attributes = {}) super(attributes) @created = attributes[:created] || attributes['created'] @duration = attributes[:duration] || attributes['duration'] @follow = attributes[:follow] || attributes['follow'] @notification_created = attributes[:notification_created] || attributes['notification_created'] || nil end |
Instance Attribute Details
#created ⇒ Boolean
Returns True if the follow was newly created by this request; false if it already existed.
14 15 16 |
# File 'lib/getstream_ruby/generated/models/get_or_create_follow_response.rb', line 14 def created @created end |
#duration ⇒ String
17 18 19 |
# File 'lib/getstream_ruby/generated/models/get_or_create_follow_response.rb', line 17 def duration @duration end |
#follow ⇒ FollowResponse
20 21 22 |
# File 'lib/getstream_ruby/generated/models/get_or_create_follow_response.rb', line 20 def follow @follow end |
#notification_created ⇒ Boolean
Returns Whether a notification activity was successfully created (only set when the follow was newly created).
23 24 25 |
# File 'lib/getstream_ruby/generated/models/get_or_create_follow_response.rb', line 23 def notification_created @notification_created end |
Class Method Details
.json_field_mappings ⇒ Object
Override field mappings for JSON serialization
35 36 37 38 39 40 41 42 |
# File 'lib/getstream_ruby/generated/models/get_or_create_follow_response.rb', line 35 def self.json_field_mappings { created: 'created', duration: 'duration', follow: 'follow', notification_created: 'notification_created' } end |