Class: GetStream::Generated::Models::GetOrCreateUnfollowResponse
- Inherits:
-
BaseModel
- Object
- BaseModel
- GetStream::Generated::Models::GetOrCreateUnfollowResponse
- Defined in:
- lib/getstream_ruby/generated/models/get_or_create_unfollow_response.rb
Instance Attribute Summary collapse
-
#deleted ⇒ Boolean
True if a follow was found and removed by this request; false if no follow existed.
- #duration ⇒ String
- #follow ⇒ FollowResponse
Class Method Summary collapse
-
.json_field_mappings ⇒ Object
Override field mappings for JSON serialization.
Instance Method Summary collapse
-
#initialize(attributes = {}) ⇒ GetOrCreateUnfollowResponse
constructor
Initialize with attributes.
Methods inherited from BaseModel
#==, #inspect, omit_empty_fields, #to_h, #to_json
Constructor Details
#initialize(attributes = {}) ⇒ GetOrCreateUnfollowResponse
Initialize with attributes
23 24 25 26 27 28 |
# File 'lib/getstream_ruby/generated/models/get_or_create_unfollow_response.rb', line 23 def initialize(attributes = {}) super(attributes) @deleted = attributes[:deleted] || attributes['deleted'] @duration = attributes[:duration] || attributes['duration'] @follow = attributes[:follow] || attributes['follow'] || nil end |
Instance Attribute Details
#deleted ⇒ Boolean
Returns True if a follow was found and removed by this request; false if no follow existed.
14 15 16 |
# File 'lib/getstream_ruby/generated/models/get_or_create_unfollow_response.rb', line 14 def deleted @deleted end |
#duration ⇒ String
17 18 19 |
# File 'lib/getstream_ruby/generated/models/get_or_create_unfollow_response.rb', line 17 def duration @duration end |
#follow ⇒ FollowResponse
20 21 22 |
# File 'lib/getstream_ruby/generated/models/get_or_create_unfollow_response.rb', line 20 def follow @follow end |
Class Method Details
.json_field_mappings ⇒ Object
Override field mappings for JSON serialization
31 32 33 34 35 36 37 |
# File 'lib/getstream_ruby/generated/models/get_or_create_unfollow_response.rb', line 31 def self.json_field_mappings { deleted: 'deleted', duration: 'duration', follow: 'follow' } end |