Class: GetStream::Generated::Models::GetUserInterestsResponse

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/getstream_ruby/generated/models/get_user_interests_response.rb

Overview

User’s computed interest tags ordered by descending count, then ascending tag name

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#==, #inspect, omit_empty_fields, #to_h, #to_json

Constructor Details

#initialize(attributes = {}) ⇒ GetUserInterestsResponse

Initialize with attributes



20
21
22
23
24
# File 'lib/getstream_ruby/generated/models/get_user_interests_response.rb', line 20

def initialize(attributes = {})
  super(attributes)
  @duration = attributes[:duration] || attributes['duration']
  @interests = attributes[:interests] || attributes['interests']
end

Instance Attribute Details

#durationString

Returns:

  • (String)


14
15
16
# File 'lib/getstream_ruby/generated/models/get_user_interests_response.rb', line 14

def duration
  @duration
end

#interestsArray<InterestTagResponse>

Returns Top-N interest tags sorted by descending count, then alphabetically by tag.

Returns:

  • (Array<InterestTagResponse>)

    Top-N interest tags sorted by descending count, then alphabetically by tag



17
18
19
# File 'lib/getstream_ruby/generated/models/get_user_interests_response.rb', line 17

def interests
  @interests
end

Class Method Details

.json_field_mappingsObject

Override field mappings for JSON serialization



27
28
29
30
31
32
# File 'lib/getstream_ruby/generated/models/get_user_interests_response.rb', line 27

def self.json_field_mappings
  {
    duration: 'duration',
    interests: 'interests'
  }
end