Class: GetStream::Generated::Models::MemberUpdatedEvent
- Defined in:
- lib/getstream_ruby/generated/models/member_updated_event.rb
Overview
Emitted when a member is updated in a channel.
Instance Attribute Summary collapse
- #channel ⇒ ChannelResponse
- #channel_custom ⇒ Object
-
#channel_id ⇒ String
The ID of the channel in which the member was updated.
-
#channel_member_count ⇒ Integer
The number of members in the channel.
-
#channel_message_count ⇒ Integer
The number of messages in the channel.
-
#channel_type ⇒ String
The type of the channel in which the member was updated.
-
#cid ⇒ String
The CID of the channel in which the member was updated.
-
#created_at ⇒ DateTime
Date/time of creation.
- #custom ⇒ Object
- #member ⇒ ChannelMemberResponse
- #received_at ⇒ DateTime
-
#team ⇒ String
The team ID.
-
#type ⇒ String
The type of event: “member.updated” in this case.
- #user ⇒ UserResponseCommonFields
Class Method Summary collapse
-
.json_field_mappings ⇒ Object
Override field mappings for JSON serialization.
Instance Method Summary collapse
-
#initialize(attributes = {}) ⇒ MemberUpdatedEvent
constructor
Initialize with attributes.
Methods inherited from BaseModel
#==, #inspect, omit_empty_fields, #to_h, #to_json
Constructor Details
#initialize(attributes = {}) ⇒ MemberUpdatedEvent
Initialize with attributes
56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 |
# File 'lib/getstream_ruby/generated/models/member_updated_event.rb', line 56 def initialize(attributes = {}) super(attributes) @created_at = attributes[:created_at] || attributes['created_at'] @channel = attributes[:channel] || attributes['channel'] @custom = attributes[:custom] || attributes['custom'] @member = attributes[:member] || attributes['member'] @type = attributes[:type] || attributes['type'] || "member.updated" @channel_id = attributes[:channel_id] || attributes['channel_id'] || nil @channel_member_count = attributes[:channel_member_count] || attributes['channel_member_count'] || nil @channel_message_count = attributes[:channel_message_count] || attributes['channel_message_count'] || nil @channel_type = attributes[:channel_type] || attributes['channel_type'] || nil @cid = attributes[:cid] || attributes['cid'] || nil @received_at = attributes[:received_at] || attributes['received_at'] || nil @team = attributes[:team] || attributes['team'] || nil @channel_custom = attributes[:channel_custom] || attributes['channel_custom'] || nil @user = attributes[:user] || attributes['user'] || nil end |
Instance Attribute Details
#channel ⇒ ChannelResponse
17 18 19 |
# File 'lib/getstream_ruby/generated/models/member_updated_event.rb', line 17 def channel @channel end |
#channel_custom ⇒ Object
50 51 52 |
# File 'lib/getstream_ruby/generated/models/member_updated_event.rb', line 50 def channel_custom @channel_custom end |
#channel_id ⇒ String
Returns The ID of the channel in which the member was updated.
29 30 31 |
# File 'lib/getstream_ruby/generated/models/member_updated_event.rb', line 29 def channel_id @channel_id end |
#channel_member_count ⇒ Integer
Returns The number of members in the channel.
32 33 34 |
# File 'lib/getstream_ruby/generated/models/member_updated_event.rb', line 32 def channel_member_count @channel_member_count end |
#channel_message_count ⇒ Integer
Returns The number of messages in the channel.
35 36 37 |
# File 'lib/getstream_ruby/generated/models/member_updated_event.rb', line 35 def @channel_message_count end |
#channel_type ⇒ String
Returns The type of the channel in which the member was updated.
38 39 40 |
# File 'lib/getstream_ruby/generated/models/member_updated_event.rb', line 38 def channel_type @channel_type end |
#cid ⇒ String
Returns The CID of the channel in which the member was updated.
41 42 43 |
# File 'lib/getstream_ruby/generated/models/member_updated_event.rb', line 41 def cid @cid end |
#created_at ⇒ DateTime
Returns Date/time of creation.
14 15 16 |
# File 'lib/getstream_ruby/generated/models/member_updated_event.rb', line 14 def created_at @created_at end |
#custom ⇒ Object
20 21 22 |
# File 'lib/getstream_ruby/generated/models/member_updated_event.rb', line 20 def custom @custom end |
#member ⇒ ChannelMemberResponse
23 24 25 |
# File 'lib/getstream_ruby/generated/models/member_updated_event.rb', line 23 def member @member end |
#received_at ⇒ DateTime
44 45 46 |
# File 'lib/getstream_ruby/generated/models/member_updated_event.rb', line 44 def received_at @received_at end |
#team ⇒ String
Returns The team ID.
47 48 49 |
# File 'lib/getstream_ruby/generated/models/member_updated_event.rb', line 47 def team @team end |
#type ⇒ String
Returns The type of event: “member.updated” in this case.
26 27 28 |
# File 'lib/getstream_ruby/generated/models/member_updated_event.rb', line 26 def type @type end |
#user ⇒ UserResponseCommonFields
53 54 55 |
# File 'lib/getstream_ruby/generated/models/member_updated_event.rb', line 53 def user @user end |
Class Method Details
.json_field_mappings ⇒ Object
Override field mappings for JSON serialization
75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 |
# File 'lib/getstream_ruby/generated/models/member_updated_event.rb', line 75 def self.json_field_mappings { created_at: 'created_at', channel: 'channel', custom: 'custom', member: 'member', type: 'type', channel_id: 'channel_id', channel_member_count: 'channel_member_count', channel_message_count: 'channel_message_count', channel_type: 'channel_type', cid: 'cid', received_at: 'received_at', team: 'team', channel_custom: 'channel_custom', user: 'user' } end |