Class: GetStream::Generated::Models::MessageFlaggedEvent

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/getstream_ruby/generated/models/message_flagged_event.rb

Overview

This event is sent when a message gets flagged. The event contains information about the message that was flagged.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#==, #inspect, omit_empty_fields, #to_h, #to_json

Constructor Details

#initialize(attributes = {}) ⇒ MessageFlaggedEvent

Initialize with attributes



68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
# File 'lib/getstream_ruby/generated/models/message_flagged_event.rb', line 68

def initialize(attributes = {})
  super(attributes)
  @created_at = attributes[:created_at] || attributes['created_at']
  @message_id = attributes[:message_id] || attributes['message_id']
  @message = attributes[:message] || attributes['message']
  @type = attributes[:type] || attributes['type'] || "message.flagged"
  @channel_id = attributes[:channel_id] || attributes['channel_id'] || nil
  @channel_member_count = attributes[:channel_member_count] || attributes['channel_member_count'] || nil
  @channel_message_count = attributes[:channel_message_count] || attributes['channel_message_count'] || nil
  @channel_type = attributes[:channel_type] || attributes['channel_type'] || nil
  @cid = attributes[:cid] || attributes['cid'] || nil
  @reason = attributes[:reason] || attributes['reason'] || nil
  @received_at = attributes[:received_at] || attributes['received_at'] || nil
  @team = attributes[:team] || attributes['team'] || nil
  @total_flags = attributes[:total_flags] || attributes['total_flags'] || nil
  @channel_custom = attributes[:channel_custom] || attributes['channel_custom'] || nil
  @custom = attributes[:custom] || attributes['custom'] || nil
  @details = attributes[:details] || attributes['details'] || nil
  @flag = attributes[:flag] || attributes['flag'] || nil
  @user = attributes[:user] || attributes['user'] || nil
end

Instance Attribute Details

#channel_customObject

Returns:

  • (Object)


53
54
55
# File 'lib/getstream_ruby/generated/models/message_flagged_event.rb', line 53

def channel_custom
  @channel_custom
end

#channel_idString

Returns The ID of the channel where the message was sent.

Returns:

  • (String)

    The ID of the channel where the message was sent



26
27
28
# File 'lib/getstream_ruby/generated/models/message_flagged_event.rb', line 26

def channel_id
  @channel_id
end

#channel_member_countInteger

Returns The number of members in the channel.

Returns:

  • (Integer)

    The number of members in the channel



29
30
31
# File 'lib/getstream_ruby/generated/models/message_flagged_event.rb', line 29

def channel_member_count
  @channel_member_count
end

#channel_message_countInteger

Returns The number of messages in the channel.

Returns:

  • (Integer)

    The number of messages in the channel



32
33
34
# File 'lib/getstream_ruby/generated/models/message_flagged_event.rb', line 32

def channel_message_count
  @channel_message_count
end

#channel_typeString

Returns The type of the channel where the message was sent.

Returns:

  • (String)

    The type of the channel where the message was sent



35
36
37
# File 'lib/getstream_ruby/generated/models/message_flagged_event.rb', line 35

def channel_type
  @channel_type
end

#cidString

Returns The CID of the channel where the message was sent.

Returns:

  • (String)

    The CID of the channel where the message was sent



38
39
40
# File 'lib/getstream_ruby/generated/models/message_flagged_event.rb', line 38

def cid
  @cid
end

#created_atDateTime

Returns Date/time of creation.

Returns:

  • (DateTime)

    Date/time of creation



14
15
16
# File 'lib/getstream_ruby/generated/models/message_flagged_event.rb', line 14

def created_at
  @created_at
end

#customObject

Returns Custom data.

Returns:

  • (Object)

    Custom data



56
57
58
# File 'lib/getstream_ruby/generated/models/message_flagged_event.rb', line 56

def custom
  @custom
end

#detailsMessageModerationResult



59
60
61
# File 'lib/getstream_ruby/generated/models/message_flagged_event.rb', line 59

def details
  @details
end

#flagFlagResponse

Returns:



62
63
64
# File 'lib/getstream_ruby/generated/models/message_flagged_event.rb', line 62

def flag
  @flag
end

#messageMessageResponse

Returns:



20
21
22
# File 'lib/getstream_ruby/generated/models/message_flagged_event.rb', line 20

def message
  @message
end

#message_idString

Returns:

  • (String)


17
18
19
# File 'lib/getstream_ruby/generated/models/message_flagged_event.rb', line 17

def message_id
  @message_id
end

#reasonString

Returns The reason for the flag.

Returns:

  • (String)

    The reason for the flag



41
42
43
# File 'lib/getstream_ruby/generated/models/message_flagged_event.rb', line 41

def reason
  @reason
end

#received_atDateTime

Returns:

  • (DateTime)


44
45
46
# File 'lib/getstream_ruby/generated/models/message_flagged_event.rb', line 44

def received_at
  @received_at
end

#teamString

Returns The team ID.

Returns:

  • (String)

    The team ID



47
48
49
# File 'lib/getstream_ruby/generated/models/message_flagged_event.rb', line 47

def team
  @team
end

#total_flagsInteger

Returns The total number of flags for the user.

Returns:

  • (Integer)

    The total number of flags for the user



50
51
52
# File 'lib/getstream_ruby/generated/models/message_flagged_event.rb', line 50

def total_flags
  @total_flags
end

#typeString

Returns The type of event: “message.flagged” in this case.

Returns:

  • (String)

    The type of event: “message.flagged” in this case



23
24
25
# File 'lib/getstream_ruby/generated/models/message_flagged_event.rb', line 23

def type
  @type
end

#userUserResponseCommonFields



65
66
67
# File 'lib/getstream_ruby/generated/models/message_flagged_event.rb', line 65

def user
  @user
end

Class Method Details

.json_field_mappingsObject

Override field mappings for JSON serialization



91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
# File 'lib/getstream_ruby/generated/models/message_flagged_event.rb', line 91

def self.json_field_mappings
  {
    created_at: 'created_at',
    message_id: 'message_id',
    message: 'message',
    type: 'type',
    channel_id: 'channel_id',
    channel_member_count: 'channel_member_count',
    channel_message_count: 'channel_message_count',
    channel_type: 'channel_type',
    cid: 'cid',
    reason: 'reason',
    received_at: 'received_at',
    team: 'team',
    total_flags: 'total_flags',
    channel_custom: 'channel_custom',
    custom: 'custom',
    details: 'details',
    flag: 'flag',
    user: 'user'
  }
end