Class: GetStream::Generated::Models::MessagePaginationParams
- Defined in:
- lib/getstream_ruby/generated/models/message_pagination_params.rb
Instance Attribute Summary collapse
-
#created_at_after ⇒ DateTime
The timestamp to get messages with a created_at timestamp greater than.
-
#created_at_after_or_equal ⇒ DateTime
The timestamp to get messages with a created_at timestamp greater than or equal to.
-
#created_at_around ⇒ DateTime
The result will be a set of messages, that are both older and newer than the created_at timestamp provided, distributed evenly around the timestamp.
-
#created_at_before ⇒ DateTime
The timestamp to get messages with a created_at timestamp smaller than.
-
#created_at_before_or_equal ⇒ DateTime
The timestamp to get messages with a created_at timestamp smaller than or equal to.
-
#id_around ⇒ String
The result will be a set of messages, that are both older and newer than the message with the provided ID, and the message with the ID provided will be in the middle of the set.
-
#id_gt ⇒ String
The ID of the message to get messages with a timestamp greater than.
-
#id_gte ⇒ String
The ID of the message to get messages with a timestamp greater than or equal to.
-
#id_lt ⇒ String
The ID of the message to get messages with a timestamp smaller than.
-
#id_lte ⇒ String
The ID of the message to get messages with a timestamp smaller than or equal to.
-
#limit ⇒ Integer
The maximum number of messages to return (max limit.
Class Method Summary collapse
-
.json_field_mappings ⇒ Object
Override field mappings for JSON serialization.
Instance Method Summary collapse
-
#initialize(attributes = {}) ⇒ MessagePaginationParams
constructor
Initialize with attributes.
Methods inherited from BaseModel
#==, #inspect, omit_empty_fields, #to_h, #to_json
Constructor Details
#initialize(attributes = {}) ⇒ MessagePaginationParams
Initialize with attributes
47 48 49 50 51 52 53 54 55 56 57 58 59 60 |
# File 'lib/getstream_ruby/generated/models/message_pagination_params.rb', line 47 def initialize(attributes = {}) super(attributes) @created_at_after = attributes[:created_at_after] || attributes['created_at_after'] || nil @created_at_after_or_equal = attributes[:created_at_after_or_equal] || attributes['created_at_after_or_equal'] || nil @created_at_around = attributes[:created_at_around] || attributes['created_at_around'] || nil @created_at_before = attributes[:created_at_before] || attributes['created_at_before'] || nil @created_at_before_or_equal = attributes[:created_at_before_or_equal] || attributes['created_at_before_or_equal'] || nil @id_around = attributes[:id_around] || attributes['id_around'] || nil @id_gt = attributes[:id_gt] || attributes['id_gt'] || nil @id_gte = attributes[:id_gte] || attributes['id_gte'] || nil @id_lt = attributes[:id_lt] || attributes['id_lt'] || nil @id_lte = attributes[:id_lte] || attributes['id_lte'] || nil @limit = attributes[:limit] || attributes['limit'] || nil end |
Instance Attribute Details
#created_at_after ⇒ DateTime
14 15 16 |
# File 'lib/getstream_ruby/generated/models/message_pagination_params.rb', line 14 def created_at_after @created_at_after end |
#created_at_after_or_equal ⇒ DateTime
17 18 19 |
# File 'lib/getstream_ruby/generated/models/message_pagination_params.rb', line 17 def created_at_after_or_equal @created_at_after_or_equal end |
#created_at_around ⇒ DateTime
20 21 22 |
# File 'lib/getstream_ruby/generated/models/message_pagination_params.rb', line 20 def created_at_around @created_at_around end |
#created_at_before ⇒ DateTime
23 24 25 |
# File 'lib/getstream_ruby/generated/models/message_pagination_params.rb', line 23 def created_at_before @created_at_before end |
#created_at_before_or_equal ⇒ DateTime
26 27 28 |
# File 'lib/getstream_ruby/generated/models/message_pagination_params.rb', line 26 def created_at_before_or_equal @created_at_before_or_equal end |
#id_around ⇒ String
29 30 31 |
# File 'lib/getstream_ruby/generated/models/message_pagination_params.rb', line 29 def id_around @id_around end |
#id_gt ⇒ String
32 33 34 |
# File 'lib/getstream_ruby/generated/models/message_pagination_params.rb', line 32 def id_gt @id_gt end |
#id_gte ⇒ String
35 36 37 |
# File 'lib/getstream_ruby/generated/models/message_pagination_params.rb', line 35 def id_gte @id_gte end |
#id_lt ⇒ String
38 39 40 |
# File 'lib/getstream_ruby/generated/models/message_pagination_params.rb', line 38 def id_lt @id_lt end |
#id_lte ⇒ String
41 42 43 |
# File 'lib/getstream_ruby/generated/models/message_pagination_params.rb', line 41 def id_lte @id_lte end |
#limit ⇒ Integer
44 45 46 |
# File 'lib/getstream_ruby/generated/models/message_pagination_params.rb', line 44 def limit @limit end |
Class Method Details
.json_field_mappings ⇒ Object
Override field mappings for JSON serialization
63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/getstream_ruby/generated/models/message_pagination_params.rb', line 63 def self.json_field_mappings { created_at_after: 'created_at_after', created_at_after_or_equal: 'created_at_after_or_equal', created_at_around: 'created_at_around', created_at_before: 'created_at_before', created_at_before_or_equal: 'created_at_before_or_equal', id_around: 'id_around', id_gt: 'id_gt', id_gte: 'id_gte', id_lt: 'id_lt', id_lte: 'id_lte', limit: 'limit' } end |