Class: GetStream::Generated::Models::NotificationMarkUnreadEvent
- Inherits:
-
BaseModel
- Object
- BaseModel
- GetStream::Generated::Models::NotificationMarkUnreadEvent
- Defined in:
- lib/getstream_ruby/generated/models/notification_mark_unread_event.rb
Overview
Emitted when a channel/thread is marked as unread.
Instance Attribute Summary collapse
- #channel ⇒ ChannelResponse
- #channel_custom ⇒ Object
-
#channel_id ⇒ String
The ID of the channel which was marked as unread.
-
#channel_member_count ⇒ Integer
The number of members in the channel.
- #channel_message_count ⇒ Integer
-
#channel_type ⇒ String
The type of the channel which was marked as unread.
-
#cid ⇒ String
The CID of the channel which was marked as unread.
-
#created_at ⇒ DateTime
Date/time of creation.
- #custom ⇒ Object
-
#first_unread_message_id ⇒ String
The ID of the first unread message.
- #grouped_unread_channels ⇒ Hash<String, Integer>
-
#last_read_at ⇒ DateTime
The time when the channel/thread was marked as unread.
-
#last_read_message_id ⇒ String
The ID of the last read message.
- #received_at ⇒ DateTime
-
#team ⇒ String
The team ID.
-
#thread_id ⇒ String
The ID of the thread which was marked as unread.
-
#total_unread_count ⇒ Integer
The total number of unread messages.
-
#type ⇒ String
The type of event: "notification.mark_unread" in this case.
-
#unread_channels ⇒ Integer
The number of channels with unread messages.
-
#unread_count ⇒ Integer
The total number of unread messages.
-
#unread_messages ⇒ Integer
The number of unread messages in the channel/thread after first_unread_message_id.
-
#unread_thread_messages ⇒ Integer
The total number of unread messages in the threads.
-
#unread_threads ⇒ Integer
The number of unread threads.
- #user ⇒ UserResponseCommonFields
Class Method Summary collapse
-
.json_field_mappings ⇒ Object
Override field mappings for JSON serialization.
Instance Method Summary collapse
-
#initialize(attributes = {}) ⇒ NotificationMarkUnreadEvent
constructor
Initialize with attributes.
Methods inherited from BaseModel
#==, #inspect, omit_empty_fields, #to_h, #to_json
Constructor Details
#initialize(attributes = {}) ⇒ NotificationMarkUnreadEvent
Initialize with attributes
86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 |
# File 'lib/getstream_ruby/generated/models/notification_mark_unread_event.rb', line 86 def initialize(attributes = {}) super(attributes) @created_at = attributes[:created_at] || attributes['created_at'] @custom = attributes[:custom] || attributes['custom'] @type = attributes[:type] || attributes['type'] || "notification.mark_unread" @channel_id = attributes[:channel_id] || attributes['channel_id'] || nil @channel_member_count = attributes[:channel_member_count] || attributes['channel_member_count'] || nil = attributes[:channel_message_count] || attributes['channel_message_count'] || nil @channel_type = attributes[:channel_type] || attributes['channel_type'] || nil @cid = attributes[:cid] || attributes['cid'] || nil = attributes[:first_unread_message_id] || attributes['first_unread_message_id'] || nil @last_read_at = attributes[:last_read_at] || attributes['last_read_at'] || nil = attributes[:last_read_message_id] || attributes['last_read_message_id'] || nil @received_at = attributes[:received_at] || attributes['received_at'] || nil @team = attributes[:team] || attributes['team'] || nil @thread_id = attributes[:thread_id] || attributes['thread_id'] || nil @total_unread_count = attributes[:total_unread_count] || attributes['total_unread_count'] || nil @unread_channels = attributes[:unread_channels] || attributes['unread_channels'] || nil @unread_count = attributes[:unread_count] || attributes['unread_count'] || nil = attributes[:unread_messages] || attributes['unread_messages'] || nil = attributes[:unread_thread_messages] || attributes['unread_thread_messages'] || nil @unread_threads = attributes[:unread_threads] || attributes['unread_threads'] || nil @channel = attributes[:channel] || attributes['channel'] || nil @channel_custom = attributes[:channel_custom] || attributes['channel_custom'] || nil @grouped_unread_channels = attributes[:grouped_unread_channels] || attributes['grouped_unread_channels'] || nil @user = attributes[:user] || attributes['user'] || nil end |
Instance Attribute Details
#channel ⇒ ChannelResponse
74 75 76 |
# File 'lib/getstream_ruby/generated/models/notification_mark_unread_event.rb', line 74 def channel @channel end |
#channel_custom ⇒ Object
77 78 79 |
# File 'lib/getstream_ruby/generated/models/notification_mark_unread_event.rb', line 77 def channel_custom @channel_custom end |
#channel_id ⇒ String
23 24 25 |
# File 'lib/getstream_ruby/generated/models/notification_mark_unread_event.rb', line 23 def channel_id @channel_id end |
#channel_member_count ⇒ Integer
26 27 28 |
# File 'lib/getstream_ruby/generated/models/notification_mark_unread_event.rb', line 26 def channel_member_count @channel_member_count end |
#channel_message_count ⇒ Integer
29 30 31 |
# File 'lib/getstream_ruby/generated/models/notification_mark_unread_event.rb', line 29 def end |
#channel_type ⇒ String
32 33 34 |
# File 'lib/getstream_ruby/generated/models/notification_mark_unread_event.rb', line 32 def channel_type @channel_type end |
#cid ⇒ String
35 36 37 |
# File 'lib/getstream_ruby/generated/models/notification_mark_unread_event.rb', line 35 def cid @cid end |
#created_at ⇒ DateTime
14 15 16 |
# File 'lib/getstream_ruby/generated/models/notification_mark_unread_event.rb', line 14 def created_at @created_at end |
#custom ⇒ Object
17 18 19 |
# File 'lib/getstream_ruby/generated/models/notification_mark_unread_event.rb', line 17 def custom @custom end |
#first_unread_message_id ⇒ String
38 39 40 |
# File 'lib/getstream_ruby/generated/models/notification_mark_unread_event.rb', line 38 def end |
#grouped_unread_channels ⇒ Hash<String, Integer>
80 81 82 |
# File 'lib/getstream_ruby/generated/models/notification_mark_unread_event.rb', line 80 def grouped_unread_channels @grouped_unread_channels end |
#last_read_at ⇒ DateTime
41 42 43 |
# File 'lib/getstream_ruby/generated/models/notification_mark_unread_event.rb', line 41 def last_read_at @last_read_at end |
#last_read_message_id ⇒ String
44 45 46 |
# File 'lib/getstream_ruby/generated/models/notification_mark_unread_event.rb', line 44 def end |
#received_at ⇒ DateTime
47 48 49 |
# File 'lib/getstream_ruby/generated/models/notification_mark_unread_event.rb', line 47 def received_at @received_at end |
#team ⇒ String
50 51 52 |
# File 'lib/getstream_ruby/generated/models/notification_mark_unread_event.rb', line 50 def team @team end |
#thread_id ⇒ String
53 54 55 |
# File 'lib/getstream_ruby/generated/models/notification_mark_unread_event.rb', line 53 def thread_id @thread_id end |
#total_unread_count ⇒ Integer
56 57 58 |
# File 'lib/getstream_ruby/generated/models/notification_mark_unread_event.rb', line 56 def total_unread_count @total_unread_count end |
#type ⇒ String
20 21 22 |
# File 'lib/getstream_ruby/generated/models/notification_mark_unread_event.rb', line 20 def type @type end |
#unread_channels ⇒ Integer
59 60 61 |
# File 'lib/getstream_ruby/generated/models/notification_mark_unread_event.rb', line 59 def unread_channels @unread_channels end |
#unread_count ⇒ Integer
62 63 64 |
# File 'lib/getstream_ruby/generated/models/notification_mark_unread_event.rb', line 62 def unread_count @unread_count end |
#unread_messages ⇒ Integer
65 66 67 |
# File 'lib/getstream_ruby/generated/models/notification_mark_unread_event.rb', line 65 def end |
#unread_thread_messages ⇒ Integer
68 69 70 |
# File 'lib/getstream_ruby/generated/models/notification_mark_unread_event.rb', line 68 def end |
#unread_threads ⇒ Integer
71 72 73 |
# File 'lib/getstream_ruby/generated/models/notification_mark_unread_event.rb', line 71 def unread_threads @unread_threads end |
#user ⇒ UserResponseCommonFields
83 84 85 |
# File 'lib/getstream_ruby/generated/models/notification_mark_unread_event.rb', line 83 def user @user end |
Class Method Details
.json_field_mappings ⇒ Object
Override field mappings for JSON serialization
115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 |
# File 'lib/getstream_ruby/generated/models/notification_mark_unread_event.rb', line 115 def self.json_field_mappings { created_at: 'created_at', custom: 'custom', type: 'type', channel_id: 'channel_id', channel_member_count: 'channel_member_count', channel_message_count: 'channel_message_count', channel_type: 'channel_type', cid: 'cid', first_unread_message_id: 'first_unread_message_id', last_read_at: 'last_read_at', last_read_message_id: 'last_read_message_id', received_at: 'received_at', team: 'team', thread_id: 'thread_id', total_unread_count: 'total_unread_count', unread_channels: 'unread_channels', unread_count: 'unread_count', unread_messages: 'unread_messages', unread_thread_messages: 'unread_thread_messages', unread_threads: 'unread_threads', channel: 'channel', channel_custom: 'channel_custom', grouped_unread_channels: 'grouped_unread_channels', user: 'user' } end |