Class: GetStream::Generated::Models::QueryFutureChannelBansPayload

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/getstream_ruby/generated/models/query_future_channel_bans_payload.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#==, #inspect, omit_empty_fields, #to_h, #to_json

Constructor Details

#initialize(attributes = {}) ⇒ QueryFutureChannelBansPayload

Initialize with attributes



47
48
49
50
51
52
53
54
55
56
57
58
59
60
# File 'lib/getstream_ruby/generated/models/query_future_channel_bans_payload.rb', line 47

def initialize(attributes = {})
  super(attributes)
  @created_at_after = attributes[:created_at_after] || attributes['created_at_after'] || nil
  @created_at_after_or_equal = attributes[:created_at_after_or_equal] || attributes['created_at_after_or_equal'] || nil
  @created_at_before = attributes[:created_at_before] || attributes['created_at_before'] || nil
  @created_at_before_or_equal = attributes[:created_at_before_or_equal] || attributes['created_at_before_or_equal'] || nil
  @exclude_expired_bans = attributes[:exclude_expired_bans] || attributes['exclude_expired_bans'] || nil
  @include_total = attributes[:include_total] || attributes['include_total'] || nil
  @limit = attributes[:limit] || attributes['limit'] || nil
  @offset = attributes[:offset] || attributes['offset'] || nil
  @target_user_id = attributes[:target_user_id] || attributes['target_user_id'] || nil
  @user_id = attributes[:user_id] || attributes['user_id'] || nil
  @user = attributes[:user] || attributes['user'] || nil
end

Instance Attribute Details

#created_at_afterDateTime

Returns:

  • (DateTime)


14
15
16
# File 'lib/getstream_ruby/generated/models/query_future_channel_bans_payload.rb', line 14

def created_at_after
  @created_at_after
end

#created_at_after_or_equalDateTime

Returns:

  • (DateTime)


17
18
19
# File 'lib/getstream_ruby/generated/models/query_future_channel_bans_payload.rb', line 17

def created_at_after_or_equal
  @created_at_after_or_equal
end

#created_at_beforeDateTime

Returns:

  • (DateTime)


20
21
22
# File 'lib/getstream_ruby/generated/models/query_future_channel_bans_payload.rb', line 20

def created_at_before
  @created_at_before
end

#created_at_before_or_equalDateTime

Returns:

  • (DateTime)


23
24
25
# File 'lib/getstream_ruby/generated/models/query_future_channel_bans_payload.rb', line 23

def created_at_before_or_equal
  @created_at_before_or_equal
end

#exclude_expired_bansBoolean

Returns Whether to exclude expired bans or not.

Returns:

  • (Boolean)

    Whether to exclude expired bans or not



26
27
28
# File 'lib/getstream_ruby/generated/models/query_future_channel_bans_payload.rb', line 26

def exclude_expired_bans
  @exclude_expired_bans
end

#include_totalBoolean

Returns When true, the response includes the total number of bans matching the query filter (independent of limit and offset, capped at 100000).

Returns:

  • (Boolean)

    When true, the response includes the total number of bans matching the query filter (independent of limit and offset, capped at 100000)



29
30
31
# File 'lib/getstream_ruby/generated/models/query_future_channel_bans_payload.rb', line 29

def include_total
  @include_total
end

#limitInteger

Returns Number of records to return.

Returns:

  • (Integer)

    Number of records to return



32
33
34
# File 'lib/getstream_ruby/generated/models/query_future_channel_bans_payload.rb', line 32

def limit
  @limit
end

#offsetInteger

Returns Number of records to offset.

Returns:

  • (Integer)

    Number of records to offset



35
36
37
# File 'lib/getstream_ruby/generated/models/query_future_channel_bans_payload.rb', line 35

def offset
  @offset
end

#target_user_idString

Returns Filter by the target user ID. Server-side: returns all bans against this user. Client-side: narrows the authenticated user's own bans to this target.

Returns:

  • (String)

    Filter by the target user ID. Server-side: returns all bans against this user. Client-side: narrows the authenticated user's own bans to this target.



38
39
40
# File 'lib/getstream_ruby/generated/models/query_future_channel_bans_payload.rb', line 38

def target_user_id
  @target_user_id
end

#userUserRequest

Returns User request object.

Returns:



44
45
46
# File 'lib/getstream_ruby/generated/models/query_future_channel_bans_payload.rb', line 44

def user
  @user
end

#user_idString

Returns:

  • (String)


41
42
43
# File 'lib/getstream_ruby/generated/models/query_future_channel_bans_payload.rb', line 41

def user_id
  @user_id
end

Class Method Details

.json_field_mappingsObject

Override field mappings for JSON serialization



63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
# File 'lib/getstream_ruby/generated/models/query_future_channel_bans_payload.rb', line 63

def self.json_field_mappings
  {
    created_at_after: 'created_at_after',
    created_at_after_or_equal: 'created_at_after_or_equal',
    created_at_before: 'created_at_before',
    created_at_before_or_equal: 'created_at_before_or_equal',
    exclude_expired_bans: 'exclude_expired_bans',
    include_total: 'include_total',
    limit: 'limit',
    offset: 'offset',
    target_user_id: 'target_user_id',
    user_id: 'user_id',
    user: 'user'
  }
end