Class: GetStream::Generated::Models::ReactionGroupResponse
- Defined in:
- lib/getstream_ruby/generated/models/reaction_group_response.rb
Overview
ReactionGroupResponse contains all information about a reaction of the same type.
Instance Attribute Summary collapse
-
#count ⇒ Integer
Count is the number of reactions of this type.
-
#first_reaction_at ⇒ DateTime
FirstReactionAt is the time of the first reaction of this type.
-
#last_reaction_at ⇒ DateTime
LastReactionAt is the time of the last reaction of this type.
-
#latest_reactions_by ⇒ Array<ReactionGroupUserResponse>
The most recent users who reacted with this type, ordered by most recent first.
-
#sum_scores ⇒ Integer
SumScores is the sum of all scores of reactions of this type.
Class Method Summary collapse
-
.json_field_mappings ⇒ Object
Override field mappings for JSON serialization.
Instance Method Summary collapse
-
#initialize(attributes = {}) ⇒ ReactionGroupResponse
constructor
Initialize with attributes.
Methods inherited from BaseModel
#==, #inspect, omit_empty_fields, #to_h, #to_json
Constructor Details
#initialize(attributes = {}) ⇒ ReactionGroupResponse
Initialize with attributes
29 30 31 32 33 34 35 36 |
# File 'lib/getstream_ruby/generated/models/reaction_group_response.rb', line 29 def initialize(attributes = {}) super(attributes) @count = attributes[:count] || attributes['count'] @first_reaction_at = attributes[:first_reaction_at] || attributes['first_reaction_at'] @last_reaction_at = attributes[:last_reaction_at] || attributes['last_reaction_at'] @sum_scores = attributes[:sum_scores] || attributes['sum_scores'] @latest_reactions_by = attributes[:latest_reactions_by] || attributes['latest_reactions_by'] end |
Instance Attribute Details
#count ⇒ Integer
14 15 16 |
# File 'lib/getstream_ruby/generated/models/reaction_group_response.rb', line 14 def count @count end |
#first_reaction_at ⇒ DateTime
17 18 19 |
# File 'lib/getstream_ruby/generated/models/reaction_group_response.rb', line 17 def first_reaction_at @first_reaction_at end |
#last_reaction_at ⇒ DateTime
20 21 22 |
# File 'lib/getstream_ruby/generated/models/reaction_group_response.rb', line 20 def last_reaction_at @last_reaction_at end |
#latest_reactions_by ⇒ Array<ReactionGroupUserResponse>
26 27 28 |
# File 'lib/getstream_ruby/generated/models/reaction_group_response.rb', line 26 def latest_reactions_by @latest_reactions_by end |
#sum_scores ⇒ Integer
23 24 25 |
# File 'lib/getstream_ruby/generated/models/reaction_group_response.rb', line 23 def sum_scores @sum_scores end |
Class Method Details
.json_field_mappings ⇒ Object
Override field mappings for JSON serialization
39 40 41 42 43 44 45 46 47 |
# File 'lib/getstream_ruby/generated/models/reaction_group_response.rb', line 39 def self.json_field_mappings { count: 'count', first_reaction_at: 'first_reaction_at', last_reaction_at: 'last_reaction_at', sum_scores: 'sum_scores', latest_reactions_by: 'latest_reactions_by' } end |