Class: GetStream::Generated::Models::ReactionNewEvent

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/getstream_ruby/generated/models/reaction_new_event.rb

Overview

Emitted when a new reaction is added to a message.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#==, #inspect, omit_empty_fields, #to_h, #to_json

Constructor Details

#initialize(attributes = {}) ⇒ ReactionNewEvent

Initialize with attributes



65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
# File 'lib/getstream_ruby/generated/models/reaction_new_event.rb', line 65

def initialize(attributes = {})
  super(attributes)
  @created_at = attributes[:created_at] || attributes['created_at']
  @channel = attributes[:channel] || attributes['channel']
  @custom = attributes[:custom] || attributes['custom']
  @type = attributes[:type] || attributes['type'] || "reaction.new"
  @channel_id = attributes[:channel_id] || attributes['channel_id'] || nil
  @channel_member_count = attributes[:channel_member_count] || attributes['channel_member_count'] || nil
  @channel_message_count = attributes[:channel_message_count] || attributes['channel_message_count'] || nil
  @channel_type = attributes[:channel_type] || attributes['channel_type'] || nil
  @cid = attributes[:cid] || attributes['cid'] || nil
  @message_id = attributes[:message_id] || attributes['message_id'] || nil
  @received_at = attributes[:received_at] || attributes['received_at'] || nil
  @team = attributes[:team] || attributes['team'] || nil
  @thread_participants = attributes[:thread_participants] || attributes['thread_participants'] || nil
  @channel_custom = attributes[:channel_custom] || attributes['channel_custom'] || nil
  @message = attributes[:message] || attributes['message'] || nil
  @reaction = attributes[:reaction] || attributes['reaction'] || nil
  @user = attributes[:user] || attributes['user'] || nil
end

Instance Attribute Details

#channelChannelResponse

Returns:



17
18
19
# File 'lib/getstream_ruby/generated/models/reaction_new_event.rb', line 17

def channel
  @channel
end

#channel_customObject

Returns:

  • (Object)


53
54
55
# File 'lib/getstream_ruby/generated/models/reaction_new_event.rb', line 53

def channel_custom
  @channel_custom
end

#channel_idString

Returns The ID of the channel containing the message.

Returns:

  • (String)

    The ID of the channel containing the message



26
27
28
# File 'lib/getstream_ruby/generated/models/reaction_new_event.rb', line 26

def channel_id
  @channel_id
end

#channel_member_countInteger

Returns The number of members in the channel.

Returns:

  • (Integer)

    The number of members in the channel



29
30
31
# File 'lib/getstream_ruby/generated/models/reaction_new_event.rb', line 29

def channel_member_count
  @channel_member_count
end

#channel_message_countInteger

Returns The number of messages in the channel.

Returns:

  • (Integer)

    The number of messages in the channel



32
33
34
# File 'lib/getstream_ruby/generated/models/reaction_new_event.rb', line 32

def channel_message_count
  @channel_message_count
end

#channel_typeString

Returns The type of the channel containing the message.

Returns:

  • (String)

    The type of the channel containing the message



35
36
37
# File 'lib/getstream_ruby/generated/models/reaction_new_event.rb', line 35

def channel_type
  @channel_type
end

#cidString

Returns The CID of the channel containing the message.

Returns:

  • (String)

    The CID of the channel containing the message



38
39
40
# File 'lib/getstream_ruby/generated/models/reaction_new_event.rb', line 38

def cid
  @cid
end

#created_atDateTime

Returns Date/time of creation.

Returns:

  • (DateTime)

    Date/time of creation



14
15
16
# File 'lib/getstream_ruby/generated/models/reaction_new_event.rb', line 14

def created_at
  @created_at
end

#customObject

Returns:

  • (Object)


20
21
22
# File 'lib/getstream_ruby/generated/models/reaction_new_event.rb', line 20

def custom
  @custom
end

#messageMessageResponse

Returns:



56
57
58
# File 'lib/getstream_ruby/generated/models/reaction_new_event.rb', line 56

def message
  @message
end

#message_idString

Returns:

  • (String)


41
42
43
# File 'lib/getstream_ruby/generated/models/reaction_new_event.rb', line 41

def message_id
  @message_id
end

#reactionReactionResponse

Returns:



59
60
61
# File 'lib/getstream_ruby/generated/models/reaction_new_event.rb', line 59

def reaction
  @reaction
end

#received_atDateTime

Returns:

  • (DateTime)


44
45
46
# File 'lib/getstream_ruby/generated/models/reaction_new_event.rb', line 44

def received_at
  @received_at
end

#teamString

Returns The team ID.

Returns:

  • (String)

    The team ID



47
48
49
# File 'lib/getstream_ruby/generated/models/reaction_new_event.rb', line 47

def team
  @team
end

#thread_participantsArray<UserResponseCommonFields>

Returns The participants of the thread.

Returns:



50
51
52
# File 'lib/getstream_ruby/generated/models/reaction_new_event.rb', line 50

def thread_participants
  @thread_participants
end

#typeString

Returns The type of event: “reaction.new” in this case.

Returns:

  • (String)

    The type of event: “reaction.new” in this case



23
24
25
# File 'lib/getstream_ruby/generated/models/reaction_new_event.rb', line 23

def type
  @type
end

#userUserResponseCommonFields



62
63
64
# File 'lib/getstream_ruby/generated/models/reaction_new_event.rb', line 62

def user
  @user
end

Class Method Details

.json_field_mappingsObject

Override field mappings for JSON serialization



87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
# File 'lib/getstream_ruby/generated/models/reaction_new_event.rb', line 87

def self.json_field_mappings
  {
    created_at: 'created_at',
    channel: 'channel',
    custom: 'custom',
    type: 'type',
    channel_id: 'channel_id',
    channel_member_count: 'channel_member_count',
    channel_message_count: 'channel_message_count',
    channel_type: 'channel_type',
    cid: 'cid',
    message_id: 'message_id',
    received_at: 'received_at',
    team: 'team',
    thread_participants: 'thread_participants',
    channel_custom: 'channel_custom',
    message: 'message',
    reaction: 'reaction',
    user: 'user'
  }
end