Class: GetStream::Generated::Models::SubmitActionRequest
- Defined in:
- lib/getstream_ruby/generated/models/submit_action_request.rb
Instance Attribute Summary collapse
-
#action_type ⇒ String
Type of moderation action to perform.
-
#appeal_id ⇒ String
UUID of the appeal to act on (required for reject_appeal, optional for other actions).
- #ban ⇒ BanActionRequestPayload
- #block ⇒ BlockActionRequestPayload
- #bypass ⇒ BypassActionRequest
- #custom ⇒ CustomActionRequestPayload
- #delete_activity ⇒ DeleteActivityRequestPayload
- #delete_comment ⇒ DeleteCommentRequestPayload
- #delete_message ⇒ DeleteMessageRequestPayload
- #delete_reaction ⇒ DeleteReactionRequestPayload
- #delete_user ⇒ DeleteUserRequestPayload
- #escalate ⇒ EscalatePayload
- #flag ⇒ FlagRequest
-
#item_id ⇒ String
UUID of the review queue item to act on.
- #mark_reviewed ⇒ MarkReviewedRequestPayload
- #reject_appeal ⇒ RejectAppealRequestPayload
- #restore ⇒ RestoreActionRequestPayload
- #shadow_block ⇒ ShadowBlockActionRequestPayload
- #unban ⇒ UnbanActionRequestPayload
- #unblock ⇒ UnblockActionRequestPayload
- #user ⇒ UserRequest
- #user_id ⇒ String
Class Method Summary collapse
-
.json_field_mappings ⇒ Object
Override field mappings for JSON serialization.
Instance Method Summary collapse
-
#initialize(attributes = {}) ⇒ SubmitActionRequest
constructor
Initialize with attributes.
Methods inherited from BaseModel
#==, #inspect, omit_empty_fields, #to_h, #to_json
Constructor Details
#initialize(attributes = {}) ⇒ SubmitActionRequest
Initialize with attributes
80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 |
# File 'lib/getstream_ruby/generated/models/submit_action_request.rb', line 80 def initialize(attributes = {}) super(attributes) @action_type = attributes[:action_type] || attributes['action_type'] @appeal_id = attributes[:appeal_id] || attributes['appeal_id'] || nil @item_id = attributes[:item_id] || attributes['item_id'] || nil @user_id = attributes[:user_id] || attributes['user_id'] || nil @ban = attributes[:ban] || attributes['ban'] || nil @block = attributes[:block] || attributes['block'] || nil @bypass = attributes[:bypass] || attributes['bypass'] || nil @custom = attributes[:custom] || attributes['custom'] || nil @delete_activity = attributes[:delete_activity] || attributes['delete_activity'] || nil @delete_comment = attributes[:delete_comment] || attributes['delete_comment'] || nil @delete_message = attributes[:delete_message] || attributes['delete_message'] || nil @delete_reaction = attributes[:delete_reaction] || attributes['delete_reaction'] || nil @delete_user = attributes[:delete_user] || attributes['delete_user'] || nil @escalate = attributes[:escalate] || attributes['escalate'] || nil @flag = attributes[:flag] || attributes['flag'] || nil @mark_reviewed = attributes[:mark_reviewed] || attributes['mark_reviewed'] || nil @reject_appeal = attributes[:reject_appeal] || attributes['reject_appeal'] || nil @restore = attributes[:restore] || attributes['restore'] || nil @shadow_block = attributes[:shadow_block] || attributes['shadow_block'] || nil @unban = attributes[:unban] || attributes['unban'] || nil @unblock = attributes[:unblock] || attributes['unblock'] || nil @user = attributes[:user] || attributes['user'] || nil end |
Instance Attribute Details
#action_type ⇒ String
Returns Type of moderation action to perform. One of: mark_reviewed, delete_message, delete_activity, delete_comment, delete_reaction, ban, custom, unban, restore, delete_user, unblock, block, shadow_block, unmask, kick_user, end_call, escalate, de_escalate.
14 15 16 |
# File 'lib/getstream_ruby/generated/models/submit_action_request.rb', line 14 def action_type @action_type end |
#appeal_id ⇒ String
Returns UUID of the appeal to act on (required for reject_appeal, optional for other actions).
17 18 19 |
# File 'lib/getstream_ruby/generated/models/submit_action_request.rb', line 17 def appeal_id @appeal_id end |
#ban ⇒ BanActionRequestPayload
26 27 28 |
# File 'lib/getstream_ruby/generated/models/submit_action_request.rb', line 26 def ban @ban end |
#block ⇒ BlockActionRequestPayload
29 30 31 |
# File 'lib/getstream_ruby/generated/models/submit_action_request.rb', line 29 def block @block end |
#bypass ⇒ BypassActionRequest
32 33 34 |
# File 'lib/getstream_ruby/generated/models/submit_action_request.rb', line 32 def bypass @bypass end |
#custom ⇒ CustomActionRequestPayload
35 36 37 |
# File 'lib/getstream_ruby/generated/models/submit_action_request.rb', line 35 def custom @custom end |
#delete_activity ⇒ DeleteActivityRequestPayload
38 39 40 |
# File 'lib/getstream_ruby/generated/models/submit_action_request.rb', line 38 def delete_activity @delete_activity end |
#delete_comment ⇒ DeleteCommentRequestPayload
41 42 43 |
# File 'lib/getstream_ruby/generated/models/submit_action_request.rb', line 41 def delete_comment @delete_comment end |
#delete_message ⇒ DeleteMessageRequestPayload
44 45 46 |
# File 'lib/getstream_ruby/generated/models/submit_action_request.rb', line 44 def @delete_message end |
#delete_reaction ⇒ DeleteReactionRequestPayload
47 48 49 |
# File 'lib/getstream_ruby/generated/models/submit_action_request.rb', line 47 def delete_reaction @delete_reaction end |
#delete_user ⇒ DeleteUserRequestPayload
50 51 52 |
# File 'lib/getstream_ruby/generated/models/submit_action_request.rb', line 50 def delete_user @delete_user end |
#escalate ⇒ EscalatePayload
53 54 55 |
# File 'lib/getstream_ruby/generated/models/submit_action_request.rb', line 53 def escalate @escalate end |
#flag ⇒ FlagRequest
56 57 58 |
# File 'lib/getstream_ruby/generated/models/submit_action_request.rb', line 56 def flag @flag end |
#item_id ⇒ String
Returns UUID of the review queue item to act on.
20 21 22 |
# File 'lib/getstream_ruby/generated/models/submit_action_request.rb', line 20 def item_id @item_id end |
#mark_reviewed ⇒ MarkReviewedRequestPayload
59 60 61 |
# File 'lib/getstream_ruby/generated/models/submit_action_request.rb', line 59 def mark_reviewed @mark_reviewed end |
#reject_appeal ⇒ RejectAppealRequestPayload
62 63 64 |
# File 'lib/getstream_ruby/generated/models/submit_action_request.rb', line 62 def reject_appeal @reject_appeal end |
#restore ⇒ RestoreActionRequestPayload
65 66 67 |
# File 'lib/getstream_ruby/generated/models/submit_action_request.rb', line 65 def restore @restore end |
#shadow_block ⇒ ShadowBlockActionRequestPayload
68 69 70 |
# File 'lib/getstream_ruby/generated/models/submit_action_request.rb', line 68 def shadow_block @shadow_block end |
#unban ⇒ UnbanActionRequestPayload
71 72 73 |
# File 'lib/getstream_ruby/generated/models/submit_action_request.rb', line 71 def unban @unban end |
#unblock ⇒ UnblockActionRequestPayload
74 75 76 |
# File 'lib/getstream_ruby/generated/models/submit_action_request.rb', line 74 def unblock @unblock end |
#user ⇒ UserRequest
77 78 79 |
# File 'lib/getstream_ruby/generated/models/submit_action_request.rb', line 77 def user @user end |
#user_id ⇒ String
23 24 25 |
# File 'lib/getstream_ruby/generated/models/submit_action_request.rb', line 23 def user_id @user_id end |
Class Method Details
.json_field_mappings ⇒ Object
Override field mappings for JSON serialization
107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 |
# File 'lib/getstream_ruby/generated/models/submit_action_request.rb', line 107 def self.json_field_mappings { action_type: 'action_type', appeal_id: 'appeal_id', item_id: 'item_id', user_id: 'user_id', ban: 'ban', block: 'block', bypass: 'bypass', custom: 'custom', delete_activity: 'delete_activity', delete_comment: 'delete_comment', delete_message: 'delete_message', delete_reaction: 'delete_reaction', delete_user: 'delete_user', escalate: 'escalate', flag: 'flag', mark_reviewed: 'mark_reviewed', reject_appeal: 'reject_appeal', restore: 'restore', shadow_block: 'shadow_block', unban: 'unban', unblock: 'unblock', user: 'user' } end |