Class: GetStream::Generated::Models::SubmitActionResponse
- Defined in:
- lib/getstream_ruby/generated/models/submit_action_response.rb
Instance Attribute Summary collapse
- #appeal_item ⇒ AppealItemResponse
-
#auto_restore_warning ⇒ String
Present when the appeal was accepted but the entity could not be restored automatically.
- #duration ⇒ String
- #item ⇒ ReviewQueueItemResponse
Class Method Summary collapse
-
.json_field_mappings ⇒ Object
Override field mappings for JSON serialization.
Instance Method Summary collapse
-
#initialize(attributes = {}) ⇒ SubmitActionResponse
constructor
Initialize with attributes.
Methods inherited from BaseModel
#==, #inspect, omit_empty_fields, #to_h, #to_json
Constructor Details
#initialize(attributes = {}) ⇒ SubmitActionResponse
Initialize with attributes
26 27 28 29 30 31 32 |
# File 'lib/getstream_ruby/generated/models/submit_action_response.rb', line 26 def initialize(attributes = {}) super(attributes) @duration = attributes[:duration] || attributes['duration'] @auto_restore_warning = attributes[:auto_restore_warning] || attributes['auto_restore_warning'] || nil @appeal_item = attributes[:appeal_item] || attributes['appeal_item'] || nil @item = attributes[:item] || attributes['item'] || nil end |
Instance Attribute Details
#appeal_item ⇒ AppealItemResponse
20 21 22 |
# File 'lib/getstream_ruby/generated/models/submit_action_response.rb', line 20 def appeal_item @appeal_item end |
#auto_restore_warning ⇒ String
Returns Present when the appeal was accepted but the entity could not be restored automatically. The moderator should restore it manually.
17 18 19 |
# File 'lib/getstream_ruby/generated/models/submit_action_response.rb', line 17 def auto_restore_warning @auto_restore_warning end |
#duration ⇒ String
14 15 16 |
# File 'lib/getstream_ruby/generated/models/submit_action_response.rb', line 14 def duration @duration end |
#item ⇒ ReviewQueueItemResponse
23 24 25 |
# File 'lib/getstream_ruby/generated/models/submit_action_response.rb', line 23 def item @item end |
Class Method Details
.json_field_mappings ⇒ Object
Override field mappings for JSON serialization
35 36 37 38 39 40 41 42 |
# File 'lib/getstream_ruby/generated/models/submit_action_response.rb', line 35 def self.json_field_mappings { duration: 'duration', auto_restore_warning: 'auto_restore_warning', appeal_item: 'appeal_item', item: 'item' } end |