Class: GetStream::Generated::Models::SubmitModerationFeedbackRequest
- Inherits:
-
BaseModel
- Object
- BaseModel
- GetStream::Generated::Models::SubmitModerationFeedbackRequest
- Defined in:
- lib/getstream_ruby/generated/models/submit_moderation_feedback_request.rb
Instance Attribute Summary collapse
-
#channel_id ⇒ String
Optional moderation channel UUID for context.
-
#current_labels ⇒ Array<String>
Classifications originally produced by the moderation system.
-
#current_recommended_action ⇒ String
Action originally produced by the moderation system.
-
#description ⇒ String
Optional free-form note explaining why the classification was wrong.
-
#expected_labels ⇒ Array<String>
Optional moderator-supplied classifications (up to 16 entries).
-
#expected_recommended_action ⇒ String
Optional moderator-supplied action.
-
#message ⇒ String
The moderated content the moderator is providing feedback on.
-
#published_at ⇒ String
Original publication time of the moderated content (RFC3339).
-
#reference ⇒ String
Provider-side reference identifying the moderated content.
Class Method Summary collapse
-
.json_field_mappings ⇒ Object
Override field mappings for JSON serialization.
Instance Method Summary collapse
-
#initialize(attributes = {}) ⇒ SubmitModerationFeedbackRequest
constructor
Initialize with attributes.
Methods inherited from BaseModel
#==, #inspect, omit_empty_fields, #to_h, #to_json
Constructor Details
#initialize(attributes = {}) ⇒ SubmitModerationFeedbackRequest
Initialize with attributes
41 42 43 44 45 46 47 48 49 50 51 52 |
# File 'lib/getstream_ruby/generated/models/submit_moderation_feedback_request.rb', line 41 def initialize(attributes = {}) super(attributes) @message = attributes[:message] || attributes['message'] @published_at = attributes[:published_at] || attributes['published_at'] @reference = attributes[:reference] || attributes['reference'] @channel_id = attributes[:channel_id] || attributes['channel_id'] || nil @current_recommended_action = attributes[:current_recommended_action] || attributes['current_recommended_action'] || nil @description = attributes[:description] || attributes['description'] || nil @expected_recommended_action = attributes[:expected_recommended_action] || attributes['expected_recommended_action'] || nil @current_labels = attributes[:current_labels] || attributes['current_labels'] || nil @expected_labels = attributes[:expected_labels] || attributes['expected_labels'] || nil end |
Instance Attribute Details
#channel_id ⇒ String
Returns Optional moderation channel UUID for context.
23 24 25 |
# File 'lib/getstream_ruby/generated/models/submit_moderation_feedback_request.rb', line 23 def channel_id @channel_id end |
#current_labels ⇒ Array<String>
Returns Classifications originally produced by the moderation system.
35 36 37 |
# File 'lib/getstream_ruby/generated/models/submit_moderation_feedback_request.rb', line 35 def current_labels @current_labels end |
#current_recommended_action ⇒ String
Returns Action originally produced by the moderation system.
26 27 28 |
# File 'lib/getstream_ruby/generated/models/submit_moderation_feedback_request.rb', line 26 def current_recommended_action @current_recommended_action end |
#description ⇒ String
Returns Optional free-form note explaining why the classification was wrong.
29 30 31 |
# File 'lib/getstream_ruby/generated/models/submit_moderation_feedback_request.rb', line 29 def description @description end |
#expected_labels ⇒ Array<String>
Returns Optional moderator-supplied classifications (up to 16 entries).
38 39 40 |
# File 'lib/getstream_ruby/generated/models/submit_moderation_feedback_request.rb', line 38 def expected_labels @expected_labels end |
#expected_recommended_action ⇒ String
Returns Optional moderator-supplied action.
32 33 34 |
# File 'lib/getstream_ruby/generated/models/submit_moderation_feedback_request.rb', line 32 def expected_recommended_action @expected_recommended_action end |
#message ⇒ String
Returns The moderated content the moderator is providing feedback on.
14 15 16 |
# File 'lib/getstream_ruby/generated/models/submit_moderation_feedback_request.rb', line 14 def @message end |
#published_at ⇒ String
Returns Original publication time of the moderated content (RFC3339).
17 18 19 |
# File 'lib/getstream_ruby/generated/models/submit_moderation_feedback_request.rb', line 17 def published_at @published_at end |
#reference ⇒ String
Returns Provider-side reference identifying the moderated content.
20 21 22 |
# File 'lib/getstream_ruby/generated/models/submit_moderation_feedback_request.rb', line 20 def reference @reference end |
Class Method Details
.json_field_mappings ⇒ Object
Override field mappings for JSON serialization
55 56 57 58 59 60 61 62 63 64 65 66 67 |
# File 'lib/getstream_ruby/generated/models/submit_moderation_feedback_request.rb', line 55 def self.json_field_mappings { message: 'message', published_at: 'published_at', reference: 'reference', channel_id: 'channel_id', current_recommended_action: 'current_recommended_action', description: 'description', expected_recommended_action: 'expected_recommended_action', current_labels: 'current_labels', expected_labels: 'expected_labels' } end |