Class: GetStream::Generated::Models::UnblockedUserEvent

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/getstream_ruby/generated/models/unblocked_user_event.rb

Overview

This event is sent when a user is unblocked on a call,this can be useful to notify the user that they can now join the call again

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#==, #inspect, omit_empty_fields, #to_h, #to_json

Constructor Details

#initialize(attributes = {}) ⇒ UnblockedUserEvent

Initialize with attributes



26
27
28
29
30
31
32
# File 'lib/getstream_ruby/generated/models/unblocked_user_event.rb', line 26

def initialize(attributes = {})
  super(attributes)
  @call_cid = attributes[:call_cid] || attributes['call_cid']
  @created_at = attributes[:created_at] || attributes['created_at']
  @user = attributes[:user] || attributes['user']
  @type = attributes[:type] || attributes['type'] || "call.unblocked_user"
end

Instance Attribute Details

#call_cid ⇒ String

Returns:

  • (String)


14
15
16
# File 'lib/getstream_ruby/generated/models/unblocked_user_event.rb', line 14

def call_cid
  @call_cid
end

#created_at ⇒ DateTime

Returns:

  • (DateTime)


17
18
19
# File 'lib/getstream_ruby/generated/models/unblocked_user_event.rb', line 17

def created_at
  @created_at
end

#type ⇒ String

Returns The type of event: "call.unblocked_user" in this case.

Returns:

  • (String) —

    The type of event: "call.unblocked_user" in this case



23
24
25
# File 'lib/getstream_ruby/generated/models/unblocked_user_event.rb', line 23

def type
  @type
end

#user ⇒ UserResponse

Returns:



20
21
22
# File 'lib/getstream_ruby/generated/models/unblocked_user_event.rb', line 20

def user
  @user
end

Class Method Details

.json_field_mappings ⇒ Object

Override field mappings for JSON serialization



35
36
37
38
39
40
41
42
# File 'lib/getstream_ruby/generated/models/unblocked_user_event.rb', line 35

def self.json_field_mappings
  {
    call_cid: 'call_cid',
    created_at: 'created_at',
    user: 'user',
    type: 'type'
  }
end