Class: GetStream::Generated::Models::UpdateActivityPartialChangeRequest

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/getstream_ruby/generated/models/update_activity_partial_change_request.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#==, #inspect, omit_empty_fields, #to_h, #to_json

Constructor Details

#initialize(attributes = {}) ⇒ UpdateActivityPartialChangeRequest

Initialize with attributes



30
31
32
33
34
35
36
37
# File 'lib/getstream_ruby/generated/models/update_activity_partial_change_request.rb', line 30

def initialize(attributes = {})
  super(attributes)
  @activity_id = attributes[:activity_id] || attributes['activity_id']
  @copy_custom_to_notification = attributes[:copy_custom_to_notification] || attributes['copy_custom_to_notification'] || nil
  @handle_mention_notifications = attributes[:handle_mention_notifications] || attributes['handle_mention_notifications'] || nil
  @unset = attributes[:unset] || attributes['unset'] || nil
  @set = attributes[:set] || attributes['set'] || nil
end

Instance Attribute Details

#activity_idString

Returns ID of the activity to update.

Returns:

  • (String)

    ID of the activity to update



14
15
16
# File 'lib/getstream_ruby/generated/models/update_activity_partial_change_request.rb', line 14

def activity_id
  @activity_id
end

#copy_custom_to_notificationObject

Deprecated.

This field is deprecated. @return [Boolean] Whether to copy custom data to the notification activity (only applies when handle_mention_notifications creates notifications) Deprecated: use notification_context.trigger.custom and notification_context.target.custom instead



18
19
20
# File 'lib/getstream_ruby/generated/models/update_activity_partial_change_request.rb', line 18

def copy_custom_to_notification
  @copy_custom_to_notification
end

#handle_mention_notificationsBoolean

Returns When true and ‘mentioned_user_ids’ is updated, automatically creates or deletes mention notifications for added/removed users. Only applicable for client-side requests (ignored for server-side requests).

Returns:

  • (Boolean)

    When true and ‘mentioned_user_ids’ is updated, automatically creates or deletes mention notifications for added/removed users. Only applicable for client-side requests (ignored for server-side requests)



21
22
23
# File 'lib/getstream_ruby/generated/models/update_activity_partial_change_request.rb', line 21

def handle_mention_notifications
  @handle_mention_notifications
end

#setObject

Returns Map of field names to new values. Supported fields: ‘text’, ‘attachments’, ‘custom’, ‘visibility’, ‘visibility_tag’, ‘restrict_replies’ (values: ‘everyone’, ‘people_i_follow’, ‘nobody’), ‘location’, ‘expires_at’, ‘filter_tags’, ‘interest_tags’, ‘poll_id’, ‘feeds’, ‘mentioned_user_ids’. For custom fields, use dot-notation (e.g., ‘custom.field_name’).

Returns:

  • (Object)

    Map of field names to new values. Supported fields: ‘text’, ‘attachments’, ‘custom’, ‘visibility’, ‘visibility_tag’, ‘restrict_replies’ (values: ‘everyone’, ‘people_i_follow’, ‘nobody’), ‘location’, ‘expires_at’, ‘filter_tags’, ‘interest_tags’, ‘poll_id’, ‘feeds’, ‘mentioned_user_ids’. For custom fields, use dot-notation (e.g., ‘custom.field_name’)



27
28
29
# File 'lib/getstream_ruby/generated/models/update_activity_partial_change_request.rb', line 27

def set
  @set
end

#unsetArray<String>

Returns List of field names to remove. Supported fields: ‘custom’, ‘location’, ‘expires_at’, ‘filter_tags’, ‘interest_tags’, ‘attachments’, ‘poll_id’, ‘mentioned_user_ids’. Use dot-notation for nested custom fields (e.g., ‘custom.field_name’).

Returns:

  • (Array<String>)

    List of field names to remove. Supported fields: ‘custom’, ‘location’, ‘expires_at’, ‘filter_tags’, ‘interest_tags’, ‘attachments’, ‘poll_id’, ‘mentioned_user_ids’. Use dot-notation for nested custom fields (e.g., ‘custom.field_name’)



24
25
26
# File 'lib/getstream_ruby/generated/models/update_activity_partial_change_request.rb', line 24

def unset
  @unset
end

Class Method Details

.json_field_mappingsObject

Override field mappings for JSON serialization



40
41
42
43
44
45
46
47
48
# File 'lib/getstream_ruby/generated/models/update_activity_partial_change_request.rb', line 40

def self.json_field_mappings
  {
    activity_id: 'activity_id',
    copy_custom_to_notification: 'copy_custom_to_notification',
    handle_mention_notifications: 'handle_mention_notifications',
    unset: 'unset',
    set: 'set'
  }
end