Class: GetStream::Generated::Models::UpdateActivityPartialRequest

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/getstream_ruby/generated/models/update_activity_partial_request.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#==, #inspect, omit_empty_fields, #to_h, #to_json

Constructor Details

#initialize(attributes = {}) ⇒ UpdateActivityPartialRequest

Initialize with attributes



38
39
40
41
42
43
44
45
46
47
48
# File 'lib/getstream_ruby/generated/models/update_activity_partial_request.rb', line 38

def initialize(attributes = {})
  super(attributes)
  @copy_custom_to_notification = attributes[:copy_custom_to_notification] || attributes['copy_custom_to_notification'] || nil
  @enrich_own_fields = attributes[:enrich_own_fields] || attributes['enrich_own_fields'] || nil
  @handle_mention_notifications = attributes[:handle_mention_notifications] || attributes['handle_mention_notifications'] || nil
  @run_activity_processors = attributes[:run_activity_processors] || attributes['run_activity_processors'] || nil
  @user_id = attributes[:user_id] || attributes['user_id'] || nil
  @unset = attributes[:unset] || attributes['unset'] || nil
  @set = attributes[:set] || attributes['set'] || nil
  @user = attributes[:user] || attributes['user'] || nil
end

Instance Attribute Details

#copy_custom_to_notificationBoolean

Returns Whether to copy custom data to the notification activity (only applies when handle_mention_notifications creates notifications).

Returns:

  • (Boolean)

    Whether to copy custom data to the notification activity (only applies when handle_mention_notifications creates notifications)



14
15
16
# File 'lib/getstream_ruby/generated/models/update_activity_partial_request.rb', line 14

def copy_custom_to_notification
  @copy_custom_to_notification
end

#enrich_own_fieldsBoolean

Returns If true, enriches the activity’s current_feed with own_* fields (own_follows, own_followings, own_capabilities, own_membership). Defaults to false for performance.

Returns:

  • (Boolean)

    If true, enriches the activity’s current_feed with own_* fields (own_follows, own_followings, own_capabilities, own_membership). Defaults to false for performance.



17
18
19
# File 'lib/getstream_ruby/generated/models/update_activity_partial_request.rb', line 17

def enrich_own_fields
  @enrich_own_fields
end

#handle_mention_notificationsBoolean

Returns If true, creates notification activities for newly mentioned users and deletes notifications for users no longer mentioned.

Returns:

  • (Boolean)

    If true, creates notification activities for newly mentioned users and deletes notifications for users no longer mentioned



20
21
22
# File 'lib/getstream_ruby/generated/models/update_activity_partial_request.rb', line 20

def handle_mention_notifications
  @handle_mention_notifications
end

#run_activity_processorsBoolean

Returns If true, runs activity processors on the updated activity. Processors will only run if the activity text and/or attachments are changed. Defaults to false.

Returns:

  • (Boolean)

    If true, runs activity processors on the updated activity. Processors will only run if the activity text and/or attachments are changed. Defaults to false.



23
24
25
# File 'lib/getstream_ruby/generated/models/update_activity_partial_request.rb', line 23

def run_activity_processors
  @run_activity_processors
end

#setObject

Returns Map of field names to new values. Supported fields: ‘text’, ‘attachments’, ‘custom’, ‘visibility’, ‘visibility_tag’, ‘restrict_replies’ (values: ‘everyone’, ‘people_i_follow’, ‘nobody’), ‘location’, ‘expires_at’, ‘filter_tags’, ‘interest_tags’, ‘poll_id’, ‘feeds’, ‘mentioned_user_ids’, ‘search_data’. For custom fields, use dot-notation (e.g., ‘custom.field_name’).

Returns:

  • (Object)

    Map of field names to new values. Supported fields: ‘text’, ‘attachments’, ‘custom’, ‘visibility’, ‘visibility_tag’, ‘restrict_replies’ (values: ‘everyone’, ‘people_i_follow’, ‘nobody’), ‘location’, ‘expires_at’, ‘filter_tags’, ‘interest_tags’, ‘poll_id’, ‘feeds’, ‘mentioned_user_ids’, ‘search_data’. For custom fields, use dot-notation (e.g., ‘custom.field_name’)



32
33
34
# File 'lib/getstream_ruby/generated/models/update_activity_partial_request.rb', line 32

def set
  @set
end

#unsetArray<String>

Returns List of field names to remove. Supported fields: ‘custom’, ‘visibility_tag’, ‘location’, ‘expires_at’, ‘filter_tags’, ‘interest_tags’, ‘attachments’, ‘poll_id’, ‘mentioned_user_ids’, ‘search_data’. Use dot-notation for nested custom fields (e.g., ‘custom.field_name’).

Returns:

  • (Array<String>)

    List of field names to remove. Supported fields: ‘custom’, ‘visibility_tag’, ‘location’, ‘expires_at’, ‘filter_tags’, ‘interest_tags’, ‘attachments’, ‘poll_id’, ‘mentioned_user_ids’, ‘search_data’. Use dot-notation for nested custom fields (e.g., ‘custom.field_name’)



29
30
31
# File 'lib/getstream_ruby/generated/models/update_activity_partial_request.rb', line 29

def unset
  @unset
end

#userUserRequest

Returns:



35
36
37
# File 'lib/getstream_ruby/generated/models/update_activity_partial_request.rb', line 35

def user
  @user
end

#user_idString

Returns:

  • (String)


26
27
28
# File 'lib/getstream_ruby/generated/models/update_activity_partial_request.rb', line 26

def user_id
  @user_id
end

Class Method Details

.json_field_mappingsObject

Override field mappings for JSON serialization



51
52
53
54
55
56
57
58
59
60
61
62
# File 'lib/getstream_ruby/generated/models/update_activity_partial_request.rb', line 51

def self.json_field_mappings
  {
    copy_custom_to_notification: 'copy_custom_to_notification',
    enrich_own_fields: 'enrich_own_fields',
    handle_mention_notifications: 'handle_mention_notifications',
    run_activity_processors: 'run_activity_processors',
    user_id: 'user_id',
    unset: 'unset',
    set: 'set',
    user: 'user'
  }
end