Class: GetStream::Generated::Models::UpdateFeedRequest

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/getstream_ruby/generated/models/update_feed_request.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#==, #inspect, omit_empty_fields, #to_h, #to_json

Constructor Details

#initialize(attributes = {}) ⇒ UpdateFeedRequest

Initialize with attributes



38
39
40
41
42
43
44
45
46
47
48
# File 'lib/getstream_ruby/generated/models/update_feed_request.rb', line 38

def initialize(attributes = {})
  super(attributes)
  @clear_location = attributes[:clear_location] || attributes['clear_location'] || nil
  @created_by_id = attributes[:created_by_id] || attributes['created_by_id'] || nil
  @description = attributes[:description] || attributes['description'] || nil
  @enrich_own_fields = attributes[:enrich_own_fields] || attributes['enrich_own_fields'] || nil
  @name = attributes[:name] || attributes['name'] || nil
  @filter_tags = attributes[:filter_tags] || attributes['filter_tags'] || nil
  @custom = attributes[:custom] || attributes['custom'] || nil
  @location = attributes[:location] || attributes['location'] || nil
end

Instance Attribute Details

#clear_locationBoolean

Returns If true, removes the geographic location from the feed.

Returns:

  • (Boolean)

    If true, removes the geographic location from the feed



14
15
16
# File 'lib/getstream_ruby/generated/models/update_feed_request.rb', line 14

def clear_location
  @clear_location
end

#created_by_idString

Returns ID of the new feed creator (owner).

Returns:

  • (String)

    ID of the new feed creator (owner)



17
18
19
# File 'lib/getstream_ruby/generated/models/update_feed_request.rb', line 17

def created_by_id
  @created_by_id
end

#customObject

Returns Custom data for the feed.

Returns:

  • (Object)

    Custom data for the feed



32
33
34
# File 'lib/getstream_ruby/generated/models/update_feed_request.rb', line 32

def custom
  @custom
end

#descriptionString

Returns Description of the feed.

Returns:

  • (String)

    Description of the feed



20
21
22
# File 'lib/getstream_ruby/generated/models/update_feed_request.rb', line 20

def description
  @description
end

#enrich_own_fieldsBoolean

Returns If true, enriches the feed with own_* fields (own_follows, own_followings, own_capabilities, own_membership). Defaults to false for performance.

Returns:

  • (Boolean)

    If true, enriches the feed with own_* fields (own_follows, own_followings, own_capabilities, own_membership). Defaults to false for performance.



23
24
25
# File 'lib/getstream_ruby/generated/models/update_feed_request.rb', line 23

def enrich_own_fields
  @enrich_own_fields
end

#filter_tagsArray<String>

Returns Tags used for filtering feeds.

Returns:

  • (Array<String>)

    Tags used for filtering feeds



29
30
31
# File 'lib/getstream_ruby/generated/models/update_feed_request.rb', line 29

def filter_tags
  @filter_tags
end

#locationLocation

Returns:



35
36
37
# File 'lib/getstream_ruby/generated/models/update_feed_request.rb', line 35

def location
  @location
end

#nameString

Returns Name of the feed.

Returns:

  • (String)

    Name of the feed



26
27
28
# File 'lib/getstream_ruby/generated/models/update_feed_request.rb', line 26

def name
  @name
end

Class Method Details

.json_field_mappingsObject

Override field mappings for JSON serialization



51
52
53
54
55
56
57
58
59
60
61
62
# File 'lib/getstream_ruby/generated/models/update_feed_request.rb', line 51

def self.json_field_mappings
  {
    clear_location: 'clear_location',
    created_by_id: 'created_by_id',
    description: 'description',
    enrich_own_fields: 'enrich_own_fields',
    name: 'name',
    filter_tags: 'filter_tags',
    custom: 'custom',
    location: 'location'
  }
end