Class: GetStream::Generated::Models::UpdateUsersResponse
- Defined in:
- lib/getstream_ruby/generated/models/update_users_response.rb
Instance Attribute Summary collapse
-
#duration ⇒ String
Duration of the request in milliseconds.
-
#membership_deletion_task_id ⇒ Object
deprecated
Deprecated.
This field is deprecated. @return [String] Deprecated: always empty. Removing a user from a team no longer deletes their memberships in that team's channels, so there is no task to poll
-
#users ⇒ Hash<String, FullUserResponse>
Object containing users.
Class Method Summary collapse
-
.json_field_mappings ⇒ Object
Override field mappings for JSON serialization.
Instance Method Summary collapse
-
#initialize(attributes = {}) ⇒ UpdateUsersResponse
constructor
Initialize with attributes.
Methods inherited from BaseModel
#==, #inspect, omit_empty_fields, #to_h, #to_json
Constructor Details
#initialize(attributes = {}) ⇒ UpdateUsersResponse
Initialize with attributes
24 25 26 27 28 29 |
# File 'lib/getstream_ruby/generated/models/update_users_response.rb', line 24 def initialize(attributes = {}) super(attributes) @duration = attributes[:duration] || attributes['duration'] @membership_deletion_task_id = attributes[:membership_deletion_task_id] || attributes['membership_deletion_task_id'] @users = attributes[:users] || attributes['users'] end |
Instance Attribute Details
#duration ⇒ String
Returns Duration of the request in milliseconds.
14 15 16 |
# File 'lib/getstream_ruby/generated/models/update_users_response.rb', line 14 def duration @duration end |
#membership_deletion_task_id ⇒ Object
Deprecated.
This field is deprecated. @return [String] Deprecated: always empty. Removing a user from a team no longer deletes their memberships in that team's channels, so there is no task to poll
18 19 20 |
# File 'lib/getstream_ruby/generated/models/update_users_response.rb', line 18 def membership_deletion_task_id @membership_deletion_task_id end |
#users ⇒ Hash<String, FullUserResponse>
Returns Object containing users.
21 22 23 |
# File 'lib/getstream_ruby/generated/models/update_users_response.rb', line 21 def users @users end |
Class Method Details
.json_field_mappings ⇒ Object
Override field mappings for JSON serialization
32 33 34 35 36 37 38 |
# File 'lib/getstream_ruby/generated/models/update_users_response.rb', line 32 def self.json_field_mappings { duration: 'duration', membership_deletion_task_id: 'membership_deletion_task_id', users: 'users' } end |