Class: GetStream::Generated::Models::UserBannedEvent

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/getstream_ruby/generated/models/user_banned_event.rb

Overview

This event is sent when a user gets banned. The event contains information about the user that was banned.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#==, #inspect, omit_empty_fields, #to_h, #to_json

Constructor Details

#initialize(attributes = {}) ⇒ UserBannedEvent

Initialize with attributes



65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
# File 'lib/getstream_ruby/generated/models/user_banned_event.rb', line 65

def initialize(attributes = {})
  super(attributes)
  @created_at = attributes[:created_at] || attributes['created_at']
  @custom = attributes[:custom] || attributes['custom']
  @user = attributes[:user] || attributes['user']
  @type = attributes[:type] || attributes['type'] || "user.banned"
  @channel_id = attributes[:channel_id] || attributes['channel_id'] || nil
  @channel_member_count = attributes[:channel_member_count] || attributes['channel_member_count'] || nil
  @channel_message_count = attributes[:channel_message_count] || attributes['channel_message_count'] || nil
  @channel_type = attributes[:channel_type] || attributes['channel_type'] || nil
  @cid = attributes[:cid] || attributes['cid'] || nil
  @expiration = attributes[:expiration] || attributes['expiration'] || nil
  @reason = attributes[:reason] || attributes['reason'] || nil
  @received_at = attributes[:received_at] || attributes['received_at'] || nil
  @shadow = attributes[:shadow] || attributes['shadow'] || nil
  @team = attributes[:team] || attributes['team'] || nil
  @total_bans = attributes[:total_bans] || attributes['total_bans'] || nil
  @channel_custom = attributes[:channel_custom] || attributes['channel_custom'] || nil
  @created_by = attributes[:created_by] || attributes['created_by'] || nil
end

Instance Attribute Details

#channel_customObject

Returns:

  • (Object)


59
60
61
# File 'lib/getstream_ruby/generated/models/user_banned_event.rb', line 59

def channel_custom
  @channel_custom
end

#channel_idString

Returns The ID of the channel where the target user was banned.

Returns:

  • (String)

    The ID of the channel where the target user was banned



26
27
28
# File 'lib/getstream_ruby/generated/models/user_banned_event.rb', line 26

def channel_id
  @channel_id
end

#channel_member_countInteger

Returns:

  • (Integer)


29
30
31
# File 'lib/getstream_ruby/generated/models/user_banned_event.rb', line 29

def channel_member_count
  @channel_member_count
end

#channel_message_countInteger

Returns:

  • (Integer)


32
33
34
# File 'lib/getstream_ruby/generated/models/user_banned_event.rb', line 32

def channel_message_count
  @channel_message_count
end

#channel_typeString

Returns The type of the channel where the target user was banned.

Returns:

  • (String)

    The type of the channel where the target user was banned



35
36
37
# File 'lib/getstream_ruby/generated/models/user_banned_event.rb', line 35

def channel_type
  @channel_type
end

#cidString

Returns The CID of the channel where the target user was banned.

Returns:

  • (String)

    The CID of the channel where the target user was banned



38
39
40
# File 'lib/getstream_ruby/generated/models/user_banned_event.rb', line 38

def cid
  @cid
end

#created_atDateTime

Returns Date/time of creation.

Returns:

  • (DateTime)

    Date/time of creation



14
15
16
# File 'lib/getstream_ruby/generated/models/user_banned_event.rb', line 14

def created_at
  @created_at
end

#created_byUserResponseCommonFields



62
63
64
# File 'lib/getstream_ruby/generated/models/user_banned_event.rb', line 62

def created_by
  @created_by
end

#customObject

Returns:

  • (Object)


17
18
19
# File 'lib/getstream_ruby/generated/models/user_banned_event.rb', line 17

def custom
  @custom
end

#expirationDateTime

Returns The expiration date of the ban.

Returns:

  • (DateTime)

    The expiration date of the ban



41
42
43
# File 'lib/getstream_ruby/generated/models/user_banned_event.rb', line 41

def expiration
  @expiration
end

#reasonString

Returns The reason for the ban.

Returns:

  • (String)

    The reason for the ban



44
45
46
# File 'lib/getstream_ruby/generated/models/user_banned_event.rb', line 44

def reason
  @reason
end

#received_atDateTime

Returns:

  • (DateTime)


47
48
49
# File 'lib/getstream_ruby/generated/models/user_banned_event.rb', line 47

def received_at
  @received_at
end

#shadowBoolean

Returns Whether the user was shadow banned.

Returns:

  • (Boolean)

    Whether the user was shadow banned



50
51
52
# File 'lib/getstream_ruby/generated/models/user_banned_event.rb', line 50

def shadow
  @shadow
end

#teamString

Returns The team of the channel where the target user was banned.

Returns:

  • (String)

    The team of the channel where the target user was banned



53
54
55
# File 'lib/getstream_ruby/generated/models/user_banned_event.rb', line 53

def team
  @team
end

#total_bansInteger

Returns:

  • (Integer)


56
57
58
# File 'lib/getstream_ruby/generated/models/user_banned_event.rb', line 56

def total_bans
  @total_bans
end

#typeString

Returns The type of event: “user.banned” in this case.

Returns:

  • (String)

    The type of event: “user.banned” in this case



23
24
25
# File 'lib/getstream_ruby/generated/models/user_banned_event.rb', line 23

def type
  @type
end

#userUserResponseCommonFields



20
21
22
# File 'lib/getstream_ruby/generated/models/user_banned_event.rb', line 20

def user
  @user
end

Class Method Details

.json_field_mappingsObject

Override field mappings for JSON serialization



87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
# File 'lib/getstream_ruby/generated/models/user_banned_event.rb', line 87

def self.json_field_mappings
  {
    created_at: 'created_at',
    custom: 'custom',
    user: 'user',
    type: 'type',
    channel_id: 'channel_id',
    channel_member_count: 'channel_member_count',
    channel_message_count: 'channel_message_count',
    channel_type: 'channel_type',
    cid: 'cid',
    expiration: 'expiration',
    reason: 'reason',
    received_at: 'received_at',
    shadow: 'shadow',
    team: 'team',
    total_bans: 'total_bans',
    channel_custom: 'channel_custom',
    created_by: 'created_by'
  }
end