Class: GetStream::Generated::Models::UserDeactivatedEvent
- Defined in:
- lib/getstream_ruby/generated/models/user_deactivated_event.rb
Overview
This event is sent when a user gets deactivated. The event contains information about the user that was deactivated.
Instance Attribute Summary collapse
-
#created_at ⇒ DateTime
Date/time of creation.
- #created_by ⇒ UserResponseCommonFields
- #custom ⇒ Object
- #received_at ⇒ DateTime
-
#type ⇒ String
The type of event: “user.deactivated” in this case.
- #user ⇒ UserResponseCommonFields
Class Method Summary collapse
-
.json_field_mappings ⇒ Object
Override field mappings for JSON serialization.
Instance Method Summary collapse
-
#initialize(attributes = {}) ⇒ UserDeactivatedEvent
constructor
Initialize with attributes.
Methods inherited from BaseModel
#==, #inspect, omit_empty_fields, #to_h, #to_json
Constructor Details
#initialize(attributes = {}) ⇒ UserDeactivatedEvent
Initialize with attributes
32 33 34 35 36 37 38 39 40 |
# File 'lib/getstream_ruby/generated/models/user_deactivated_event.rb', line 32 def initialize(attributes = {}) super(attributes) @created_at = attributes[:created_at] || attributes['created_at'] @custom = attributes[:custom] || attributes['custom'] @user = attributes[:user] || attributes['user'] @type = attributes[:type] || attributes['type'] || "user.deactivated" @received_at = attributes[:received_at] || attributes['received_at'] || nil @created_by = attributes[:created_by] || attributes['created_by'] || nil end |
Instance Attribute Details
#created_at ⇒ DateTime
Returns Date/time of creation.
14 15 16 |
# File 'lib/getstream_ruby/generated/models/user_deactivated_event.rb', line 14 def created_at @created_at end |
#created_by ⇒ UserResponseCommonFields
29 30 31 |
# File 'lib/getstream_ruby/generated/models/user_deactivated_event.rb', line 29 def created_by @created_by end |
#custom ⇒ Object
17 18 19 |
# File 'lib/getstream_ruby/generated/models/user_deactivated_event.rb', line 17 def custom @custom end |
#received_at ⇒ DateTime
26 27 28 |
# File 'lib/getstream_ruby/generated/models/user_deactivated_event.rb', line 26 def received_at @received_at end |
#type ⇒ String
Returns The type of event: “user.deactivated” in this case.
23 24 25 |
# File 'lib/getstream_ruby/generated/models/user_deactivated_event.rb', line 23 def type @type end |
#user ⇒ UserResponseCommonFields
20 21 22 |
# File 'lib/getstream_ruby/generated/models/user_deactivated_event.rb', line 20 def user @user end |
Class Method Details
.json_field_mappings ⇒ Object
Override field mappings for JSON serialization
43 44 45 46 47 48 49 50 51 52 |
# File 'lib/getstream_ruby/generated/models/user_deactivated_event.rb', line 43 def self.json_field_mappings { created_at: 'created_at', custom: 'custom', user: 'user', type: 'type', received_at: 'received_at', created_by: 'created_by' } end |