Class: GetStream::Generated::Models::UserFlaggedEvent
- Defined in:
- lib/getstream_ruby/generated/models/user_flagged_event.rb
Overview
This event is sent when a user gets flagged. The event contains information about the user that was flagged.
Instance Attribute Summary collapse
-
#created_at ⇒ DateTime
Date/time of creation.
-
#custom ⇒ Object
Custom data.
-
#reason ⇒ String
The reason for the flag.
- #received_at ⇒ DateTime
- #target_user ⇒ UserResponseCommonFields
-
#total_flags ⇒ Integer
The total number of flags for the user.
-
#type ⇒ String
The type of event: “user.flagged” in this case.
- #user ⇒ UserResponseCommonFields
Class Method Summary collapse
-
.json_field_mappings ⇒ Object
Override field mappings for JSON serialization.
Instance Method Summary collapse
-
#initialize(attributes = {}) ⇒ UserFlaggedEvent
constructor
Initialize with attributes.
Methods inherited from BaseModel
#==, #inspect, omit_empty_fields, #to_h, #to_json
Constructor Details
#initialize(attributes = {}) ⇒ UserFlaggedEvent
Initialize with attributes
38 39 40 41 42 43 44 45 46 47 48 |
# File 'lib/getstream_ruby/generated/models/user_flagged_event.rb', line 38 def initialize(attributes = {}) super(attributes) @created_at = attributes[:created_at] || attributes['created_at'] @reason = attributes[:reason] || attributes['reason'] @total_flags = attributes[:total_flags] || attributes['total_flags'] @user = attributes[:user] || attributes['user'] @type = attributes[:type] || attributes['type'] || "user.flagged" @received_at = attributes[:received_at] || attributes['received_at'] || nil @custom = attributes[:custom] || attributes['custom'] || nil @target_user = attributes[:target_user] || attributes['target_user'] || nil end |
Instance Attribute Details
#created_at ⇒ DateTime
Returns Date/time of creation.
14 15 16 |
# File 'lib/getstream_ruby/generated/models/user_flagged_event.rb', line 14 def created_at @created_at end |
#custom ⇒ Object
Returns Custom data.
32 33 34 |
# File 'lib/getstream_ruby/generated/models/user_flagged_event.rb', line 32 def custom @custom end |
#reason ⇒ String
Returns The reason for the flag.
17 18 19 |
# File 'lib/getstream_ruby/generated/models/user_flagged_event.rb', line 17 def reason @reason end |
#received_at ⇒ DateTime
29 30 31 |
# File 'lib/getstream_ruby/generated/models/user_flagged_event.rb', line 29 def received_at @received_at end |
#target_user ⇒ UserResponseCommonFields
35 36 37 |
# File 'lib/getstream_ruby/generated/models/user_flagged_event.rb', line 35 def target_user @target_user end |
#total_flags ⇒ Integer
Returns The total number of flags for the user.
20 21 22 |
# File 'lib/getstream_ruby/generated/models/user_flagged_event.rb', line 20 def total_flags @total_flags end |
#type ⇒ String
Returns The type of event: “user.flagged” in this case.
26 27 28 |
# File 'lib/getstream_ruby/generated/models/user_flagged_event.rb', line 26 def type @type end |
#user ⇒ UserResponseCommonFields
23 24 25 |
# File 'lib/getstream_ruby/generated/models/user_flagged_event.rb', line 23 def user @user end |
Class Method Details
.json_field_mappings ⇒ Object
Override field mappings for JSON serialization
51 52 53 54 55 56 57 58 59 60 61 62 |
# File 'lib/getstream_ruby/generated/models/user_flagged_event.rb', line 51 def self.json_field_mappings { created_at: 'created_at', reason: 'reason', total_flags: 'total_flags', user: 'user', type: 'type', received_at: 'received_at', custom: 'custom', target_user: 'target_user' } end |