Class: GetStream::Generated::Models::UserMutedEvent
- Defined in:
- lib/getstream_ruby/generated/models/user_muted_event.rb
Overview
This event is sent when a user gets muted. The event contains information about the user that was muted.
Instance Attribute Summary collapse
-
#created_at ⇒ DateTime
Date/time of creation.
- #custom ⇒ Object
- #received_at ⇒ DateTime
- #target_user ⇒ UserResponseCommonFields
-
#target_users ⇒ Array<UserResponseCommonFields>
The target users that were muted.
-
#type ⇒ String
The type of event: “user.muted” in this case.
- #user ⇒ UserResponseCommonFields
Class Method Summary collapse
-
.json_field_mappings ⇒ Object
Override field mappings for JSON serialization.
Instance Method Summary collapse
-
#initialize(attributes = {}) ⇒ UserMutedEvent
constructor
Initialize with attributes.
Methods inherited from BaseModel
#==, #inspect, omit_empty_fields, #to_h, #to_json
Constructor Details
#initialize(attributes = {}) ⇒ UserMutedEvent
Initialize with attributes
35 36 37 38 39 40 41 42 43 44 |
# File 'lib/getstream_ruby/generated/models/user_muted_event.rb', line 35 def initialize(attributes = {}) super(attributes) @created_at = attributes[:created_at] || attributes['created_at'] @custom = attributes[:custom] || attributes['custom'] @user = attributes[:user] || attributes['user'] @type = attributes[:type] || attributes['type'] || "user.muted" @received_at = attributes[:received_at] || attributes['received_at'] || nil @target_users = attributes[:target_users] || attributes['target_users'] || nil @target_user = attributes[:target_user] || attributes['target_user'] || nil end |
Instance Attribute Details
#created_at ⇒ DateTime
Returns Date/time of creation.
14 15 16 |
# File 'lib/getstream_ruby/generated/models/user_muted_event.rb', line 14 def created_at @created_at end |
#custom ⇒ Object
17 18 19 |
# File 'lib/getstream_ruby/generated/models/user_muted_event.rb', line 17 def custom @custom end |
#received_at ⇒ DateTime
26 27 28 |
# File 'lib/getstream_ruby/generated/models/user_muted_event.rb', line 26 def received_at @received_at end |
#target_user ⇒ UserResponseCommonFields
32 33 34 |
# File 'lib/getstream_ruby/generated/models/user_muted_event.rb', line 32 def target_user @target_user end |
#target_users ⇒ Array<UserResponseCommonFields>
Returns The target users that were muted.
29 30 31 |
# File 'lib/getstream_ruby/generated/models/user_muted_event.rb', line 29 def target_users @target_users end |
#type ⇒ String
Returns The type of event: “user.muted” in this case.
23 24 25 |
# File 'lib/getstream_ruby/generated/models/user_muted_event.rb', line 23 def type @type end |
#user ⇒ UserResponseCommonFields
20 21 22 |
# File 'lib/getstream_ruby/generated/models/user_muted_event.rb', line 20 def user @user end |
Class Method Details
.json_field_mappings ⇒ Object
Override field mappings for JSON serialization
47 48 49 50 51 52 53 54 55 56 57 |
# File 'lib/getstream_ruby/generated/models/user_muted_event.rb', line 47 def self.json_field_mappings { created_at: 'created_at', custom: 'custom', user: 'user', type: 'type', received_at: 'received_at', target_users: 'target_users', target_user: 'target_user' } end |