Class: GetStream::Generated::Models::UserUnbannedEvent

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/getstream_ruby/generated/models/user_unbanned_event.rb

Overview

This event is sent when a user gets unbanned. The event contains information about the user that was unbanned.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#==, #inspect, omit_empty_fields, #to_h, #to_json

Constructor Details

#initialize(attributes = {}) ⇒ UserUnbannedEvent

Initialize with attributes



56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
# File 'lib/getstream_ruby/generated/models/user_unbanned_event.rb', line 56

def initialize(attributes = {})
  super(attributes)
  @created_at = attributes[:created_at] || attributes['created_at']
  @custom = attributes[:custom] || attributes['custom']
  @user = attributes[:user] || attributes['user']
  @type = attributes[:type] || attributes['type'] || "user.unbanned"
  @channel_id = attributes[:channel_id] || attributes['channel_id'] || nil
  @channel_member_count = attributes[:channel_member_count] || attributes['channel_member_count'] || nil
  @channel_message_count = attributes[:channel_message_count] || attributes['channel_message_count'] || nil
  @channel_type = attributes[:channel_type] || attributes['channel_type'] || nil
  @cid = attributes[:cid] || attributes['cid'] || nil
  @received_at = attributes[:received_at] || attributes['received_at'] || nil
  @shadow = attributes[:shadow] || attributes['shadow'] || nil
  @team = attributes[:team] || attributes['team'] || nil
  @channel_custom = attributes[:channel_custom] || attributes['channel_custom'] || nil
  @created_by = attributes[:created_by] || attributes['created_by'] || nil
end

Instance Attribute Details

#channel_customObject

Returns:

  • (Object)


50
51
52
# File 'lib/getstream_ruby/generated/models/user_unbanned_event.rb', line 50

def channel_custom
  @channel_custom
end

#channel_idString

Returns The ID of the channel where the target user was unbanned.

Returns:

  • (String)

    The ID of the channel where the target user was unbanned



26
27
28
# File 'lib/getstream_ruby/generated/models/user_unbanned_event.rb', line 26

def channel_id
  @channel_id
end

#channel_member_countInteger

Returns:

  • (Integer)


29
30
31
# File 'lib/getstream_ruby/generated/models/user_unbanned_event.rb', line 29

def channel_member_count
  @channel_member_count
end

#channel_message_countInteger

Returns:

  • (Integer)


32
33
34
# File 'lib/getstream_ruby/generated/models/user_unbanned_event.rb', line 32

def channel_message_count
  @channel_message_count
end

#channel_typeString

Returns The type of the channel where the target user was unbanned.

Returns:

  • (String)

    The type of the channel where the target user was unbanned



35
36
37
# File 'lib/getstream_ruby/generated/models/user_unbanned_event.rb', line 35

def channel_type
  @channel_type
end

#cidString

Returns The CID of the channel where the target user was unbanned.

Returns:

  • (String)

    The CID of the channel where the target user was unbanned



38
39
40
# File 'lib/getstream_ruby/generated/models/user_unbanned_event.rb', line 38

def cid
  @cid
end

#created_atDateTime

Returns Date/time of creation.

Returns:

  • (DateTime)

    Date/time of creation



14
15
16
# File 'lib/getstream_ruby/generated/models/user_unbanned_event.rb', line 14

def created_at
  @created_at
end

#created_byUserResponseCommonFields



53
54
55
# File 'lib/getstream_ruby/generated/models/user_unbanned_event.rb', line 53

def created_by
  @created_by
end

#customObject

Returns:

  • (Object)


17
18
19
# File 'lib/getstream_ruby/generated/models/user_unbanned_event.rb', line 17

def custom
  @custom
end

#received_atDateTime

Returns:

  • (DateTime)


41
42
43
# File 'lib/getstream_ruby/generated/models/user_unbanned_event.rb', line 41

def received_at
  @received_at
end

#shadowBoolean

Returns Whether the target user was shadow unbanned.

Returns:

  • (Boolean)

    Whether the target user was shadow unbanned



44
45
46
# File 'lib/getstream_ruby/generated/models/user_unbanned_event.rb', line 44

def shadow
  @shadow
end

#teamString

Returns The team of the channel where the target user was unbanned.

Returns:

  • (String)

    The team of the channel where the target user was unbanned



47
48
49
# File 'lib/getstream_ruby/generated/models/user_unbanned_event.rb', line 47

def team
  @team
end

#typeString

Returns The type of event: “user.unbanned” in this case.

Returns:

  • (String)

    The type of event: “user.unbanned” in this case



23
24
25
# File 'lib/getstream_ruby/generated/models/user_unbanned_event.rb', line 23

def type
  @type
end

#userUserResponseCommonFields



20
21
22
# File 'lib/getstream_ruby/generated/models/user_unbanned_event.rb', line 20

def user
  @user
end

Class Method Details

.json_field_mappingsObject

Override field mappings for JSON serialization



75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
# File 'lib/getstream_ruby/generated/models/user_unbanned_event.rb', line 75

def self.json_field_mappings
  {
    created_at: 'created_at',
    custom: 'custom',
    user: 'user',
    type: 'type',
    channel_id: 'channel_id',
    channel_member_count: 'channel_member_count',
    channel_message_count: 'channel_message_count',
    channel_type: 'channel_type',
    cid: 'cid',
    received_at: 'received_at',
    shadow: 'shadow',
    team: 'team',
    channel_custom: 'channel_custom',
    created_by: 'created_by'
  }
end