Class: GetStream::Generated::Models::ActivityRequest
- Defined in:
- lib/getstream_ruby/generated/models/activity_request.rb
Instance Attribute Summary collapse
-
#attachments ⇒ Array<Attachment>
List of attachments for the activity.
-
#collection_refs ⇒ Array<String>
Collections that this activity references.
-
#copy_custom_to_notification ⇒ Object
deprecated
Deprecated.
This field is deprecated. @return [Boolean] Whether to copy custom data to the notification activity (only applies when create_notification_activity is true) Deprecated: use notification_context.trigger.custom and notification_context.target.custom instead
-
#create_notification_activity ⇒ Boolean
Whether to create notification activities for mentioned users.
-
#custom ⇒ Object
Custom data for the activity.
-
#expires_at ⇒ String
Expiration time for the activity.
-
#feeds ⇒ Array<String>
List of feeds to add the activity to with a default max limit of 25 feeds.
-
#filter_tags ⇒ Array<String>
Tags for filtering activities.
-
#id ⇒ String
Optional ID for the activity.
-
#interest_tags ⇒ Array<String>
Tags for indicating user interests.
- #location ⇒ Location
-
#mentioned_user_ids ⇒ Array<String>
List of users mentioned in the activity.
-
#parent_id ⇒ String
ID of parent activity for replies/comments.
-
#poll_id ⇒ String
ID of a poll to attach to activity.
-
#restrict_replies ⇒ String
Controls who can add comments/replies to this activity.
-
#search_data ⇒ Object
Additional data for search indexing.
-
#skip_enrich_url ⇒ Boolean
Whether to skip URL enrichment for the activity.
-
#skip_push ⇒ Boolean
Whether to skip push notifications.
-
#text ⇒ String
Text content of the activity.
-
#type ⇒ String
Type of activity.
-
#user_id ⇒ String
ID of the user creating the activity.
-
#visibility ⇒ String
Visibility setting for the activity.
-
#visibility_tag ⇒ String
If visibility is ‘tag’, this is the tag name and is required.
Class Method Summary collapse
-
.json_field_mappings ⇒ Object
Override field mappings for JSON serialization.
Instance Method Summary collapse
-
#initialize(attributes = {}) ⇒ ActivityRequest
constructor
Initialize with attributes.
Methods inherited from BaseModel
#==, #inspect, omit_empty_fields, #to_h, #to_json
Constructor Details
#initialize(attributes = {}) ⇒ ActivityRequest
Initialize with attributes
84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 |
# File 'lib/getstream_ruby/generated/models/activity_request.rb', line 84 def initialize(attributes = {}) super(attributes) @type = attributes[:type] || attributes['type'] @feeds = attributes[:feeds] || attributes['feeds'] @copy_custom_to_notification = attributes[:copy_custom_to_notification] || attributes['copy_custom_to_notification'] || nil @create_notification_activity = attributes[:create_notification_activity] || attributes['create_notification_activity'] || nil @expires_at = attributes[:expires_at] || attributes['expires_at'] || nil @id = attributes[:id] || attributes['id'] || nil @parent_id = attributes[:parent_id] || attributes['parent_id'] || nil @poll_id = attributes[:poll_id] || attributes['poll_id'] || nil @restrict_replies = attributes[:restrict_replies] || attributes['restrict_replies'] || nil @skip_enrich_url = attributes[:skip_enrich_url] || attributes['skip_enrich_url'] || nil @skip_push = attributes[:skip_push] || attributes['skip_push'] || nil @text = attributes[:text] || attributes['text'] || nil @user_id = attributes[:user_id] || attributes['user_id'] || nil @visibility = attributes[:visibility] || attributes['visibility'] || nil @visibility_tag = attributes[:visibility_tag] || attributes['visibility_tag'] || nil @attachments = attributes[:attachments] || attributes['attachments'] || nil @collection_refs = attributes[:collection_refs] || attributes['collection_refs'] || nil @filter_tags = attributes[:filter_tags] || attributes['filter_tags'] || nil @interest_tags = attributes[:interest_tags] || attributes['interest_tags'] || nil @mentioned_user_ids = attributes[:mentioned_user_ids] || attributes['mentioned_user_ids'] || nil @custom = attributes[:custom] || attributes['custom'] || nil @location = attributes[:location] || attributes['location'] || nil @search_data = attributes[:search_data] || attributes['search_data'] || nil end |
Instance Attribute Details
#attachments ⇒ Array<Attachment>
Returns List of attachments for the activity.
60 61 62 |
# File 'lib/getstream_ruby/generated/models/activity_request.rb', line 60 def @attachments end |
#collection_refs ⇒ Array<String>
Returns Collections that this activity references.
63 64 65 |
# File 'lib/getstream_ruby/generated/models/activity_request.rb', line 63 def collection_refs @collection_refs end |
#copy_custom_to_notification ⇒ Object
This field is deprecated. @return [Boolean] Whether to copy custom data to the notification activity (only applies when create_notification_activity is true) Deprecated: use notification_context.trigger.custom and notification_context.target.custom instead
21 22 23 |
# File 'lib/getstream_ruby/generated/models/activity_request.rb', line 21 def copy_custom_to_notification @copy_custom_to_notification end |
#create_notification_activity ⇒ Boolean
Returns Whether to create notification activities for mentioned users.
24 25 26 |
# File 'lib/getstream_ruby/generated/models/activity_request.rb', line 24 def create_notification_activity @create_notification_activity end |
#custom ⇒ Object
Returns Custom data for the activity.
75 76 77 |
# File 'lib/getstream_ruby/generated/models/activity_request.rb', line 75 def custom @custom end |
#expires_at ⇒ String
Returns Expiration time for the activity.
27 28 29 |
# File 'lib/getstream_ruby/generated/models/activity_request.rb', line 27 def expires_at @expires_at end |
#feeds ⇒ Array<String>
Returns List of feeds to add the activity to with a default max limit of 25 feeds.
17 18 19 |
# File 'lib/getstream_ruby/generated/models/activity_request.rb', line 17 def feeds @feeds end |
#filter_tags ⇒ Array<String>
Returns Tags for filtering activities.
66 67 68 |
# File 'lib/getstream_ruby/generated/models/activity_request.rb', line 66 def @filter_tags end |
#id ⇒ String
Returns Optional ID for the activity.
30 31 32 |
# File 'lib/getstream_ruby/generated/models/activity_request.rb', line 30 def id @id end |
#interest_tags ⇒ Array<String>
Returns Tags for indicating user interests.
69 70 71 |
# File 'lib/getstream_ruby/generated/models/activity_request.rb', line 69 def @interest_tags end |
#location ⇒ Location
78 79 80 |
# File 'lib/getstream_ruby/generated/models/activity_request.rb', line 78 def location @location end |
#mentioned_user_ids ⇒ Array<String>
Returns List of users mentioned in the activity.
72 73 74 |
# File 'lib/getstream_ruby/generated/models/activity_request.rb', line 72 def mentioned_user_ids @mentioned_user_ids end |
#parent_id ⇒ String
Returns ID of parent activity for replies/comments.
33 34 35 |
# File 'lib/getstream_ruby/generated/models/activity_request.rb', line 33 def parent_id @parent_id end |
#poll_id ⇒ String
Returns ID of a poll to attach to activity.
36 37 38 |
# File 'lib/getstream_ruby/generated/models/activity_request.rb', line 36 def poll_id @poll_id end |
#restrict_replies ⇒ String
Returns Controls who can add comments/replies to this activity. One of: everyone, people_i_follow, nobody.
39 40 41 |
# File 'lib/getstream_ruby/generated/models/activity_request.rb', line 39 def restrict_replies @restrict_replies end |
#search_data ⇒ Object
Returns Additional data for search indexing.
81 82 83 |
# File 'lib/getstream_ruby/generated/models/activity_request.rb', line 81 def search_data @search_data end |
#skip_enrich_url ⇒ Boolean
Returns Whether to skip URL enrichment for the activity.
42 43 44 |
# File 'lib/getstream_ruby/generated/models/activity_request.rb', line 42 def skip_enrich_url @skip_enrich_url end |
#skip_push ⇒ Boolean
Returns Whether to skip push notifications.
45 46 47 |
# File 'lib/getstream_ruby/generated/models/activity_request.rb', line 45 def skip_push @skip_push end |
#text ⇒ String
Returns Text content of the activity.
48 49 50 |
# File 'lib/getstream_ruby/generated/models/activity_request.rb', line 48 def text @text end |
#type ⇒ String
Returns Type of activity.
14 15 16 |
# File 'lib/getstream_ruby/generated/models/activity_request.rb', line 14 def type @type end |
#user_id ⇒ String
Returns ID of the user creating the activity.
51 52 53 |
# File 'lib/getstream_ruby/generated/models/activity_request.rb', line 51 def user_id @user_id end |
#visibility ⇒ String
Returns Visibility setting for the activity. One of: public, private, tag.
54 55 56 |
# File 'lib/getstream_ruby/generated/models/activity_request.rb', line 54 def visibility @visibility end |
#visibility_tag ⇒ String
Returns If visibility is ‘tag’, this is the tag name and is required.
57 58 59 |
# File 'lib/getstream_ruby/generated/models/activity_request.rb', line 57 def visibility_tag @visibility_tag end |
Class Method Details
.json_field_mappings ⇒ Object
Override field mappings for JSON serialization
112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 |
# File 'lib/getstream_ruby/generated/models/activity_request.rb', line 112 def self.json_field_mappings { type: 'type', feeds: 'feeds', copy_custom_to_notification: 'copy_custom_to_notification', create_notification_activity: 'create_notification_activity', expires_at: 'expires_at', id: 'id', parent_id: 'parent_id', poll_id: 'poll_id', restrict_replies: 'restrict_replies', skip_enrich_url: 'skip_enrich_url', skip_push: 'skip_push', text: 'text', user_id: 'user_id', visibility: 'visibility', visibility_tag: 'visibility_tag', attachments: 'attachments', collection_refs: 'collection_refs', filter_tags: 'filter_tags', interest_tags: 'interest_tags', mentioned_user_ids: 'mentioned_user_ids', custom: 'custom', location: 'location', search_data: 'search_data' } end |