Class: GetStream::Generated::Models::AppealItemResponse

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/getstream_ruby/generated/models/appeal_item_response.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#==, #inspect, omit_empty_fields, #to_h, #to_json

Constructor Details

#initialize(attributes = {}) ⇒ AppealItemResponse

Initialize with attributes



83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
# File 'lib/getstream_ruby/generated/models/appeal_item_response.rb', line 83

def initialize(attributes = {})
  super(attributes)
  @appeal_reason = attributes[:appeal_reason] || attributes['appeal_reason']
  @created_at = attributes[:created_at] || attributes['created_at']
  @entity_id = attributes[:entity_id] || attributes['entity_id']
  @entity_type = attributes[:entity_type] || attributes['entity_type']
  @id = attributes[:id] || attributes['id']
  @status = attributes[:status] || attributes['status']
  @updated_at = attributes[:updated_at] || attributes['updated_at']
  @ai_text_severity = attributes[:ai_text_severity] || attributes['ai_text_severity'] || nil
  @channel_cid = attributes[:channel_cid] || attributes['channel_cid'] || nil
  @config_key = attributes[:config_key] || attributes['config_key'] || nil
  @decision_reason = attributes[:decision_reason] || attributes['decision_reason'] || nil
  @recommended_action = attributes[:recommended_action] || attributes['recommended_action'] || nil
  @review_queue_item_id = attributes[:review_queue_item_id] || attributes['review_queue_item_id'] || nil
  @severity = attributes[:severity] || attributes['severity'] || nil
  @actions = attributes[:actions] || attributes['actions'] || nil
  @attachments = attributes[:attachments] || attributes['attachments'] || nil
  @flag_labels = attributes[:flag_labels] || attributes['flag_labels'] || nil
  @flag_types = attributes[:flag_types] || attributes['flag_types'] || nil
  @flags = attributes[:flags] || attributes['flags'] || nil
  @entity_content = attributes[:entity_content] || attributes['entity_content'] || nil
  @moderation_action = attributes[:moderation_action] || attributes['moderation_action'] || nil
  @original_moderation_action = attributes[:original_moderation_action] || attributes['original_moderation_action'] || nil
  @user = attributes[:user] || attributes['user'] || nil
end

Instance Attribute Details

#actionsArray<ActionLogResponse>

Returns Full chronological history of all moderation actions on the review queue item.

Returns:

  • (Array<ActionLogResponse>)

    Full chronological history of all moderation actions on the review queue item



56
57
58
# File 'lib/getstream_ruby/generated/models/appeal_item_response.rb', line 56

def actions
  @actions
end

#ai_text_severityString

Returns Text severity level assigned by the AI provider.

Returns:

  • (String)

    Text severity level assigned by the AI provider



35
36
37
# File 'lib/getstream_ruby/generated/models/appeal_item_response.rb', line 35

def ai_text_severity
  @ai_text_severity
end

#appeal_reasonString

Returns Reason Text of the Appeal Item.

Returns:

  • (String)

    Reason Text of the Appeal Item



14
15
16
# File 'lib/getstream_ruby/generated/models/appeal_item_response.rb', line 14

def appeal_reason
  @appeal_reason
end

#attachmentsArray<String>

Returns Attachments(e.g. Images) of the Appeal Item.

Returns:

  • (Array<String>)

    Attachments(e.g. Images) of the Appeal Item



59
60
61
# File 'lib/getstream_ruby/generated/models/appeal_item_response.rb', line 59

def attachments
  @attachments
end

#channel_cidString

Returns CID of the channel the entity belongs to, if applicable.

Returns:

  • (String)

    CID of the channel the entity belongs to, if applicable



38
39
40
# File 'lib/getstream_ruby/generated/models/appeal_item_response.rb', line 38

def channel_cid
  @channel_cid
end

#config_keyString

Returns Moderation policy key that was applied.

Returns:

  • (String)

    Moderation policy key that was applied



41
42
43
# File 'lib/getstream_ruby/generated/models/appeal_item_response.rb', line 41

def config_key
  @config_key
end

#created_atDateTime

Returns When the flag was created.

Returns:

  • (DateTime)

    When the flag was created



17
18
19
# File 'lib/getstream_ruby/generated/models/appeal_item_response.rb', line 17

def created_at
  @created_at
end

#decision_reasonString

Returns Decision Reason of the Appeal Item.

Returns:

  • (String)

    Decision Reason of the Appeal Item



44
45
46
# File 'lib/getstream_ruby/generated/models/appeal_item_response.rb', line 44

def decision_reason
  @decision_reason
end

#entity_contentModerationPayload

Returns:



71
72
73
# File 'lib/getstream_ruby/generated/models/appeal_item_response.rb', line 71

def entity_content
  @entity_content
end

#entity_idString

Returns ID of the entity.

Returns:

  • (String)

    ID of the entity



20
21
22
# File 'lib/getstream_ruby/generated/models/appeal_item_response.rb', line 20

def entity_id
  @entity_id
end

#entity_typeString

Returns Type of entity.

Returns:

  • (String)

    Type of entity



23
24
25
# File 'lib/getstream_ruby/generated/models/appeal_item_response.rb', line 23

def entity_type
  @entity_type
end

#flag_labelsArray<String>

Returns Classification labels from automated and manual review.

Returns:

  • (Array<String>)

    Classification labels from automated and manual review



62
63
64
# File 'lib/getstream_ruby/generated/models/appeal_item_response.rb', line 62

def flag_labels
  @flag_labels
end

#flag_typesArray<String>

Returns Types of flags applied to the entity (e.g. user_report, bodyguard).

Returns:

  • (Array<String>)

    Types of flags applied to the entity (e.g. user_report, bodyguard)



65
66
67
# File 'lib/getstream_ruby/generated/models/appeal_item_response.rb', line 65

def flag_types
  @flag_types
end

#flagsArray<ModerationFlagResponse>

Returns Per-provider flag records explaining why the action was taken.

Returns:



68
69
70
# File 'lib/getstream_ruby/generated/models/appeal_item_response.rb', line 68

def flags
  @flags
end

#idString

Returns:

  • (String)


26
27
28
# File 'lib/getstream_ruby/generated/models/appeal_item_response.rb', line 26

def id
  @id
end

#moderation_actionActionLogResponse

Returns:



74
75
76
# File 'lib/getstream_ruby/generated/models/appeal_item_response.rb', line 74

def moderation_action
  @moderation_action
end

#original_moderation_actionActionLogResponse

Returns:



77
78
79
# File 'lib/getstream_ruby/generated/models/appeal_item_response.rb', line 77

def original_moderation_action
  @original_moderation_action
end

Returns Action recommended by the automated moderation system (e.g. flag, remove, shadow).

Returns:

  • (String)

    Action recommended by the automated moderation system (e.g. flag, remove, shadow)



47
48
49
# File 'lib/getstream_ruby/generated/models/appeal_item_response.rb', line 47

def recommended_action
  @recommended_action
end

#review_queue_item_idString

Returns ID of the review queue item linked to this appeal, if the appeal was submitted with one.

Returns:

  • (String)

    ID of the review queue item linked to this appeal, if the appeal was submitted with one



50
51
52
# File 'lib/getstream_ruby/generated/models/appeal_item_response.rb', line 50

def review_queue_item_id
  @review_queue_item_id
end

#severityInteger

Returns Overall content severity score (1–100).

Returns:

  • (Integer)

    Overall content severity score (1–100)



53
54
55
# File 'lib/getstream_ruby/generated/models/appeal_item_response.rb', line 53

def severity
  @severity
end

#statusString

Returns Status of the Appeal Item.

Returns:

  • (String)

    Status of the Appeal Item



29
30
31
# File 'lib/getstream_ruby/generated/models/appeal_item_response.rb', line 29

def status
  @status
end

#updated_atDateTime

Returns When the flag was last updated.

Returns:

  • (DateTime)

    When the flag was last updated



32
33
34
# File 'lib/getstream_ruby/generated/models/appeal_item_response.rb', line 32

def updated_at
  @updated_at
end

#userUserResponse

Returns:



80
81
82
# File 'lib/getstream_ruby/generated/models/appeal_item_response.rb', line 80

def user
  @user
end

Class Method Details

.json_field_mappingsObject

Override field mappings for JSON serialization



111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
# File 'lib/getstream_ruby/generated/models/appeal_item_response.rb', line 111

def self.json_field_mappings
  {
    appeal_reason: 'appeal_reason',
    created_at: 'created_at',
    entity_id: 'entity_id',
    entity_type: 'entity_type',
    id: 'id',
    status: 'status',
    updated_at: 'updated_at',
    ai_text_severity: 'ai_text_severity',
    channel_cid: 'channel_cid',
    config_key: 'config_key',
    decision_reason: 'decision_reason',
    recommended_action: 'recommended_action',
    review_queue_item_id: 'review_queue_item_id',
    severity: 'severity',
    actions: 'actions',
    attachments: 'attachments',
    flag_labels: 'flag_labels',
    flag_types: 'flag_types',
    flags: 'flags',
    entity_content: 'entity_content',
    moderation_action: 'moderation_action',
    original_moderation_action: 'original_moderation_action',
    user: 'user'
  }
end