Class: GetStream::Generated::Models::ExportChannelsRequest
- Defined in:
- lib/getstream_ruby/generated/models/export_channels_request.rb
Instance Attribute Summary collapse
-
#channels ⇒ Array<ChannelExport>
Export options for channels.
-
#clear_deleted_message_text ⇒ Boolean
Set if deleted message text should be cleared.
- #export_users ⇒ Boolean
-
#format ⇒ String
Output format: 'json' (default) or 'csv'.
-
#include_fields ⇒ Array<String>
For csv format: subset of message columns to include (defaults to a standard set).
-
#include_soft_deleted_channels ⇒ Boolean
Set if you want to include deleted channels.
-
#include_truncated_messages ⇒ Boolean
Set if you want to include truncated messages.
-
#version ⇒ String
Export version.
Class Method Summary collapse
-
.json_field_mappings ⇒ Object
Override field mappings for JSON serialization.
Instance Method Summary collapse
-
#initialize(attributes = {}) ⇒ ExportChannelsRequest
constructor
Initialize with attributes.
Methods inherited from BaseModel
#==, #inspect, omit_empty_fields, #to_h, #to_json
Constructor Details
#initialize(attributes = {}) ⇒ ExportChannelsRequest
Initialize with attributes
38 39 40 41 42 43 44 45 46 47 48 |
# File 'lib/getstream_ruby/generated/models/export_channels_request.rb', line 38 def initialize(attributes = {}) super(attributes) @channels = attributes[:channels] || attributes['channels'] @clear_deleted_message_text = attributes[:clear_deleted_message_text] || attributes['clear_deleted_message_text'] || nil @export_users = attributes[:export_users] || attributes['export_users'] || nil @format = attributes[:format] || attributes['format'] || nil @include_soft_deleted_channels = attributes[:include_soft_deleted_channels] || attributes['include_soft_deleted_channels'] || nil @include_truncated_messages = attributes[:include_truncated_messages] || attributes['include_truncated_messages'] || nil @version = attributes[:version] || attributes['version'] || nil @include_fields = attributes[:include_fields] || attributes['include_fields'] || nil end |
Instance Attribute Details
#channels ⇒ Array<ChannelExport>
Returns Export options for channels.
14 15 16 |
# File 'lib/getstream_ruby/generated/models/export_channels_request.rb', line 14 def channels @channels end |
#clear_deleted_message_text ⇒ Boolean
Returns Set if deleted message text should be cleared.
17 18 19 |
# File 'lib/getstream_ruby/generated/models/export_channels_request.rb', line 17 def @clear_deleted_message_text end |
#export_users ⇒ Boolean
20 21 22 |
# File 'lib/getstream_ruby/generated/models/export_channels_request.rb', line 20 def export_users @export_users end |
#format ⇒ String
Returns Output format: 'json' (default) or 'csv'. csv requires version=v2 and is incompatible with export_users.
23 24 25 |
# File 'lib/getstream_ruby/generated/models/export_channels_request.rb', line 23 def format @format end |
#include_fields ⇒ Array<String>
Returns For csv format: subset of message columns to include (defaults to a standard set).
35 36 37 |
# File 'lib/getstream_ruby/generated/models/export_channels_request.rb', line 35 def include_fields @include_fields end |
#include_soft_deleted_channels ⇒ Boolean
Returns Set if you want to include deleted channels.
26 27 28 |
# File 'lib/getstream_ruby/generated/models/export_channels_request.rb', line 26 def include_soft_deleted_channels @include_soft_deleted_channels end |
#include_truncated_messages ⇒ Boolean
Returns Set if you want to include truncated messages.
29 30 31 |
# File 'lib/getstream_ruby/generated/models/export_channels_request.rb', line 29 def @include_truncated_messages end |
#version ⇒ String
Returns Export version.
32 33 34 |
# File 'lib/getstream_ruby/generated/models/export_channels_request.rb', line 32 def version @version end |
Class Method Details
.json_field_mappings ⇒ Object
Override field mappings for JSON serialization
51 52 53 54 55 56 57 58 59 60 61 62 |
# File 'lib/getstream_ruby/generated/models/export_channels_request.rb', line 51 def self.json_field_mappings { channels: 'channels', clear_deleted_message_text: 'clear_deleted_message_text', export_users: 'export_users', format: 'format', include_soft_deleted_channels: 'include_soft_deleted_channels', include_truncated_messages: 'include_truncated_messages', version: 'version', include_fields: 'include_fields' } end |