Class: GetStream::Generated::Models::FeedsModerationTemplateConfigPayload
- Inherits:
-
BaseModel
- Object
- BaseModel
- GetStream::Generated::Models::FeedsModerationTemplateConfigPayload
- Defined in:
- lib/getstream_ruby/generated/models/feeds_moderation_template_config_payload.rb
Overview
Configuration for a feeds moderation template
Instance Attribute Summary collapse
-
#config_key ⇒ String
Key of the moderation configuration to use.
-
#data_types ⇒ Hash<String, String>
Map of data type names to their content types.
Class Method Summary collapse
-
.json_field_mappings ⇒ Object
Override field mappings for JSON serialization.
Instance Method Summary collapse
-
#initialize(attributes = {}) ⇒ FeedsModerationTemplateConfigPayload
constructor
Initialize with attributes.
Methods inherited from BaseModel
#==, #inspect, omit_empty_fields, #to_h, #to_json
Constructor Details
#initialize(attributes = {}) ⇒ FeedsModerationTemplateConfigPayload
Initialize with attributes
20 21 22 23 24 |
# File 'lib/getstream_ruby/generated/models/feeds_moderation_template_config_payload.rb', line 20 def initialize(attributes = {}) super(attributes) @data_types = attributes[:data_types] || attributes['data_types'] @config_key = attributes[:config_key] || attributes['config_key'] || nil end |
Instance Attribute Details
#config_key ⇒ String
Returns Key of the moderation configuration to use.
17 18 19 |
# File 'lib/getstream_ruby/generated/models/feeds_moderation_template_config_payload.rb', line 17 def config_key @config_key end |
#data_types ⇒ Hash<String, String>
Returns Map of data type names to their content types.
14 15 16 |
# File 'lib/getstream_ruby/generated/models/feeds_moderation_template_config_payload.rb', line 14 def data_types @data_types end |
Class Method Details
.json_field_mappings ⇒ Object
Override field mappings for JSON serialization
27 28 29 30 31 32 |
# File 'lib/getstream_ruby/generated/models/feeds_moderation_template_config_payload.rb', line 27 def self.json_field_mappings { data_types: 'data_types', config_key: 'config_key' } end |