Class: GetStream::Generated::Models::GetOrCreateUnfollowRequest
- Inherits:
-
BaseModel
- Object
- BaseModel
- GetStream::Generated::Models::GetOrCreateUnfollowRequest
- Defined in:
- lib/getstream_ruby/generated/models/get_or_create_unfollow_request.rb
Instance Attribute Summary collapse
-
#delete_notification_activity ⇒ Boolean
Whether to delete the corresponding notification activity (default: false).
-
#enrich_own_fields ⇒ Boolean
If true, enriches the follow’s source_feed and target_feed with own_* fields (own_follows, own_followings, own_capabilities, own_membership).
-
#keep_history ⇒ Boolean
When true, activities from the unfollowed feed will remain in the source feed’s timeline (default: false).
-
#source ⇒ String
Fully qualified ID of the source feed.
-
#target ⇒ String
Fully qualified ID of the target feed.
Class Method Summary collapse
-
.json_field_mappings ⇒ Object
Override field mappings for JSON serialization.
Instance Method Summary collapse
-
#initialize(attributes = {}) ⇒ GetOrCreateUnfollowRequest
constructor
Initialize with attributes.
Methods inherited from BaseModel
#==, #inspect, omit_empty_fields, #to_h, #to_json
Constructor Details
#initialize(attributes = {}) ⇒ GetOrCreateUnfollowRequest
Initialize with attributes
29 30 31 32 33 34 35 36 |
# File 'lib/getstream_ruby/generated/models/get_or_create_unfollow_request.rb', line 29 def initialize(attributes = {}) super(attributes) @source = attributes[:source] || attributes['source'] @target = attributes[:target] || attributes['target'] @delete_notification_activity = attributes[:delete_notification_activity] || attributes['delete_notification_activity'] || nil @enrich_own_fields = attributes[:enrich_own_fields] || attributes['enrich_own_fields'] || nil @keep_history = attributes[:keep_history] || attributes['keep_history'] || nil end |
Instance Attribute Details
#delete_notification_activity ⇒ Boolean
Returns Whether to delete the corresponding notification activity (default: false).
20 21 22 |
# File 'lib/getstream_ruby/generated/models/get_or_create_unfollow_request.rb', line 20 def delete_notification_activity @delete_notification_activity end |
#enrich_own_fields ⇒ Boolean
Returns If true, enriches the follow’s source_feed and target_feed with own_* fields (own_follows, own_followings, own_capabilities, own_membership). Defaults to false for performance.
23 24 25 |
# File 'lib/getstream_ruby/generated/models/get_or_create_unfollow_request.rb', line 23 def enrich_own_fields @enrich_own_fields end |
#keep_history ⇒ Boolean
Returns When true, activities from the unfollowed feed will remain in the source feed’s timeline (default: false).
26 27 28 |
# File 'lib/getstream_ruby/generated/models/get_or_create_unfollow_request.rb', line 26 def keep_history @keep_history end |
#source ⇒ String
Returns Fully qualified ID of the source feed.
14 15 16 |
# File 'lib/getstream_ruby/generated/models/get_or_create_unfollow_request.rb', line 14 def source @source end |
#target ⇒ String
Returns Fully qualified ID of the target feed.
17 18 19 |
# File 'lib/getstream_ruby/generated/models/get_or_create_unfollow_request.rb', line 17 def target @target end |
Class Method Details
.json_field_mappings ⇒ Object
Override field mappings for JSON serialization
39 40 41 42 43 44 45 46 47 |
# File 'lib/getstream_ruby/generated/models/get_or_create_unfollow_request.rb', line 39 def self.json_field_mappings { source: 'source', target: 'target', delete_notification_activity: 'delete_notification_activity', enrich_own_fields: 'enrich_own_fields', keep_history: 'keep_history' } end |