Class: GetStream::Generated::Models::GroupedChannelsBucket
- Defined in:
- lib/getstream_ruby/generated/models/grouped_channels_bucket.rb
Instance Attribute Summary collapse
-
#channels ⇒ Array<ChannelStateResponseFields>
Channels returned for this bucket.
-
#next ⇒ String
Cursor for the next page of this group.
-
#prev ⇒ String
Cursor for the previous page of this group.
-
#unread_channels ⇒ Integer
Unread channels currently classified into this bucket.
Class Method Summary collapse
-
.json_field_mappings ⇒ Object
Override field mappings for JSON serialization.
Instance Method Summary collapse
-
#initialize(attributes = {}) ⇒ GroupedChannelsBucket
constructor
Initialize with attributes.
Methods inherited from BaseModel
#==, #inspect, omit_empty_fields, #to_h, #to_json
Constructor Details
#initialize(attributes = {}) ⇒ GroupedChannelsBucket
Initialize with attributes
26 27 28 29 30 31 32 |
# File 'lib/getstream_ruby/generated/models/grouped_channels_bucket.rb', line 26 def initialize(attributes = {}) super(attributes) @channels = attributes[:channels] || attributes['channels'] @next = attributes[:next] || attributes['next'] || nil @prev = attributes[:prev] || attributes['prev'] || nil @unread_channels = attributes[:unread_channels] || attributes['unread_channels'] || nil end |
Instance Attribute Details
#channels ⇒ Array<ChannelStateResponseFields>
Returns Channels returned for this bucket.
14 15 16 |
# File 'lib/getstream_ruby/generated/models/grouped_channels_bucket.rb', line 14 def channels @channels end |
#next ⇒ String
Returns Cursor for the next page of this group.
17 18 19 |
# File 'lib/getstream_ruby/generated/models/grouped_channels_bucket.rb', line 17 def next @next end |
#prev ⇒ String
Returns Cursor for the previous page of this group.
20 21 22 |
# File 'lib/getstream_ruby/generated/models/grouped_channels_bucket.rb', line 20 def prev @prev end |
#unread_channels ⇒ Integer
Returns Unread channels currently classified into this bucket.
23 24 25 |
# File 'lib/getstream_ruby/generated/models/grouped_channels_bucket.rb', line 23 def unread_channels @unread_channels end |
Class Method Details
.json_field_mappings ⇒ Object
Override field mappings for JSON serialization
35 36 37 38 39 40 41 42 |
# File 'lib/getstream_ruby/generated/models/grouped_channels_bucket.rb', line 35 def self.json_field_mappings { channels: 'channels', next: 'next', prev: 'prev', unread_channels: 'unread_channels' } end |