Class: GetStream::Generated::Models::QueryFutureChannelBansPayload
- Inherits:
-
BaseModel
- Object
- BaseModel
- GetStream::Generated::Models::QueryFutureChannelBansPayload
- Defined in:
- lib/getstream_ruby/generated/models/query_future_channel_bans_payload.rb
Instance Attribute Summary collapse
-
#exclude_expired_bans ⇒ Boolean
Whether to exclude expired bans or not.
-
#include_total ⇒ Boolean
When true, the response includes the total number of bans matching the query filter (independent of limit and offset, capped at 100000).
-
#limit ⇒ Integer
Number of records to return.
-
#offset ⇒ Integer
Number of records to offset.
-
#target_user_id ⇒ String
Filter by the target user ID.
-
#user ⇒ UserRequest
User request object.
- #user_id ⇒ String
Class Method Summary collapse
-
.json_field_mappings ⇒ Object
Override field mappings for JSON serialization.
Instance Method Summary collapse
-
#initialize(attributes = {}) ⇒ QueryFutureChannelBansPayload
constructor
Initialize with attributes.
Methods inherited from BaseModel
#==, #inspect, omit_empty_fields, #to_h, #to_json
Constructor Details
#initialize(attributes = {}) ⇒ QueryFutureChannelBansPayload
Initialize with attributes
35 36 37 38 39 40 41 42 43 44 |
# File 'lib/getstream_ruby/generated/models/query_future_channel_bans_payload.rb', line 35 def initialize(attributes = {}) super(attributes) @exclude_expired_bans = attributes[:exclude_expired_bans] || attributes['exclude_expired_bans'] || nil @include_total = attributes[:include_total] || attributes['include_total'] || nil @limit = attributes[:limit] || attributes['limit'] || nil @offset = attributes[:offset] || attributes['offset'] || nil @target_user_id = attributes[:target_user_id] || attributes['target_user_id'] || nil @user_id = attributes[:user_id] || attributes['user_id'] || nil @user = attributes[:user] || attributes['user'] || nil end |
Instance Attribute Details
#exclude_expired_bans ⇒ Boolean
Returns Whether to exclude expired bans or not.
14 15 16 |
# File 'lib/getstream_ruby/generated/models/query_future_channel_bans_payload.rb', line 14 def exclude_expired_bans @exclude_expired_bans end |
#include_total ⇒ Boolean
Returns When true, the response includes the total number of bans matching the query filter (independent of limit and offset, capped at 100000).
17 18 19 |
# File 'lib/getstream_ruby/generated/models/query_future_channel_bans_payload.rb', line 17 def include_total @include_total end |
#limit ⇒ Integer
Returns Number of records to return.
20 21 22 |
# File 'lib/getstream_ruby/generated/models/query_future_channel_bans_payload.rb', line 20 def limit @limit end |
#offset ⇒ Integer
Returns Number of records to offset.
23 24 25 |
# File 'lib/getstream_ruby/generated/models/query_future_channel_bans_payload.rb', line 23 def offset @offset end |
#target_user_id ⇒ String
Returns Filter by the target user ID. Server-side: returns all bans against this user. Client-side: narrows the authenticated user's own bans to this target.
26 27 28 |
# File 'lib/getstream_ruby/generated/models/query_future_channel_bans_payload.rb', line 26 def target_user_id @target_user_id end |
#user ⇒ UserRequest
Returns User request object.
32 33 34 |
# File 'lib/getstream_ruby/generated/models/query_future_channel_bans_payload.rb', line 32 def user @user end |
#user_id ⇒ String
29 30 31 |
# File 'lib/getstream_ruby/generated/models/query_future_channel_bans_payload.rb', line 29 def user_id @user_id end |
Class Method Details
.json_field_mappings ⇒ Object
Override field mappings for JSON serialization
47 48 49 50 51 52 53 54 55 56 57 |
# File 'lib/getstream_ruby/generated/models/query_future_channel_bans_payload.rb', line 47 def self.json_field_mappings { exclude_expired_bans: 'exclude_expired_bans', include_total: 'include_total', limit: 'limit', offset: 'offset', target_user_id: 'target_user_id', user_id: 'user_id', user: 'user' } end |