Class: GetStream::Generated::Models::ReactionGroupResponse

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/getstream_ruby/generated/models/reaction_group_response.rb

Overview

ReactionGroupResponse contains all information about a reaction of the same type.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#==, #inspect, omit_empty_fields, #to_h, #to_json

Constructor Details

#initialize(attributes = {}) ⇒ ReactionGroupResponse

Initialize with attributes



29
30
31
32
33
34
35
36
# File 'lib/getstream_ruby/generated/models/reaction_group_response.rb', line 29

def initialize(attributes = {})
  super(attributes)
  @count = attributes[:count] || attributes['count']
  @first_reaction_at = attributes[:first_reaction_at] || attributes['first_reaction_at']
  @last_reaction_at = attributes[:last_reaction_at] || attributes['last_reaction_at']
  @sum_scores = attributes[:sum_scores] || attributes['sum_scores']
  @latest_reactions_by = attributes[:latest_reactions_by] || attributes['latest_reactions_by']
end

Instance Attribute Details

#countInteger

Returns Count is the number of reactions of this type.

Returns:

  • (Integer)

    Count is the number of reactions of this type.



14
15
16
# File 'lib/getstream_ruby/generated/models/reaction_group_response.rb', line 14

def count
  @count
end

#first_reaction_atDateTime

Returns FirstReactionAt is the time of the first reaction of this type. This is the same also if all reaction of this type are deleted, because if someone will react again with the same type, will be preserved the sorting.

Returns:

  • (DateTime)

    FirstReactionAt is the time of the first reaction of this type. This is the same also if all reaction of this type are deleted, because if someone will react again with the same type, will be preserved the sorting.



17
18
19
# File 'lib/getstream_ruby/generated/models/reaction_group_response.rb', line 17

def first_reaction_at
  @first_reaction_at
end

#last_reaction_atDateTime

Returns LastReactionAt is the time of the last reaction of this type.

Returns:

  • (DateTime)

    LastReactionAt is the time of the last reaction of this type.



20
21
22
# File 'lib/getstream_ruby/generated/models/reaction_group_response.rb', line 20

def last_reaction_at
  @last_reaction_at
end

#latest_reactions_byArray<ReactionGroupUserResponse>

Returns The most recent users who reacted with this type, ordered by most recent first.

Returns:



26
27
28
# File 'lib/getstream_ruby/generated/models/reaction_group_response.rb', line 26

def latest_reactions_by
  @latest_reactions_by
end

#sum_scoresInteger

Returns SumScores is the sum of all scores of reactions of this type. Medium allows you to clap articles more than once and shows the sum of all claps from all users. For example, you can send ‘clap` x5 using `score: 5`.

Returns:

  • (Integer)

    SumScores is the sum of all scores of reactions of this type. Medium allows you to clap articles more than once and shows the sum of all claps from all users. For example, you can send ‘clap` x5 using `score: 5`.



23
24
25
# File 'lib/getstream_ruby/generated/models/reaction_group_response.rb', line 23

def sum_scores
  @sum_scores
end

Class Method Details

.json_field_mappingsObject

Override field mappings for JSON serialization



39
40
41
42
43
44
45
46
47
# File 'lib/getstream_ruby/generated/models/reaction_group_response.rb', line 39

def self.json_field_mappings
  {
    count: 'count',
    first_reaction_at: 'first_reaction_at',
    last_reaction_at: 'last_reaction_at',
    sum_scores: 'sum_scores',
    latest_reactions_by: 'latest_reactions_by'
  }
end