Class: GetStream::Generated::Models::UnfollowPair
- Defined in:
- lib/getstream_ruby/generated/models/unfollow_pair.rb
Instance Attribute Summary collapse
-
#keep_history ⇒ Boolean
When true, activities from the unfollowed feed will remain in the source feed’s timeline (default: false).
-
#source ⇒ String
Fully qualified ID of the source feed.
-
#target ⇒ String
Fully qualified ID of the target feed.
Class Method Summary collapse
-
.json_field_mappings ⇒ Object
Override field mappings for JSON serialization.
Instance Method Summary collapse
-
#initialize(attributes = {}) ⇒ UnfollowPair
constructor
Initialize with attributes.
Methods inherited from BaseModel
#==, #inspect, omit_empty_fields, #to_h, #to_json
Constructor Details
#initialize(attributes = {}) ⇒ UnfollowPair
Initialize with attributes
23 24 25 26 27 28 |
# File 'lib/getstream_ruby/generated/models/unfollow_pair.rb', line 23 def initialize(attributes = {}) super(attributes) @source = attributes[:source] || attributes['source'] @target = attributes[:target] || attributes['target'] @keep_history = attributes[:keep_history] || attributes['keep_history'] || nil end |
Instance Attribute Details
#keep_history ⇒ Boolean
Returns When true, activities from the unfollowed feed will remain in the source feed’s timeline (default: false).
20 21 22 |
# File 'lib/getstream_ruby/generated/models/unfollow_pair.rb', line 20 def keep_history @keep_history end |
#source ⇒ String
Returns Fully qualified ID of the source feed.
14 15 16 |
# File 'lib/getstream_ruby/generated/models/unfollow_pair.rb', line 14 def source @source end |
#target ⇒ String
Returns Fully qualified ID of the target feed.
17 18 19 |
# File 'lib/getstream_ruby/generated/models/unfollow_pair.rb', line 17 def target @target end |
Class Method Details
.json_field_mappings ⇒ Object
Override field mappings for JSON serialization
31 32 33 34 35 36 37 |
# File 'lib/getstream_ruby/generated/models/unfollow_pair.rb', line 31 def self.json_field_mappings { source: 'source', target: 'target', keep_history: 'keep_history' } end |