Class: GetStream::Generated::Models::UpdateActivityRequest
- Defined in:
- lib/getstream_ruby/generated/models/update_activity_request.rb
Instance Attribute Summary collapse
-
#attachments ⇒ Array<Attachment>
List of attachments for the activity.
-
#collection_refs ⇒ Array<String>
Collections that this activity references.
-
#copy_custom_to_notification ⇒ Object
deprecated
Deprecated.
This field is deprecated. @return [Boolean] Whether to copy custom data to the notification activity (only applies when handle_mention_notifications creates notifications) Deprecated: use notification_context.trigger.custom and notification_context.target.custom instead
-
#custom ⇒ Object
Custom data for the activity.
-
#enrich_own_fields ⇒ Boolean
If true, enriches the activity’s current_feed with own_* fields (own_follows, own_followings, own_capabilities, own_membership).
-
#expires_at ⇒ DateTime
Time when the activity will expire.
-
#feeds ⇒ Array<String>
List of feeds the activity is present in.
-
#filter_tags ⇒ Array<String>
Tags used for filtering the activity.
-
#force_moderation ⇒ Boolean
If true, forces moderation to run for server-side requests.
-
#handle_mention_notifications ⇒ Boolean
If true, creates notification activities for newly mentioned users and deletes notifications for users no longer mentioned.
-
#interest_tags ⇒ Array<String>
Tags indicating interest categories.
- #location ⇒ Location
-
#mentioned_user_ids ⇒ Array<String>
List of user IDs mentioned in the activity.
-
#poll_id ⇒ String
Poll ID.
-
#restrict_replies ⇒ String
Controls who can add comments/replies to this activity.
-
#run_activity_processors ⇒ Boolean
If true, runs activity processors on the updated activity.
-
#search_data ⇒ Object
Additional data for search indexing.
-
#skip_enrich_url ⇒ Boolean
Whether to skip URL enrichment for the activity.
-
#text ⇒ String
The text content of the activity.
- #user ⇒ UserRequest
- #user_id ⇒ String
-
#visibility ⇒ String
Visibility setting for the activity.
-
#visibility_tag ⇒ String
If visibility is ‘tag’, this is the tag name and is required.
Class Method Summary collapse
-
.json_field_mappings ⇒ Object
Override field mappings for JSON serialization.
Instance Method Summary collapse
-
#initialize(attributes = {}) ⇒ UpdateActivityRequest
constructor
Initialize with attributes.
Methods inherited from BaseModel
#==, #inspect, omit_empty_fields, #to_h, #to_json
Constructor Details
#initialize(attributes = {}) ⇒ UpdateActivityRequest
Initialize with attributes
84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 |
# File 'lib/getstream_ruby/generated/models/update_activity_request.rb', line 84 def initialize(attributes = {}) super(attributes) @copy_custom_to_notification = attributes[:copy_custom_to_notification] || attributes['copy_custom_to_notification'] || nil @enrich_own_fields = attributes[:enrich_own_fields] || attributes['enrich_own_fields'] || nil @expires_at = attributes[:expires_at] || attributes['expires_at'] || nil @force_moderation = attributes[:force_moderation] || attributes['force_moderation'] || nil @handle_mention_notifications = attributes[:handle_mention_notifications] || attributes['handle_mention_notifications'] || nil @poll_id = attributes[:poll_id] || attributes['poll_id'] || nil @restrict_replies = attributes[:restrict_replies] || attributes['restrict_replies'] || nil @run_activity_processors = attributes[:run_activity_processors] || attributes['run_activity_processors'] || nil @skip_enrich_url = attributes[:skip_enrich_url] || attributes['skip_enrich_url'] || nil @text = attributes[:text] || attributes['text'] || nil @user_id = attributes[:user_id] || attributes['user_id'] || nil @visibility = attributes[:visibility] || attributes['visibility'] || nil @visibility_tag = attributes[:visibility_tag] || attributes['visibility_tag'] || nil @attachments = attributes[:attachments] || attributes['attachments'] || nil @collection_refs = attributes[:collection_refs] || attributes['collection_refs'] || nil @feeds = attributes[:feeds] || attributes['feeds'] || nil @filter_tags = attributes[:filter_tags] || attributes['filter_tags'] || nil @interest_tags = attributes[:interest_tags] || attributes['interest_tags'] || nil @mentioned_user_ids = attributes[:mentioned_user_ids] || attributes['mentioned_user_ids'] || nil @custom = attributes[:custom] || attributes['custom'] || nil @location = attributes[:location] || attributes['location'] || nil @search_data = attributes[:search_data] || attributes['search_data'] || nil @user = attributes[:user] || attributes['user'] || nil end |
Instance Attribute Details
#attachments ⇒ Array<Attachment>
Returns List of attachments for the activity.
54 55 56 |
# File 'lib/getstream_ruby/generated/models/update_activity_request.rb', line 54 def @attachments end |
#collection_refs ⇒ Array<String>
Returns Collections that this activity references.
57 58 59 |
# File 'lib/getstream_ruby/generated/models/update_activity_request.rb', line 57 def collection_refs @collection_refs end |
#copy_custom_to_notification ⇒ Object
This field is deprecated. @return [Boolean] Whether to copy custom data to the notification activity (only applies when handle_mention_notifications creates notifications) Deprecated: use notification_context.trigger.custom and notification_context.target.custom instead
Model attributes
15 16 17 |
# File 'lib/getstream_ruby/generated/models/update_activity_request.rb', line 15 def copy_custom_to_notification @copy_custom_to_notification end |
#custom ⇒ Object
Returns Custom data for the activity.
72 73 74 |
# File 'lib/getstream_ruby/generated/models/update_activity_request.rb', line 72 def custom @custom end |
#enrich_own_fields ⇒ Boolean
Returns If true, enriches the activity’s current_feed with own_* fields (own_follows, own_followings, own_capabilities, own_membership). Defaults to false for performance.
18 19 20 |
# File 'lib/getstream_ruby/generated/models/update_activity_request.rb', line 18 def enrich_own_fields @enrich_own_fields end |
#expires_at ⇒ DateTime
Returns Time when the activity will expire.
21 22 23 |
# File 'lib/getstream_ruby/generated/models/update_activity_request.rb', line 21 def expires_at @expires_at end |
#feeds ⇒ Array<String>
Returns List of feeds the activity is present in.
60 61 62 |
# File 'lib/getstream_ruby/generated/models/update_activity_request.rb', line 60 def feeds @feeds end |
#filter_tags ⇒ Array<String>
Returns Tags used for filtering the activity.
63 64 65 |
# File 'lib/getstream_ruby/generated/models/update_activity_request.rb', line 63 def @filter_tags end |
#force_moderation ⇒ Boolean
Returns If true, forces moderation to run for server-side requests. By default, server-side requests skip moderation. Client-side requests always run moderation regardless of this field.
24 25 26 |
# File 'lib/getstream_ruby/generated/models/update_activity_request.rb', line 24 def force_moderation @force_moderation end |
#handle_mention_notifications ⇒ Boolean
Returns If true, creates notification activities for newly mentioned users and deletes notifications for users no longer mentioned.
27 28 29 |
# File 'lib/getstream_ruby/generated/models/update_activity_request.rb', line 27 def handle_mention_notifications @handle_mention_notifications end |
#interest_tags ⇒ Array<String>
Returns Tags indicating interest categories.
66 67 68 |
# File 'lib/getstream_ruby/generated/models/update_activity_request.rb', line 66 def @interest_tags end |
#location ⇒ Location
75 76 77 |
# File 'lib/getstream_ruby/generated/models/update_activity_request.rb', line 75 def location @location end |
#mentioned_user_ids ⇒ Array<String>
Returns List of user IDs mentioned in the activity.
69 70 71 |
# File 'lib/getstream_ruby/generated/models/update_activity_request.rb', line 69 def mentioned_user_ids @mentioned_user_ids end |
#poll_id ⇒ String
Returns Poll ID.
30 31 32 |
# File 'lib/getstream_ruby/generated/models/update_activity_request.rb', line 30 def poll_id @poll_id end |
#restrict_replies ⇒ String
Returns Controls who can add comments/replies to this activity. One of: everyone, people_i_follow, nobody.
33 34 35 |
# File 'lib/getstream_ruby/generated/models/update_activity_request.rb', line 33 def restrict_replies @restrict_replies end |
#run_activity_processors ⇒ Boolean
Returns If true, runs activity processors on the updated activity. Processors will only run if the activity text and/or attachments are changed. Defaults to false.
36 37 38 |
# File 'lib/getstream_ruby/generated/models/update_activity_request.rb', line 36 def run_activity_processors @run_activity_processors end |
#search_data ⇒ Object
Returns Additional data for search indexing.
78 79 80 |
# File 'lib/getstream_ruby/generated/models/update_activity_request.rb', line 78 def search_data @search_data end |
#skip_enrich_url ⇒ Boolean
Returns Whether to skip URL enrichment for the activity.
39 40 41 |
# File 'lib/getstream_ruby/generated/models/update_activity_request.rb', line 39 def skip_enrich_url @skip_enrich_url end |
#text ⇒ String
Returns The text content of the activity.
42 43 44 |
# File 'lib/getstream_ruby/generated/models/update_activity_request.rb', line 42 def text @text end |
#user ⇒ UserRequest
81 82 83 |
# File 'lib/getstream_ruby/generated/models/update_activity_request.rb', line 81 def user @user end |
#user_id ⇒ String
45 46 47 |
# File 'lib/getstream_ruby/generated/models/update_activity_request.rb', line 45 def user_id @user_id end |
#visibility ⇒ String
Returns Visibility setting for the activity.
48 49 50 |
# File 'lib/getstream_ruby/generated/models/update_activity_request.rb', line 48 def visibility @visibility end |
#visibility_tag ⇒ String
Returns If visibility is ‘tag’, this is the tag name and is required.
51 52 53 |
# File 'lib/getstream_ruby/generated/models/update_activity_request.rb', line 51 def visibility_tag @visibility_tag end |
Class Method Details
.json_field_mappings ⇒ Object
Override field mappings for JSON serialization
112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 |
# File 'lib/getstream_ruby/generated/models/update_activity_request.rb', line 112 def self.json_field_mappings { copy_custom_to_notification: 'copy_custom_to_notification', enrich_own_fields: 'enrich_own_fields', expires_at: 'expires_at', force_moderation: 'force_moderation', handle_mention_notifications: 'handle_mention_notifications', poll_id: 'poll_id', restrict_replies: 'restrict_replies', run_activity_processors: 'run_activity_processors', skip_enrich_url: 'skip_enrich_url', text: 'text', user_id: 'user_id', visibility: 'visibility', visibility_tag: 'visibility_tag', attachments: 'attachments', collection_refs: 'collection_refs', feeds: 'feeds', filter_tags: 'filter_tags', interest_tags: 'interest_tags', mentioned_user_ids: 'mentioned_user_ids', custom: 'custom', location: 'location', search_data: 'search_data', user: 'user' } end |