Class: GetStream::Generated::Models::UpdateActivityRequest

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/getstream_ruby/generated/models/update_activity_request.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#==, #inspect, omit_empty_fields, #to_h, #to_json

Constructor Details

#initialize(attributes = {}) ⇒ UpdateActivityRequest

Initialize with attributes



80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
# File 'lib/getstream_ruby/generated/models/update_activity_request.rb', line 80

def initialize(attributes = {})
  super(attributes)
  @copy_custom_to_notification = attributes[:copy_custom_to_notification] || attributes['copy_custom_to_notification'] || nil
  @enrich_own_fields = attributes[:enrich_own_fields] || attributes['enrich_own_fields'] || nil
  @expires_at = attributes[:expires_at] || attributes['expires_at'] || nil
  @handle_mention_notifications = attributes[:handle_mention_notifications] || attributes['handle_mention_notifications'] || nil
  @poll_id = attributes[:poll_id] || attributes['poll_id'] || nil
  @restrict_replies = attributes[:restrict_replies] || attributes['restrict_replies'] || nil
  @run_activity_processors = attributes[:run_activity_processors] || attributes['run_activity_processors'] || nil
  @skip_enrich_url = attributes[:skip_enrich_url] || attributes['skip_enrich_url'] || nil
  @text = attributes[:text] || attributes['text'] || nil
  @user_id = attributes[:user_id] || attributes['user_id'] || nil
  @visibility = attributes[:visibility] || attributes['visibility'] || nil
  @visibility_tag = attributes[:visibility_tag] || attributes['visibility_tag'] || nil
  @attachments = attributes[:attachments] || attributes['attachments'] || nil
  @collection_refs = attributes[:collection_refs] || attributes['collection_refs'] || nil
  @feeds = attributes[:feeds] || attributes['feeds'] || nil
  @filter_tags = attributes[:filter_tags] || attributes['filter_tags'] || nil
  @interest_tags = attributes[:interest_tags] || attributes['interest_tags'] || nil
  @mentioned_user_ids = attributes[:mentioned_user_ids] || attributes['mentioned_user_ids'] || nil
  @custom = attributes[:custom] || attributes['custom'] || nil
  @location = attributes[:location] || attributes['location'] || nil
  @search_data = attributes[:search_data] || attributes['search_data'] || nil
  @user = attributes[:user] || attributes['user'] || nil
end

Instance Attribute Details

#attachmentsArray<Attachment>

Returns List of attachments for the activity.

Returns:

  • List of attachments for the activity



50
51
52
# File 'lib/getstream_ruby/generated/models/update_activity_request.rb', line 50

def attachments
  @attachments
end

#collection_refsArray<String>

Returns Collections that this activity references.

Returns:

  • Collections that this activity references



53
54
55
# File 'lib/getstream_ruby/generated/models/update_activity_request.rb', line 53

def collection_refs
  @collection_refs
end

#copy_custom_to_notificationBoolean

Returns Whether to copy custom data to the notification activity (only applies when handle_mention_notifications creates notifications).

Returns:

  • Whether to copy custom data to the notification activity (only applies when handle_mention_notifications creates notifications)



14
15
16
# File 'lib/getstream_ruby/generated/models/update_activity_request.rb', line 14

def copy_custom_to_notification
  @copy_custom_to_notification
end

#customObject

Returns Custom data for the activity.

Returns:

  • Custom data for the activity



68
69
70
# File 'lib/getstream_ruby/generated/models/update_activity_request.rb', line 68

def custom
  @custom
end

#enrich_own_fieldsBoolean

Returns If true, enriches the activity’s current_feed with own_* fields (own_follows, own_followings, own_capabilities, own_membership). Defaults to false for performance.

Returns:

  • If true, enriches the activity’s current_feed with own_* fields (own_follows, own_followings, own_capabilities, own_membership). Defaults to false for performance.



17
18
19
# File 'lib/getstream_ruby/generated/models/update_activity_request.rb', line 17

def enrich_own_fields
  @enrich_own_fields
end

#expires_atDateTime

Returns Time when the activity will expire.

Returns:

  • Time when the activity will expire



20
21
22
# File 'lib/getstream_ruby/generated/models/update_activity_request.rb', line 20

def expires_at
  @expires_at
end

#feedsArray<String>

Returns List of feeds the activity is present in.

Returns:

  • List of feeds the activity is present in



56
57
58
# File 'lib/getstream_ruby/generated/models/update_activity_request.rb', line 56

def feeds
  @feeds
end

#filter_tagsArray<String>

Returns Tags used for filtering the activity.

Returns:

  • Tags used for filtering the activity



59
60
61
# File 'lib/getstream_ruby/generated/models/update_activity_request.rb', line 59

def filter_tags
  @filter_tags
end

#handle_mention_notificationsBoolean

Returns If true, creates notification activities for newly mentioned users and deletes notifications for users no longer mentioned.

Returns:

  • If true, creates notification activities for newly mentioned users and deletes notifications for users no longer mentioned



23
24
25
# File 'lib/getstream_ruby/generated/models/update_activity_request.rb', line 23

def handle_mention_notifications
  @handle_mention_notifications
end

#interest_tagsArray<String>

Returns Tags indicating interest categories.

Returns:

  • Tags indicating interest categories



62
63
64
# File 'lib/getstream_ruby/generated/models/update_activity_request.rb', line 62

def interest_tags
  @interest_tags
end

#locationActivityLocation

Returns:



71
72
73
# File 'lib/getstream_ruby/generated/models/update_activity_request.rb', line 71

def location
  @location
end

#mentioned_user_idsArray<String>

Returns List of user IDs mentioned in the activity.

Returns:

  • List of user IDs mentioned in the activity



65
66
67
# File 'lib/getstream_ruby/generated/models/update_activity_request.rb', line 65

def mentioned_user_ids
  @mentioned_user_ids
end

#poll_idString

Returns Poll ID.

Returns:

  • Poll ID



26
27
28
# File 'lib/getstream_ruby/generated/models/update_activity_request.rb', line 26

def poll_id
  @poll_id
end

#restrict_repliesString

Returns Controls who can add comments/replies to this activity. One of: everyone, people_i_follow, nobody.

Returns:

  • Controls who can add comments/replies to this activity. One of: everyone, people_i_follow, nobody



29
30
31
# File 'lib/getstream_ruby/generated/models/update_activity_request.rb', line 29

def restrict_replies
  @restrict_replies
end

#run_activity_processorsBoolean

Returns If true, runs activity processors on the updated activity. Processors will only run if the activity text and/or attachments are changed. Defaults to false.

Returns:

  • If true, runs activity processors on the updated activity. Processors will only run if the activity text and/or attachments are changed. Defaults to false.



32
33
34
# File 'lib/getstream_ruby/generated/models/update_activity_request.rb', line 32

def run_activity_processors
  @run_activity_processors
end

#search_dataObject

Returns Additional data for search indexing.

Returns:

  • Additional data for search indexing



74
75
76
# File 'lib/getstream_ruby/generated/models/update_activity_request.rb', line 74

def search_data
  @search_data
end

#skip_enrich_urlBoolean

Returns Whether to skip URL enrichment for the activity.

Returns:

  • Whether to skip URL enrichment for the activity



35
36
37
# File 'lib/getstream_ruby/generated/models/update_activity_request.rb', line 35

def skip_enrich_url
  @skip_enrich_url
end

#textString

Returns The text content of the activity.

Returns:

  • The text content of the activity



38
39
40
# File 'lib/getstream_ruby/generated/models/update_activity_request.rb', line 38

def text
  @text
end

#userUserRequest

Returns:



77
78
79
# File 'lib/getstream_ruby/generated/models/update_activity_request.rb', line 77

def user
  @user
end

#user_idString

Returns:



41
42
43
# File 'lib/getstream_ruby/generated/models/update_activity_request.rb', line 41

def user_id
  @user_id
end

#visibilityString

Returns Visibility setting for the activity.

Returns:

  • Visibility setting for the activity



44
45
46
# File 'lib/getstream_ruby/generated/models/update_activity_request.rb', line 44

def visibility
  @visibility
end

#visibility_tagString

Returns If visibility is ‘tag’, this is the tag name and is required.

Returns:

  • If visibility is ‘tag’, this is the tag name and is required



47
48
49
# File 'lib/getstream_ruby/generated/models/update_activity_request.rb', line 47

def visibility_tag
  @visibility_tag
end

Class Method Details

.json_field_mappingsObject

Override field mappings for JSON serialization



107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
# File 'lib/getstream_ruby/generated/models/update_activity_request.rb', line 107

def self.json_field_mappings
  {
    copy_custom_to_notification: 'copy_custom_to_notification',
    enrich_own_fields: 'enrich_own_fields',
    expires_at: 'expires_at',
    handle_mention_notifications: 'handle_mention_notifications',
    poll_id: 'poll_id',
    restrict_replies: 'restrict_replies',
    run_activity_processors: 'run_activity_processors',
    skip_enrich_url: 'skip_enrich_url',
    text: 'text',
    user_id: 'user_id',
    visibility: 'visibility',
    visibility_tag: 'visibility_tag',
    attachments: 'attachments',
    collection_refs: 'collection_refs',
    feeds: 'feeds',
    filter_tags: 'filter_tags',
    interest_tags: 'interest_tags',
    mentioned_user_ids: 'mentioned_user_ids',
    custom: 'custom',
    location: 'location',
    search_data: 'search_data',
    user: 'user'
  }
end