Class: GetStream::Generated::Models::UpdateActivityRequest
- Defined in:
- lib/getstream_ruby/generated/models/update_activity_request.rb
Instance Attribute Summary collapse
-
#attachments ⇒ Array<Attachment>
List of attachments for the activity.
-
#collection_refs ⇒ Array<String>
Collections that this activity references.
-
#copy_custom_to_notification ⇒ Boolean
Whether to copy custom data to the notification activity (only applies when handle_mention_notifications creates notifications).
-
#custom ⇒ Object
Custom data for the activity.
-
#enrich_own_fields ⇒ Boolean
If true, enriches the activity’s current_feed with own_* fields (own_follows, own_followings, own_capabilities, own_membership).
-
#expires_at ⇒ DateTime
Time when the activity will expire.
-
#feeds ⇒ Array<String>
List of feeds the activity is present in.
-
#filter_tags ⇒ Array<String>
Tags used for filtering the activity.
-
#handle_mention_notifications ⇒ Boolean
If true, creates notification activities for newly mentioned users and deletes notifications for users no longer mentioned.
-
#interest_tags ⇒ Array<String>
Tags indicating interest categories.
- #location ⇒ ActivityLocation
-
#mentioned_user_ids ⇒ Array<String>
List of user IDs mentioned in the activity.
-
#poll_id ⇒ String
Poll ID.
-
#restrict_replies ⇒ String
Controls who can add comments/replies to this activity.
-
#run_activity_processors ⇒ Boolean
If true, runs activity processors on the updated activity.
-
#search_data ⇒ Object
Additional data for search indexing.
-
#skip_enrich_url ⇒ Boolean
Whether to skip URL enrichment for the activity.
-
#text ⇒ String
The text content of the activity.
- #user ⇒ UserRequest
- #user_id ⇒ String
-
#visibility ⇒ String
Visibility setting for the activity.
-
#visibility_tag ⇒ String
If visibility is ‘tag’, this is the tag name and is required.
Class Method Summary collapse
-
.json_field_mappings ⇒ Object
Override field mappings for JSON serialization.
Instance Method Summary collapse
-
#initialize(attributes = {}) ⇒ UpdateActivityRequest
constructor
Initialize with attributes.
Methods inherited from BaseModel
#==, #inspect, omit_empty_fields, #to_h, #to_json
Constructor Details
#initialize(attributes = {}) ⇒ UpdateActivityRequest
Initialize with attributes
80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 |
# File 'lib/getstream_ruby/generated/models/update_activity_request.rb', line 80 def initialize(attributes = {}) super(attributes) @copy_custom_to_notification = attributes[:copy_custom_to_notification] || attributes['copy_custom_to_notification'] || nil @enrich_own_fields = attributes[:enrich_own_fields] || attributes['enrich_own_fields'] || nil @expires_at = attributes[:expires_at] || attributes['expires_at'] || nil @handle_mention_notifications = attributes[:handle_mention_notifications] || attributes['handle_mention_notifications'] || nil @poll_id = attributes[:poll_id] || attributes['poll_id'] || nil @restrict_replies = attributes[:restrict_replies] || attributes['restrict_replies'] || nil @run_activity_processors = attributes[:run_activity_processors] || attributes['run_activity_processors'] || nil @skip_enrich_url = attributes[:skip_enrich_url] || attributes['skip_enrich_url'] || nil @text = attributes[:text] || attributes['text'] || nil @user_id = attributes[:user_id] || attributes['user_id'] || nil @visibility = attributes[:visibility] || attributes['visibility'] || nil @visibility_tag = attributes[:visibility_tag] || attributes['visibility_tag'] || nil = attributes[:attachments] || attributes['attachments'] || nil @collection_refs = attributes[:collection_refs] || attributes['collection_refs'] || nil @feeds = attributes[:feeds] || attributes['feeds'] || nil = attributes[:filter_tags] || attributes['filter_tags'] || nil = attributes[:interest_tags] || attributes['interest_tags'] || nil @mentioned_user_ids = attributes[:mentioned_user_ids] || attributes['mentioned_user_ids'] || nil @custom = attributes[:custom] || attributes['custom'] || nil @location = attributes[:location] || attributes['location'] || nil @search_data = attributes[:search_data] || attributes['search_data'] || nil @user = attributes[:user] || attributes['user'] || nil end |
Instance Attribute Details
#attachments ⇒ Array<Attachment>
Returns List of attachments for the activity.
50 51 52 |
# File 'lib/getstream_ruby/generated/models/update_activity_request.rb', line 50 def end |
#collection_refs ⇒ Array<String>
Returns Collections that this activity references.
53 54 55 |
# File 'lib/getstream_ruby/generated/models/update_activity_request.rb', line 53 def collection_refs @collection_refs end |
#copy_custom_to_notification ⇒ Boolean
Returns Whether to copy custom data to the notification activity (only applies when handle_mention_notifications creates notifications).
14 15 16 |
# File 'lib/getstream_ruby/generated/models/update_activity_request.rb', line 14 def copy_custom_to_notification @copy_custom_to_notification end |
#custom ⇒ Object
Returns Custom data for the activity.
68 69 70 |
# File 'lib/getstream_ruby/generated/models/update_activity_request.rb', line 68 def custom @custom end |
#enrich_own_fields ⇒ Boolean
Returns If true, enriches the activity’s current_feed with own_* fields (own_follows, own_followings, own_capabilities, own_membership). Defaults to false for performance.
17 18 19 |
# File 'lib/getstream_ruby/generated/models/update_activity_request.rb', line 17 def enrich_own_fields @enrich_own_fields end |
#expires_at ⇒ DateTime
Returns Time when the activity will expire.
20 21 22 |
# File 'lib/getstream_ruby/generated/models/update_activity_request.rb', line 20 def expires_at @expires_at end |
#feeds ⇒ Array<String>
Returns List of feeds the activity is present in.
56 57 58 |
# File 'lib/getstream_ruby/generated/models/update_activity_request.rb', line 56 def feeds @feeds end |
#filter_tags ⇒ Array<String>
Returns Tags used for filtering the activity.
59 60 61 |
# File 'lib/getstream_ruby/generated/models/update_activity_request.rb', line 59 def end |
#handle_mention_notifications ⇒ Boolean
Returns If true, creates notification activities for newly mentioned users and deletes notifications for users no longer mentioned.
23 24 25 |
# File 'lib/getstream_ruby/generated/models/update_activity_request.rb', line 23 def handle_mention_notifications @handle_mention_notifications end |
#interest_tags ⇒ Array<String>
Returns Tags indicating interest categories.
62 63 64 |
# File 'lib/getstream_ruby/generated/models/update_activity_request.rb', line 62 def end |
#location ⇒ ActivityLocation
71 72 73 |
# File 'lib/getstream_ruby/generated/models/update_activity_request.rb', line 71 def location @location end |
#mentioned_user_ids ⇒ Array<String>
Returns List of user IDs mentioned in the activity.
65 66 67 |
# File 'lib/getstream_ruby/generated/models/update_activity_request.rb', line 65 def mentioned_user_ids @mentioned_user_ids end |
#poll_id ⇒ String
Returns Poll ID.
26 27 28 |
# File 'lib/getstream_ruby/generated/models/update_activity_request.rb', line 26 def poll_id @poll_id end |
#restrict_replies ⇒ String
Returns Controls who can add comments/replies to this activity. One of: everyone, people_i_follow, nobody.
29 30 31 |
# File 'lib/getstream_ruby/generated/models/update_activity_request.rb', line 29 def restrict_replies @restrict_replies end |
#run_activity_processors ⇒ Boolean
Returns If true, runs activity processors on the updated activity. Processors will only run if the activity text and/or attachments are changed. Defaults to false.
32 33 34 |
# File 'lib/getstream_ruby/generated/models/update_activity_request.rb', line 32 def run_activity_processors @run_activity_processors end |
#search_data ⇒ Object
Returns Additional data for search indexing.
74 75 76 |
# File 'lib/getstream_ruby/generated/models/update_activity_request.rb', line 74 def search_data @search_data end |
#skip_enrich_url ⇒ Boolean
Returns Whether to skip URL enrichment for the activity.
35 36 37 |
# File 'lib/getstream_ruby/generated/models/update_activity_request.rb', line 35 def skip_enrich_url @skip_enrich_url end |
#text ⇒ String
Returns The text content of the activity.
38 39 40 |
# File 'lib/getstream_ruby/generated/models/update_activity_request.rb', line 38 def text @text end |
#user ⇒ UserRequest
77 78 79 |
# File 'lib/getstream_ruby/generated/models/update_activity_request.rb', line 77 def user @user end |
#user_id ⇒ String
41 42 43 |
# File 'lib/getstream_ruby/generated/models/update_activity_request.rb', line 41 def user_id @user_id end |
#visibility ⇒ String
Returns Visibility setting for the activity.
44 45 46 |
# File 'lib/getstream_ruby/generated/models/update_activity_request.rb', line 44 def visibility @visibility end |
#visibility_tag ⇒ String
Returns If visibility is ‘tag’, this is the tag name and is required.
47 48 49 |
# File 'lib/getstream_ruby/generated/models/update_activity_request.rb', line 47 def visibility_tag @visibility_tag end |
Class Method Details
.json_field_mappings ⇒ Object
Override field mappings for JSON serialization
107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 |
# File 'lib/getstream_ruby/generated/models/update_activity_request.rb', line 107 def self.json_field_mappings { copy_custom_to_notification: 'copy_custom_to_notification', enrich_own_fields: 'enrich_own_fields', expires_at: 'expires_at', handle_mention_notifications: 'handle_mention_notifications', poll_id: 'poll_id', restrict_replies: 'restrict_replies', run_activity_processors: 'run_activity_processors', skip_enrich_url: 'skip_enrich_url', text: 'text', user_id: 'user_id', visibility: 'visibility', visibility_tag: 'visibility_tag', attachments: 'attachments', collection_refs: 'collection_refs', feeds: 'feeds', filter_tags: 'filter_tags', interest_tags: 'interest_tags', mentioned_user_ids: 'mentioned_user_ids', custom: 'custom', location: 'location', search_data: 'search_data', user: 'user' } end |