Class: GetStream::Generated::Models::UpdateCommentPartialRequest
- Inherits:
-
BaseModel
- Object
- BaseModel
- GetStream::Generated::Models::UpdateCommentPartialRequest
- Defined in:
- lib/getstream_ruby/generated/models/update_comment_partial_request.rb
Instance Attribute Summary collapse
-
#copy_custom_to_notification ⇒ Object
deprecated
Deprecated.
This field is deprecated. @return [Boolean] Whether to copy custom data to notification activities Deprecated: use notification_context.trigger.custom and notification_context.target.custom instead
-
#force_moderation ⇒ Boolean
If true, forces moderation to run for server-side requests.
-
#handle_mention_notifications ⇒ Boolean
Whether to handle mention notification changes.
-
#set ⇒ Object
Map of field names to new values.
-
#skip_enrich_url ⇒ Boolean
Whether to skip URL enrichment.
-
#skip_push ⇒ Boolean
Whether to skip push notifications.
-
#unset ⇒ Array<String>
List of field names to remove.
- #user ⇒ UserRequest
- #user_id ⇒ String
Class Method Summary collapse
-
.json_field_mappings ⇒ Object
Override field mappings for JSON serialization.
Instance Method Summary collapse
-
#initialize(attributes = {}) ⇒ UpdateCommentPartialRequest
constructor
Initialize with attributes.
Methods inherited from BaseModel
#==, #inspect, omit_empty_fields, #to_h, #to_json
Constructor Details
#initialize(attributes = {}) ⇒ UpdateCommentPartialRequest
Initialize with attributes
42 43 44 45 46 47 48 49 50 51 52 53 |
# File 'lib/getstream_ruby/generated/models/update_comment_partial_request.rb', line 42 def initialize(attributes = {}) super(attributes) @copy_custom_to_notification = attributes[:copy_custom_to_notification] || attributes['copy_custom_to_notification'] || nil @force_moderation = attributes[:force_moderation] || attributes['force_moderation'] || nil @handle_mention_notifications = attributes[:handle_mention_notifications] || attributes['handle_mention_notifications'] || nil @skip_enrich_url = attributes[:skip_enrich_url] || attributes['skip_enrich_url'] || nil @skip_push = attributes[:skip_push] || attributes['skip_push'] || nil @user_id = attributes[:user_id] || attributes['user_id'] || nil @unset = attributes[:unset] || attributes['unset'] || nil @set = attributes[:set] || attributes['set'] || nil @user = attributes[:user] || attributes['user'] || nil end |
Instance Attribute Details
#copy_custom_to_notification ⇒ Object
This field is deprecated. @return [Boolean] Whether to copy custom data to notification activities Deprecated: use notification_context.trigger.custom and notification_context.target.custom instead
Model attributes
15 16 17 |
# File 'lib/getstream_ruby/generated/models/update_comment_partial_request.rb', line 15 def copy_custom_to_notification @copy_custom_to_notification end |
#force_moderation ⇒ Boolean
Returns If true, forces moderation to run for server-side requests. By default, server-side requests skip moderation. Client-side requests always run moderation regardless of this field.
18 19 20 |
# File 'lib/getstream_ruby/generated/models/update_comment_partial_request.rb', line 18 def force_moderation @force_moderation end |
#handle_mention_notifications ⇒ Boolean
Returns Whether to handle mention notification changes.
21 22 23 |
# File 'lib/getstream_ruby/generated/models/update_comment_partial_request.rb', line 21 def handle_mention_notifications @handle_mention_notifications end |
#set ⇒ Object
Returns Map of field names to new values. Supported fields: ‘text’, ‘attachments’, ‘custom’, ‘mentioned_user_ids’, ‘status’. Use dot-notation for nested custom fields (e.g., ‘custom.field_name’).
36 37 38 |
# File 'lib/getstream_ruby/generated/models/update_comment_partial_request.rb', line 36 def set @set end |
#skip_enrich_url ⇒ Boolean
Returns Whether to skip URL enrichment.
24 25 26 |
# File 'lib/getstream_ruby/generated/models/update_comment_partial_request.rb', line 24 def skip_enrich_url @skip_enrich_url end |
#skip_push ⇒ Boolean
Returns Whether to skip push notifications.
27 28 29 |
# File 'lib/getstream_ruby/generated/models/update_comment_partial_request.rb', line 27 def skip_push @skip_push end |
#unset ⇒ Array<String>
Returns List of field names to remove. Supported fields: ‘custom’, ‘attachments’, ‘mentioned_user_ids’, ‘status’. Use dot-notation for nested custom fields (e.g., ‘custom.field_name’).
33 34 35 |
# File 'lib/getstream_ruby/generated/models/update_comment_partial_request.rb', line 33 def unset @unset end |
#user ⇒ UserRequest
39 40 41 |
# File 'lib/getstream_ruby/generated/models/update_comment_partial_request.rb', line 39 def user @user end |
#user_id ⇒ String
30 31 32 |
# File 'lib/getstream_ruby/generated/models/update_comment_partial_request.rb', line 30 def user_id @user_id end |
Class Method Details
.json_field_mappings ⇒ Object
Override field mappings for JSON serialization
56 57 58 59 60 61 62 63 64 65 66 67 68 |
# File 'lib/getstream_ruby/generated/models/update_comment_partial_request.rb', line 56 def self.json_field_mappings { copy_custom_to_notification: 'copy_custom_to_notification', force_moderation: 'force_moderation', handle_mention_notifications: 'handle_mention_notifications', skip_enrich_url: 'skip_enrich_url', skip_push: 'skip_push', user_id: 'user_id', unset: 'unset', set: 'set', user: 'user' } end |