Class: GetStream::Generated::Models::UpdateCommentRequest
- Defined in:
- lib/getstream_ruby/generated/models/update_comment_request.rb
Instance Attribute Summary collapse
-
#attachments ⇒ Array<Attachment>
Updated media attachments for the comment.
-
#comment ⇒ String
Updated text content of the comment.
-
#copy_custom_to_notification ⇒ Object
deprecated
Deprecated.
This field is deprecated. @return [Boolean] Whether to copy custom data to the notification activity (only applies when handle_mention_notifications creates notifications) Deprecated: use notification_context.trigger.custom and notification_context.target.custom instead
-
#custom ⇒ Object
Updated custom data for the comment.
-
#force_moderation ⇒ Boolean
If true, forces moderation to run for server-side requests.
-
#handle_mention_notifications ⇒ Boolean
If true, creates notification activities for newly mentioned users and deletes notifications for users no longer mentioned.
-
#mentioned_user_ids ⇒ Array<String>
List of user IDs mentioned in the comment.
-
#skip_enrich_url ⇒ Boolean
Whether to skip URL enrichment for this comment.
- #skip_push ⇒ Boolean
- #user ⇒ UserRequest
- #user_id ⇒ String
Class Method Summary collapse
-
.json_field_mappings ⇒ Object
Override field mappings for JSON serialization.
Instance Method Summary collapse
-
#initialize(attributes = {}) ⇒ UpdateCommentRequest
constructor
Initialize with attributes.
Methods inherited from BaseModel
#==, #inspect, omit_empty_fields, #to_h, #to_json
Constructor Details
#initialize(attributes = {}) ⇒ UpdateCommentRequest
Initialize with attributes
48 49 50 51 52 53 54 55 56 57 58 59 60 61 |
# File 'lib/getstream_ruby/generated/models/update_comment_request.rb', line 48 def initialize(attributes = {}) super(attributes) @comment = attributes[:comment] || attributes['comment'] || nil @copy_custom_to_notification = attributes[:copy_custom_to_notification] || attributes['copy_custom_to_notification'] || nil @force_moderation = attributes[:force_moderation] || attributes['force_moderation'] || nil @handle_mention_notifications = attributes[:handle_mention_notifications] || attributes['handle_mention_notifications'] || nil @skip_enrich_url = attributes[:skip_enrich_url] || attributes['skip_enrich_url'] || nil @skip_push = attributes[:skip_push] || attributes['skip_push'] || nil @user_id = attributes[:user_id] || attributes['user_id'] || nil @attachments = attributes[:attachments] || attributes['attachments'] || nil @mentioned_user_ids = attributes[:mentioned_user_ids] || attributes['mentioned_user_ids'] || nil @custom = attributes[:custom] || attributes['custom'] || nil @user = attributes[:user] || attributes['user'] || nil end |
Instance Attribute Details
#attachments ⇒ Array<Attachment>
Returns Updated media attachments for the comment. Providing this field will replace all existing attachments.
36 37 38 |
# File 'lib/getstream_ruby/generated/models/update_comment_request.rb', line 36 def @attachments end |
#comment ⇒ String
Returns Updated text content of the comment.
14 15 16 |
# File 'lib/getstream_ruby/generated/models/update_comment_request.rb', line 14 def comment @comment end |
#copy_custom_to_notification ⇒ Object
This field is deprecated. @return [Boolean] Whether to copy custom data to the notification activity (only applies when handle_mention_notifications creates notifications) Deprecated: use notification_context.trigger.custom and notification_context.target.custom instead
18 19 20 |
# File 'lib/getstream_ruby/generated/models/update_comment_request.rb', line 18 def copy_custom_to_notification @copy_custom_to_notification end |
#custom ⇒ Object
Returns Updated custom data for the comment.
42 43 44 |
# File 'lib/getstream_ruby/generated/models/update_comment_request.rb', line 42 def custom @custom end |
#force_moderation ⇒ Boolean
Returns If true, forces moderation to run for server-side requests. By default, server-side requests skip moderation. Client-side requests always run moderation regardless of this field.
21 22 23 |
# File 'lib/getstream_ruby/generated/models/update_comment_request.rb', line 21 def force_moderation @force_moderation end |
#handle_mention_notifications ⇒ Boolean
Returns If true, creates notification activities for newly mentioned users and deletes notifications for users no longer mentioned.
24 25 26 |
# File 'lib/getstream_ruby/generated/models/update_comment_request.rb', line 24 def handle_mention_notifications @handle_mention_notifications end |
#mentioned_user_ids ⇒ Array<String>
Returns List of user IDs mentioned in the comment.
39 40 41 |
# File 'lib/getstream_ruby/generated/models/update_comment_request.rb', line 39 def mentioned_user_ids @mentioned_user_ids end |
#skip_enrich_url ⇒ Boolean
Returns Whether to skip URL enrichment for this comment.
27 28 29 |
# File 'lib/getstream_ruby/generated/models/update_comment_request.rb', line 27 def skip_enrich_url @skip_enrich_url end |
#skip_push ⇒ Boolean
30 31 32 |
# File 'lib/getstream_ruby/generated/models/update_comment_request.rb', line 30 def skip_push @skip_push end |
#user ⇒ UserRequest
45 46 47 |
# File 'lib/getstream_ruby/generated/models/update_comment_request.rb', line 45 def user @user end |
#user_id ⇒ String
33 34 35 |
# File 'lib/getstream_ruby/generated/models/update_comment_request.rb', line 33 def user_id @user_id end |
Class Method Details
.json_field_mappings ⇒ Object
Override field mappings for JSON serialization
64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'lib/getstream_ruby/generated/models/update_comment_request.rb', line 64 def self.json_field_mappings { comment: 'comment', copy_custom_to_notification: 'copy_custom_to_notification', force_moderation: 'force_moderation', handle_mention_notifications: 'handle_mention_notifications', skip_enrich_url: 'skip_enrich_url', skip_push: 'skip_push', user_id: 'user_id', attachments: 'attachments', mentioned_user_ids: 'mentioned_user_ids', custom: 'custom', user: 'user' } end |