Class: GetStream::Generated::Models::UpdateCommentRequest

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/getstream_ruby/generated/models/update_comment_request.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#==, #inspect, omit_empty_fields, #to_h, #to_json

Constructor Details

#initialize(attributes = {}) ⇒ UpdateCommentRequest

Initialize with attributes



44
45
46
47
48
49
50
51
52
53
54
55
56
# File 'lib/getstream_ruby/generated/models/update_comment_request.rb', line 44

def initialize(attributes = {})
  super(attributes)
  @comment = attributes[:comment] || attributes['comment'] || nil
  @copy_custom_to_notification = attributes[:copy_custom_to_notification] || attributes['copy_custom_to_notification'] || nil
  @handle_mention_notifications = attributes[:handle_mention_notifications] || attributes['handle_mention_notifications'] || nil
  @skip_enrich_url = attributes[:skip_enrich_url] || attributes['skip_enrich_url'] || nil
  @skip_push = attributes[:skip_push] || attributes['skip_push'] || nil
  @user_id = attributes[:user_id] || attributes['user_id'] || nil
  @attachments = attributes[:attachments] || attributes['attachments'] || nil
  @mentioned_user_ids = attributes[:mentioned_user_ids] || attributes['mentioned_user_ids'] || nil
  @custom = attributes[:custom] || attributes['custom'] || nil
  @user = attributes[:user] || attributes['user'] || nil
end

Instance Attribute Details

#attachmentsArray<Attachment>

Returns Updated media attachments for the comment. Providing this field will replace all existing attachments.

Returns:

  • (Array<Attachment>)

    Updated media attachments for the comment. Providing this field will replace all existing attachments.



32
33
34
# File 'lib/getstream_ruby/generated/models/update_comment_request.rb', line 32

def attachments
  @attachments
end

#commentString

Returns Updated text content of the comment.

Returns:

  • (String)

    Updated text content of the comment



14
15
16
# File 'lib/getstream_ruby/generated/models/update_comment_request.rb', line 14

def comment
  @comment
end

#copy_custom_to_notificationBoolean

Returns Whether to copy custom data to the notification activity (only applies when handle_mention_notifications creates notifications).

Returns:

  • (Boolean)

    Whether to copy custom data to the notification activity (only applies when handle_mention_notifications creates notifications)



17
18
19
# File 'lib/getstream_ruby/generated/models/update_comment_request.rb', line 17

def copy_custom_to_notification
  @copy_custom_to_notification
end

#customObject

Returns Updated custom data for the comment.

Returns:

  • (Object)

    Updated custom data for the comment



38
39
40
# File 'lib/getstream_ruby/generated/models/update_comment_request.rb', line 38

def custom
  @custom
end

#handle_mention_notificationsBoolean

Returns If true, creates notification activities for newly mentioned users and deletes notifications for users no longer mentioned.

Returns:

  • (Boolean)

    If true, creates notification activities for newly mentioned users and deletes notifications for users no longer mentioned



20
21
22
# File 'lib/getstream_ruby/generated/models/update_comment_request.rb', line 20

def handle_mention_notifications
  @handle_mention_notifications
end

#mentioned_user_idsArray<String>

Returns List of user IDs mentioned in the comment.

Returns:

  • (Array<String>)

    List of user IDs mentioned in the comment



35
36
37
# File 'lib/getstream_ruby/generated/models/update_comment_request.rb', line 35

def mentioned_user_ids
  @mentioned_user_ids
end

#skip_enrich_urlBoolean

Returns Whether to skip URL enrichment for this comment.

Returns:

  • (Boolean)

    Whether to skip URL enrichment for this comment



23
24
25
# File 'lib/getstream_ruby/generated/models/update_comment_request.rb', line 23

def skip_enrich_url
  @skip_enrich_url
end

#skip_pushBoolean

Returns:

  • (Boolean)


26
27
28
# File 'lib/getstream_ruby/generated/models/update_comment_request.rb', line 26

def skip_push
  @skip_push
end

#userUserRequest

Returns:



41
42
43
# File 'lib/getstream_ruby/generated/models/update_comment_request.rb', line 41

def user
  @user
end

#user_idString

Returns:

  • (String)


29
30
31
# File 'lib/getstream_ruby/generated/models/update_comment_request.rb', line 29

def user_id
  @user_id
end

Class Method Details

.json_field_mappingsObject

Override field mappings for JSON serialization



59
60
61
62
63
64
65
66
67
68
69
70
71
72
# File 'lib/getstream_ruby/generated/models/update_comment_request.rb', line 59

def self.json_field_mappings
  {
    comment: 'comment',
    copy_custom_to_notification: 'copy_custom_to_notification',
    handle_mention_notifications: 'handle_mention_notifications',
    skip_enrich_url: 'skip_enrich_url',
    skip_push: 'skip_push',
    user_id: 'user_id',
    attachments: 'attachments',
    mentioned_user_ids: 'mentioned_user_ids',
    custom: 'custom',
    user: 'user'
  }
end