Class: GetStream::Generated::Models::UpdateFollowRequest
- Defined in:
- lib/getstream_ruby/generated/models/update_follow_request.rb
Instance Attribute Summary collapse
-
#copy_custom_to_notification ⇒ Boolean
Whether to copy custom data to the notification activity (only applies when create_notification_activity is true).
-
#create_notification_activity ⇒ Boolean
Whether to create a notification activity for this follow.
-
#custom ⇒ Object
Custom data for the follow relationship.
-
#enrich_own_fields ⇒ Boolean
If true, enriches the follow’s source_feed and target_feed with own_* fields (own_follows, own_followings, own_capabilities, own_membership).
- #follower_role ⇒ String
-
#push_preference ⇒ String
Push preference for the follow relationship.
-
#skip_push ⇒ Boolean
Whether to skip push for this follow.
-
#source ⇒ String
Fully qualified ID of the source feed.
-
#status ⇒ String
Status of the follow relationship.
-
#target ⇒ String
Fully qualified ID of the target feed.
Class Method Summary collapse
-
.json_field_mappings ⇒ Object
Override field mappings for JSON serialization.
Instance Method Summary collapse
-
#initialize(attributes = {}) ⇒ UpdateFollowRequest
constructor
Initialize with attributes.
Methods inherited from BaseModel
#==, #inspect, omit_empty_fields, #to_h, #to_json
Constructor Details
#initialize(attributes = {}) ⇒ UpdateFollowRequest
Initialize with attributes
44 45 46 47 48 49 50 51 52 53 54 55 56 |
# File 'lib/getstream_ruby/generated/models/update_follow_request.rb', line 44 def initialize(attributes = {}) super(attributes) @source = attributes[:source] || attributes['source'] @target = attributes[:target] || attributes['target'] @copy_custom_to_notification = attributes[:copy_custom_to_notification] || attributes['copy_custom_to_notification'] || nil @create_notification_activity = attributes[:create_notification_activity] || attributes['create_notification_activity'] || nil @enrich_own_fields = attributes[:enrich_own_fields] || attributes['enrich_own_fields'] || nil @follower_role = attributes[:follower_role] || attributes['follower_role'] || nil @push_preference = attributes[:push_preference] || attributes['push_preference'] || nil @skip_push = attributes[:skip_push] || attributes['skip_push'] || nil @status = attributes[:status] || attributes['status'] || nil @custom = attributes[:custom] || attributes['custom'] || nil end |
Instance Attribute Details
#copy_custom_to_notification ⇒ Boolean
Returns Whether to copy custom data to the notification activity (only applies when create_notification_activity is true).
20 21 22 |
# File 'lib/getstream_ruby/generated/models/update_follow_request.rb', line 20 def copy_custom_to_notification @copy_custom_to_notification end |
#create_notification_activity ⇒ Boolean
Returns Whether to create a notification activity for this follow.
23 24 25 |
# File 'lib/getstream_ruby/generated/models/update_follow_request.rb', line 23 def create_notification_activity @create_notification_activity end |
#custom ⇒ Object
Returns Custom data for the follow relationship.
41 42 43 |
# File 'lib/getstream_ruby/generated/models/update_follow_request.rb', line 41 def custom @custom end |
#enrich_own_fields ⇒ Boolean
Returns If true, enriches the follow’s source_feed and target_feed with own_* fields (own_follows, own_followings, own_capabilities, own_membership). Defaults to false for performance.
26 27 28 |
# File 'lib/getstream_ruby/generated/models/update_follow_request.rb', line 26 def enrich_own_fields @enrich_own_fields end |
#follower_role ⇒ String
29 30 31 |
# File 'lib/getstream_ruby/generated/models/update_follow_request.rb', line 29 def follower_role @follower_role end |
#push_preference ⇒ String
Returns Push preference for the follow relationship.
32 33 34 |
# File 'lib/getstream_ruby/generated/models/update_follow_request.rb', line 32 def push_preference @push_preference end |
#skip_push ⇒ Boolean
Returns Whether to skip push for this follow.
35 36 37 |
# File 'lib/getstream_ruby/generated/models/update_follow_request.rb', line 35 def skip_push @skip_push end |
#source ⇒ String
Returns Fully qualified ID of the source feed.
14 15 16 |
# File 'lib/getstream_ruby/generated/models/update_follow_request.rb', line 14 def source @source end |
#status ⇒ String
Returns Status of the follow relationship. One of: accepted, pending, rejected.
38 39 40 |
# File 'lib/getstream_ruby/generated/models/update_follow_request.rb', line 38 def status @status end |
#target ⇒ String
Returns Fully qualified ID of the target feed.
17 18 19 |
# File 'lib/getstream_ruby/generated/models/update_follow_request.rb', line 17 def target @target end |
Class Method Details
.json_field_mappings ⇒ Object
Override field mappings for JSON serialization
59 60 61 62 63 64 65 66 67 68 69 70 71 72 |
# File 'lib/getstream_ruby/generated/models/update_follow_request.rb', line 59 def self.json_field_mappings { source: 'source', target: 'target', copy_custom_to_notification: 'copy_custom_to_notification', create_notification_activity: 'create_notification_activity', enrich_own_fields: 'enrich_own_fields', follower_role: 'follower_role', push_preference: 'push_preference', skip_push: 'skip_push', status: 'status', custom: 'custom' } end |