Class: GetStream::Generated::Models::UserUnreadReminderEvent
- Defined in:
- lib/getstream_ruby/generated/models/user_unread_reminder_event.rb
Overview
Reminder events allow you to notify your users about unread messages. Reminders can be used to trigger an email, push notification or SMS to the user.
Instance Attribute Summary collapse
-
#channels ⇒ Hash<String, ChannelMessagesResponse>
The channels with unread messages.
-
#created_at ⇒ DateTime
Date/time of creation.
- #custom ⇒ Object
- #received_at ⇒ DateTime
-
#type ⇒ String
The type of event: “user.unread_message_reminder” in this case.
- #user ⇒ UserResponseCommonFields
Class Method Summary collapse
-
.json_field_mappings ⇒ Object
Override field mappings for JSON serialization.
Instance Method Summary collapse
-
#initialize(attributes = {}) ⇒ UserUnreadReminderEvent
constructor
Initialize with attributes.
Methods inherited from BaseModel
#==, #inspect, omit_empty_fields, #to_h, #to_json
Constructor Details
#initialize(attributes = {}) ⇒ UserUnreadReminderEvent
Initialize with attributes
32 33 34 35 36 37 38 39 40 |
# File 'lib/getstream_ruby/generated/models/user_unread_reminder_event.rb', line 32 def initialize(attributes = {}) super(attributes) @created_at = attributes[:created_at] || attributes['created_at'] @channels = attributes[:channels] || attributes['channels'] @custom = attributes[:custom] || attributes['custom'] @user = attributes[:user] || attributes['user'] @type = attributes[:type] || attributes['type'] || "user.unread_message_reminder" @received_at = attributes[:received_at] || attributes['received_at'] || nil end |
Instance Attribute Details
#channels ⇒ Hash<String, ChannelMessagesResponse>
Returns The channels with unread messages.
17 18 19 |
# File 'lib/getstream_ruby/generated/models/user_unread_reminder_event.rb', line 17 def channels @channels end |
#created_at ⇒ DateTime
Returns Date/time of creation.
14 15 16 |
# File 'lib/getstream_ruby/generated/models/user_unread_reminder_event.rb', line 14 def created_at @created_at end |
#custom ⇒ Object
20 21 22 |
# File 'lib/getstream_ruby/generated/models/user_unread_reminder_event.rb', line 20 def custom @custom end |
#received_at ⇒ DateTime
29 30 31 |
# File 'lib/getstream_ruby/generated/models/user_unread_reminder_event.rb', line 29 def received_at @received_at end |
#type ⇒ String
Returns The type of event: “user.unread_message_reminder” in this case.
26 27 28 |
# File 'lib/getstream_ruby/generated/models/user_unread_reminder_event.rb', line 26 def type @type end |
#user ⇒ UserResponseCommonFields
23 24 25 |
# File 'lib/getstream_ruby/generated/models/user_unread_reminder_event.rb', line 23 def user @user end |
Class Method Details
.json_field_mappings ⇒ Object
Override field mappings for JSON serialization
43 44 45 46 47 48 49 50 51 52 |
# File 'lib/getstream_ruby/generated/models/user_unread_reminder_event.rb', line 43 def self.json_field_mappings { created_at: 'created_at', channels: 'channels', custom: 'custom', user: 'user', type: 'type', received_at: 'received_at' } end |