Class: GetStream::Generated::VideoClient
- Inherits:
-
Object
- Object
- GetStream::Generated::VideoClient
- Defined in:
- lib/getstream_ruby/generated/video_client.rb
Overview
Video API client with generated methods
Instance Method Summary collapse
-
#block_user(_type, _id, block_user_request) ⇒ Models::BlockUserResponse
Block a user, preventing them from joining the call until they are unblocked.Sends events:- call.blocked_user.
-
#collect_user_feedback(_type, _id, collect_user_feedback_request) ⇒ Models::CollectUserFeedbackResponse
Sends events:- call.user_feedback_submitted.
- #create_call_type(create_call_type_request) ⇒ Models::CreateCallTypeResponse
-
#create_sip_inbound_routing_rule(sip_inbound_routing_rule_request) ⇒ Models::SIPInboundRoutingRuleResponse
Create a new SIP Inbound Routing Rule with either direct routing or PIN routing configuration.
-
#create_sip_trunk(create_sip_trunk_request) ⇒ Models::CreateSIPTrunkResponse
Create a new SIP trunk for the application.
-
#delete_call(_type, _id, delete_call_request) ⇒ Models::DeleteCallResponse
Sends events:- call.deleted.
- #delete_call_type(name) ⇒ Models::Response
-
#delete_recording(_type, _id, session, filename) ⇒ Models::DeleteRecordingResponse
Deletes recording.
-
#delete_sip_inbound_routing_rule(_id) ⇒ Models::DeleteSIPInboundRoutingRuleResponse
Delete a SIP Inbound Routing Rule for the application.
-
#delete_sip_trunk(_id) ⇒ Models::DeleteSIPTrunkResponse
Delete a SIP trunk for the application.
-
#delete_transcription(_type, _id, session, filename) ⇒ Models::DeleteTranscriptionResponse
Deletes transcription.
-
#end_call(_type, _id) ⇒ Models::EndCallResponse
Sends events:- call.ended.
-
#get_active_calls_status ⇒ Models::GetActiveCallsStatusResponse
Get the current status of all active calls including metrics and summary information.
- #get_call(_type, _id, members_limit = nil, ring = nil, notify = nil, video = nil) ⇒ Models::GetCallResponse
- #get_call_participant_session_metrics(_type, _id, session, user, user_session, since = nil, _until = nil) ⇒ Models::GetCallParticipantSessionMetricsResponse
- #get_call_report(_type, _id, session_id = nil) ⇒ Models::GetCallReportResponse
- #get_call_session_participant_stats_details(call_type, call_id, session, user, user_session, since = nil, _until = nil, max_points = nil) ⇒ Models::GetCallSessionParticipantStatsDetailsResponse
- #get_call_session_participant_stats_timeline(call_type, call_id, session, user, user_session, start_time = nil, end_time = nil, severity = nil) ⇒ Models::QueryCallSessionParticipantStatsTimelineResponse
- #get_call_stats_map(call_type, call_id, session, start_time = nil, end_time = nil, exclude_publishers = nil, exclude_subscribers = nil, exclude_sfus = nil) ⇒ Models::QueryCallStatsMapResponse
- #get_call_type(name) ⇒ Models::GetCallTypeResponse
-
#get_edges ⇒ Models::GetEdgesResponse
Returns the list of all edges available for video calls.
-
#get_or_create_call(_type, _id, get_or_create_call_request) ⇒ Models::GetOrCreateCallResponse
Gets or creates a new callSends events:- call.created- call.notification- call.ring.
-
#go_live(_type, _id, go_live_request) ⇒ Models::GoLiveResponse
Sends events:- call.live_started.
-
#initialize(client) ⇒ VideoClient
constructor
A new instance of VideoClient.
-
#kick_user(_type, _id, kick_user_request) ⇒ Models::KickUserResponse
Kicks a user from the call.
- #list_call_types ⇒ Models::ListCallTypeResponse
-
#list_recordings(_type, _id) ⇒ Models::ListRecordingsResponse
Lists recordings.
-
#list_sip_inbound_routing_rule ⇒ Models::ListSIPInboundRoutingRuleResponse
List all SIP Inbound Routing Rules for the application.
-
#list_sip_trunks ⇒ Models::ListSIPTrunksResponse
List all SIP trunks for the application.
-
#list_transcriptions(_type, _id) ⇒ Models::ListTranscriptionsResponse
Lists transcriptions.
-
#mute_users(_type, _id, mute_users_request) ⇒ Models::MuteUsersResponse
Mutes users in a call.
- #query_aggregate_call_stats(query_aggregate_call_stats_request) ⇒ Models::QueryAggregateCallStatsResponse
-
#query_call_members(query_call_members_request) ⇒ Models::QueryCallMembersResponse
Query call members with filter query.
- #query_call_participant_sessions(_type, _id, session, limit = nil, prev = nil, _next = nil, filter_conditions = nil) ⇒ Models::QueryCallParticipantSessionsResponse
-
#query_call_participants(_id, _type, query_call_participants_request, limit = nil) ⇒ Models::QueryCallParticipantsResponse
Returns a list of participants connected to the call.
- #query_call_session_participant_stats(call_type, call_id, session, limit = nil, prev = nil, _next = nil, sort = nil, filter_conditions = nil) ⇒ Models::QueryCallSessionParticipantStatsResponse
- #query_call_stats(query_call_stats_request) ⇒ Models::QueryCallStatsResponse
-
#query_calls(query_calls_request) ⇒ Models::QueryCallsResponse
Query calls with filter query.
- #query_user_feedback(query_user_feedback_request, full = nil) ⇒ Models::QueryUserFeedbackResponse
-
#resolve_sip_inbound(resolve_sip_inbound_request) ⇒ Models::ResolveSipInboundResponse
Resolve SIP inbound routing based on trunk number, caller number, and challenge authentication.
-
#ring_call(_type, _id, ring_call_request) ⇒ Models::RingCallResponse
Sends a ring notification to the provided users who are not already in the call.
-
#send_call_event(_type, _id, send_call_event_request) ⇒ Models::SendCallEventResponse
Sends custom event to the callSends events:- custom.
-
#send_closed_caption(_type, _id, send_closed_caption_request) ⇒ Models::SendClosedCaptionResponse
Sends a closed caption event to the callSends events:- call.closed_caption.
-
#start_closed_captions(_type, _id, start_closed_captions_request) ⇒ Models::StartClosedCaptionsResponse
Starts closed captions.
-
#start_frame_recording(_type, _id, start_frame_recording_request) ⇒ Models::StartFrameRecordingResponse
Starts frame by frame recordingSends events:- call.frame_recording_started.
-
#start_hls_broadcasting(_type, _id) ⇒ Models::StartHLSBroadcastingResponse
Starts HLS broadcasting.
-
#start_recording(_type, _id, recording_type, start_recording_request) ⇒ Models::StartRecordingResponse
Starts recordingSends events:- call.recording_started.
-
#start_rtmp_broadcasts(_type, _id, start_rtmp_broadcasts_request) ⇒ Models::StartRTMPBroadcastsResponse
Starts RTMP broadcasts for the provided RTMP destinations.
-
#start_transcription(_type, _id, start_transcription_request) ⇒ Models::StartTranscriptionResponse
Starts transcription.
-
#stop_all_rtmp_broadcasts(_type, _id) ⇒ Models::StopAllRTMPBroadcastsResponse
Stop all RTMP broadcasts for the provided call.
-
#stop_closed_captions(_type, _id, stop_closed_captions_request) ⇒ Models::StopClosedCaptionsResponse
Stops closed captionsSends events:- call.transcription_stopped.
-
#stop_frame_recording(_type, _id) ⇒ Models::StopFrameRecordingResponse
Stops frame recordingSends events:- call.frame_recording_stopped.
-
#stop_hls_broadcasting(_type, _id) ⇒ Models::StopHLSBroadcastingResponse
Stops HLS broadcasting.
-
#stop_live(_type, _id, stop_live_request) ⇒ Models::StopLiveResponse
Sends events:- call.updated.
-
#stop_recording(_type, _id, recording_type, stop_recording_request) ⇒ Models::StopRecordingResponse
Stops recordingSends events:- call.recording_stopped.
-
#stop_rtmp_broadcast(_type, _id, name, stop_rtmp_broadcasts_request) ⇒ Models::StopRTMPBroadcastsResponse
Stop RTMP broadcasts for the provided RTMP destinations.
-
#stop_transcription(_type, _id, stop_transcription_request) ⇒ Models::StopTranscriptionResponse
Stops transcriptionSends events:- call.transcription_stopped.
-
#unblock_user(_type, _id, unblock_user_request) ⇒ Models::UnblockUserResponse
Removes the block for a user on a call.
-
#update_call(_type, _id, update_call_request) ⇒ Models::UpdateCallResponse
Sends events:- call.updated.
-
#update_call_members(_type, _id, update_call_members_request) ⇒ Models::UpdateCallMembersResponse
Sends events:- call.member_added- call.member_removed- call.member_updated.
- #update_call_type(name, update_call_type_request) ⇒ Models::UpdateCallTypeResponse
-
#update_sip_inbound_routing_rule(_id, update_sip_inbound_routing_rule_request) ⇒ Models::UpdateSIPInboundRoutingRuleResponse
Update an existing SIP Inbound Routing Rule with new configuration.
-
#update_sip_trunk(_id, update_sip_trunk_request) ⇒ Models::UpdateSIPTrunkResponse
Update a SIP trunk for the application.
-
#update_user_permissions(_type, _id, update_user_permissions_request) ⇒ Models::UpdateUserPermissionsResponse
Updates user permissionsSends events:- call.permissions_updated.
-
#video_pin(_type, _id, pin_request) ⇒ Models::PinResponse
Pins a track for all users in the call.
-
#video_unpin(_type, _id, unpin_request) ⇒ Models::UnpinResponse
Unpins a track for all users in the call.
Constructor Details
#initialize(client) ⇒ VideoClient
Returns a new instance of VideoClient.
12 13 14 |
# File 'lib/getstream_ruby/generated/video_client.rb', line 12 def initialize(client) @client = client end |
Instance Method Details
#block_user(_type, _id, block_user_request) ⇒ Models::BlockUserResponse
Block a user, preventing them from joining the call until they are unblocked.Sends events:- call.blocked_user
163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 |
# File 'lib/getstream_ruby/generated/video_client.rb', line 163 def block_user(_type, _id, block_user_request) path = '/api/v2/video/call/{type}/{id}/block' # Replace path parameters path = path.gsub('{type}', _type.to_s) path = path.gsub('{id}', _id.to_s) # Build request body body = block_user_request # Make the API request @client.make_request( :post, path, body: body ) end |
#collect_user_feedback(_type, _id, collect_user_feedback_request) ⇒ Models::CollectUserFeedbackResponse
Sends events:- call.user_feedback_submitted
251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 |
# File 'lib/getstream_ruby/generated/video_client.rb', line 251 def collect_user_feedback(_type, _id, collect_user_feedback_request) path = '/api/v2/video/call/{type}/{id}/feedback' # Replace path parameters path = path.gsub('{type}', _type.to_s) path = path.gsub('{id}', _id.to_s) # Build request body body = collect_user_feedback_request # Make the API request @client.make_request( :post, path, body: body ) end |
#create_call_type(create_call_type_request) ⇒ Models::CreateCallTypeResponse
1139 1140 1141 1142 1143 1144 1145 1146 1147 1148 1149 1150 |
# File 'lib/getstream_ruby/generated/video_client.rb', line 1139 def create_call_type(create_call_type_request) path = '/api/v2/video/calltypes' # Build request body body = create_call_type_request # Make the API request @client.make_request( :post, path, body: body ) end |
#create_sip_inbound_routing_rule(sip_inbound_routing_rule_request) ⇒ Models::SIPInboundRoutingRuleResponse
Create a new SIP Inbound Routing Rule with either direct routing or PIN routing configuration
1234 1235 1236 1237 1238 1239 1240 1241 1242 1243 1244 1245 |
# File 'lib/getstream_ruby/generated/video_client.rb', line 1234 def create_sip_inbound_routing_rule(sip_inbound_routing_rule_request) path = '/api/v2/video/sip/inbound_routing_rules' # Build request body body = sip_inbound_routing_rule_request # Make the API request @client.make_request( :post, path, body: body ) end |
#create_sip_trunk(create_sip_trunk_request) ⇒ Models::CreateSIPTrunkResponse
Create a new SIP trunk for the application
1300 1301 1302 1303 1304 1305 1306 1307 1308 1309 1310 1311 |
# File 'lib/getstream_ruby/generated/video_client.rb', line 1300 def create_sip_trunk(create_sip_trunk_request) path = '/api/v2/video/sip/inbound_trunks' # Build request body body = create_sip_trunk_request # Make the API request @client.make_request( :post, path, body: body ) end |
#delete_call(_type, _id, delete_call_request) ⇒ Models::DeleteCallResponse
Sends events:- call.deleted
207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 |
# File 'lib/getstream_ruby/generated/video_client.rb', line 207 def delete_call(_type, _id, delete_call_request) path = '/api/v2/video/call/{type}/{id}/delete' # Replace path parameters path = path.gsub('{type}', _type.to_s) path = path.gsub('{id}', _id.to_s) # Build request body body = delete_call_request # Make the API request @client.make_request( :post, path, body: body ) end |
#delete_call_type(name) ⇒ Models::Response
1156 1157 1158 1159 1160 1161 1162 1163 1164 1165 1166 |
# File 'lib/getstream_ruby/generated/video_client.rb', line 1156 def delete_call_type(name) path = '/api/v2/video/calltypes/{name}' # Replace path parameters path = path.gsub('{name}', name.to_s) # Make the API request @client.make_request( :delete, path ) end |
#delete_recording(_type, _id, session, filename) ⇒ Models::DeleteRecordingResponse
Deletes recording
936 937 938 939 940 941 942 943 944 945 946 947 948 949 |
# File 'lib/getstream_ruby/generated/video_client.rb', line 936 def delete_recording(_type, _id, session, filename) path = '/api/v2/video/call/{type}/{id}/{session}/recordings/{filename}' # Replace path parameters path = path.gsub('{type}', _type.to_s) path = path.gsub('{id}', _id.to_s) path = path.gsub('{session}', session.to_s) path = path.gsub('{filename}', filename.to_s) # Make the API request @client.make_request( :delete, path ) end |
#delete_sip_inbound_routing_rule(_id) ⇒ Models::DeleteSIPInboundRoutingRuleResponse
Delete a SIP Inbound Routing Rule for the application
1251 1252 1253 1254 1255 1256 1257 1258 1259 1260 1261 |
# File 'lib/getstream_ruby/generated/video_client.rb', line 1251 def delete_sip_inbound_routing_rule(_id) path = '/api/v2/video/sip/inbound_routing_rules/{id}' # Replace path parameters path = path.gsub('{id}', _id.to_s) # Make the API request @client.make_request( :delete, path ) end |
#delete_sip_trunk(_id) ⇒ Models::DeleteSIPTrunkResponse
Delete a SIP trunk for the application
1317 1318 1319 1320 1321 1322 1323 1324 1325 1326 1327 |
# File 'lib/getstream_ruby/generated/video_client.rb', line 1317 def delete_sip_trunk(_id) path = '/api/v2/video/sip/inbound_trunks/{id}' # Replace path parameters path = path.gsub('{id}', _id.to_s) # Make the API request @client.make_request( :delete, path ) end |
#delete_transcription(_type, _id, session, filename) ⇒ Models::DeleteTranscriptionResponse
Deletes transcription
958 959 960 961 962 963 964 965 966 967 968 969 970 971 |
# File 'lib/getstream_ruby/generated/video_client.rb', line 958 def delete_transcription(_type, _id, session, filename) path = '/api/v2/video/call/{type}/{id}/{session}/transcriptions/{filename}' # Replace path parameters path = path.gsub('{type}', _type.to_s) path = path.gsub('{id}', _id.to_s) path = path.gsub('{session}', session.to_s) path = path.gsub('{filename}', filename.to_s) # Make the API request @client.make_request( :delete, path ) end |
#end_call(_type, _id) ⇒ Models::EndCallResponse
Sends events:- call.ended
316 317 318 319 320 321 322 323 324 325 326 327 |
# File 'lib/getstream_ruby/generated/video_client.rb', line 316 def end_call(_type, _id) path = '/api/v2/video/call/{type}/{id}/mark_ended' # Replace path parameters path = path.gsub('{type}', _type.to_s) path = path.gsub('{id}', _id.to_s) # Make the API request @client.make_request( :post, path ) end |
#get_active_calls_status ⇒ Models::GetActiveCallsStatusResponse
Get the current status of all active calls including metrics and summary information
18 19 20 21 22 23 24 25 26 |
# File 'lib/getstream_ruby/generated/video_client.rb', line 18 def get_active_calls_status() path = '/api/v2/video/active_calls_status' # Make the API request @client.make_request( :get, path ) end |
#get_call(_type, _id, members_limit = nil, ring = nil, notify = nil, video = nil) ⇒ Models::GetCallResponse
93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 |
# File 'lib/getstream_ruby/generated/video_client.rb', line 93 def get_call(_type, _id, members_limit = nil, ring = nil, notify = nil, video = nil) path = '/api/v2/video/call/{type}/{id}' # Replace path parameters path = path.gsub('{type}', _type.to_s) path = path.gsub('{id}', _id.to_s) # Build query parameters query_params = {} query_params['members_limit'] = members_limit unless members_limit.nil? query_params['ring'] = ring unless ring.nil? query_params['notify'] = notify unless notify.nil? query_params['video'] = video unless video.nil? # Make the API request @client.make_request( :get, path, query_params: query_params ) end |
#get_call_participant_session_metrics(_type, _id, session, user, user_session, since = nil, _until = nil) ⇒ Models::GetCallParticipantSessionMetricsResponse
607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 |
# File 'lib/getstream_ruby/generated/video_client.rb', line 607 def get_call_participant_session_metrics(_type, _id, session, user, user_session, since = nil, _until = nil) path = '/api/v2/video/call/{type}/{id}/session/{session}/participant/{user}/{user_session}/details/track' # Replace path parameters path = path.gsub('{type}', _type.to_s) path = path.gsub('{id}', _id.to_s) path = path.gsub('{session}', session.to_s) path = path.gsub('{user}', user.to_s) path = path.gsub('{user_session}', user_session.to_s) # Build query parameters query_params = {} query_params['since'] = since unless since.nil? query_params['until'] = _until unless _until.nil? # Make the API request @client.make_request( :get, path, query_params: query_params ) end |
#get_call_report(_type, _id, session_id = nil) ⇒ Models::GetCallReportResponse
494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 |
# File 'lib/getstream_ruby/generated/video_client.rb', line 494 def get_call_report(_type, _id, session_id = nil) path = '/api/v2/video/call/{type}/{id}/report' # Replace path parameters path = path.gsub('{type}', _type.to_s) path = path.gsub('{id}', _id.to_s) # Build query parameters query_params = {} query_params['session_id'] = session_id unless session_id.nil? # Make the API request @client.make_request( :get, path, query_params: query_params ) end |
#get_call_session_participant_stats_details(call_type, call_id, session, user, user_session, since = nil, _until = nil, max_points = nil) ⇒ Models::GetCallSessionParticipantStatsDetailsResponse
1017 1018 1019 1020 1021 1022 1023 1024 1025 1026 1027 1028 1029 1030 1031 1032 1033 1034 1035 1036 1037 |
# File 'lib/getstream_ruby/generated/video_client.rb', line 1017 def get_call_session_participant_stats_details(call_type, call_id, session, user, user_session, since = nil, _until = nil, max_points = nil) path = '/api/v2/video/call_stats/{call_type}/{call_id}/{session}/participant/{user}/{user_session}/details' # Replace path parameters path = path.gsub('{call_type}', call_type.to_s) path = path.gsub('{call_id}', call_id.to_s) path = path.gsub('{session}', session.to_s) path = path.gsub('{user}', user.to_s) path = path.gsub('{user_session}', user_session.to_s) # Build query parameters query_params = {} query_params['since'] = since unless since.nil? query_params['until'] = _until unless _until.nil? query_params['max_points'] = max_points unless max_points.nil? # Make the API request @client.make_request( :get, path, query_params: query_params ) end |
#get_call_session_participant_stats_timeline(call_type, call_id, session, user, user_session, start_time = nil, end_time = nil, severity = nil) ⇒ Models::QueryCallSessionParticipantStatsTimelineResponse
1083 1084 1085 1086 1087 1088 1089 1090 1091 1092 1093 1094 1095 1096 1097 1098 1099 1100 1101 1102 1103 |
# File 'lib/getstream_ruby/generated/video_client.rb', line 1083 def get_call_session_participant_stats_timeline(call_type, call_id, session, user, user_session, start_time = nil, end_time = nil, severity = nil) path = '/api/v2/video/call_stats/{call_type}/{call_id}/{session}/participants/{user}/{user_session}/timeline' # Replace path parameters path = path.gsub('{call_type}', call_type.to_s) path = path.gsub('{call_id}', call_id.to_s) path = path.gsub('{session}', session.to_s) path = path.gsub('{user}', user.to_s) path = path.gsub('{user_session}', user_session.to_s) # Build query parameters query_params = {} query_params['start_time'] = start_time unless start_time.nil? query_params['end_time'] = end_time unless end_time.nil? query_params['severity'] = severity unless severity.nil? # Make the API request @client.make_request( :get, path, query_params: query_params ) end |
#get_call_stats_map(call_type, call_id, session, start_time = nil, end_time = nil, exclude_publishers = nil, exclude_subscribers = nil, exclude_sfus = nil) ⇒ Models::QueryCallStatsMapResponse
984 985 986 987 988 989 990 991 992 993 994 995 996 997 998 999 1000 1001 1002 1003 1004 |
# File 'lib/getstream_ruby/generated/video_client.rb', line 984 def get_call_stats_map(call_type, call_id, session, start_time = nil, end_time = nil, exclude_publishers = nil, exclude_subscribers = nil, exclude_sfus = nil) path = '/api/v2/video/call_stats/{call_type}/{call_id}/{session}/map' # Replace path parameters path = path.gsub('{call_type}', call_type.to_s) path = path.gsub('{call_id}', call_id.to_s) path = path.gsub('{session}', session.to_s) # Build query parameters query_params = {} query_params['start_time'] = start_time unless start_time.nil? query_params['end_time'] = end_time unless end_time.nil? query_params['exclude_publishers'] = exclude_publishers unless exclude_publishers.nil? query_params['exclude_subscribers'] = exclude_subscribers unless exclude_subscribers.nil? query_params['exclude_sfus'] = exclude_sfus unless exclude_sfus.nil? # Make the API request @client.make_request( :get, path, query_params: query_params ) end |
#get_call_type(name) ⇒ Models::GetCallTypeResponse
1172 1173 1174 1175 1176 1177 1178 1179 1180 1181 1182 |
# File 'lib/getstream_ruby/generated/video_client.rb', line 1172 def get_call_type(name) path = '/api/v2/video/calltypes/{name}' # Replace path parameters path = path.gsub('{name}', name.to_s) # Make the API request @client.make_request( :get, path ) end |
#get_edges ⇒ Models::GetEdgesResponse
Returns the list of all edges available for video calls.
1207 1208 1209 1210 1211 1212 1213 1214 1215 |
# File 'lib/getstream_ruby/generated/video_client.rb', line 1207 def get_edges() path = '/api/v2/video/edges' # Make the API request @client.make_request( :get, path ) end |
#get_or_create_call(_type, _id, get_or_create_call_request) ⇒ Models::GetOrCreateCallResponse
Gets or creates a new callSends events:- call.created- call.notification- call.ring
141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 |
# File 'lib/getstream_ruby/generated/video_client.rb', line 141 def get_or_create_call(_type, _id, get_or_create_call_request) path = '/api/v2/video/call/{type}/{id}' # Replace path parameters path = path.gsub('{type}', _type.to_s) path = path.gsub('{id}', _id.to_s) # Build request body body = get_or_create_call_request # Make the API request @client.make_request( :post, path, body: body ) end |
#go_live(_type, _id, go_live_request) ⇒ Models::GoLiveResponse
Sends events:- call.live_started
273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 |
# File 'lib/getstream_ruby/generated/video_client.rb', line 273 def go_live(_type, _id, go_live_request) path = '/api/v2/video/call/{type}/{id}/go_live' # Replace path parameters path = path.gsub('{type}', _type.to_s) path = path.gsub('{id}', _id.to_s) # Build request body body = go_live_request # Make the API request @client.make_request( :post, path, body: body ) end |
#kick_user(_type, _id, kick_user_request) ⇒ Models::KickUserResponse
Kicks a user from the call. Optionally block the user from rejoining by setting block=true.Sends events:- call.blocked_user- call.kicked_user
295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 |
# File 'lib/getstream_ruby/generated/video_client.rb', line 295 def kick_user(_type, _id, kick_user_request) path = '/api/v2/video/call/{type}/{id}/kick' # Replace path parameters path = path.gsub('{type}', _type.to_s) path = path.gsub('{id}', _id.to_s) # Build request body body = kick_user_request # Make the API request @client.make_request( :post, path, body: body ) end |
#list_call_types ⇒ Models::ListCallTypeResponse
1125 1126 1127 1128 1129 1130 1131 1132 1133 |
# File 'lib/getstream_ruby/generated/video_client.rb', line 1125 def list_call_types() path = '/api/v2/video/calltypes' # Make the API request @client.make_request( :get, path ) end |
#list_recordings(_type, _id) ⇒ Models::ListRecordingsResponse
Lists recordings
427 428 429 430 431 432 433 434 435 436 437 438 |
# File 'lib/getstream_ruby/generated/video_client.rb', line 427 def list_recordings(_type, _id) path = '/api/v2/video/call/{type}/{id}/recordings' # Replace path parameters path = path.gsub('{type}', _type.to_s) path = path.gsub('{id}', _id.to_s) # Make the API request @client.make_request( :get, path ) end |
#list_sip_inbound_routing_rule ⇒ Models::ListSIPInboundRoutingRuleResponse
List all SIP Inbound Routing Rules for the application
1220 1221 1222 1223 1224 1225 1226 1227 1228 |
# File 'lib/getstream_ruby/generated/video_client.rb', line 1220 def list_sip_inbound_routing_rule() path = '/api/v2/video/sip/inbound_routing_rules' # Make the API request @client.make_request( :get, path ) end |
#list_sip_trunks ⇒ Models::ListSIPTrunksResponse
List all SIP trunks for the application
1286 1287 1288 1289 1290 1291 1292 1293 1294 |
# File 'lib/getstream_ruby/generated/video_client.rb', line 1286 def list_sip_trunks() path = '/api/v2/video/sip/inbound_trunks' # Make the API request @client.make_request( :get, path ) end |
#list_transcriptions(_type, _id) ⇒ Models::ListTranscriptionsResponse
Lists transcriptions
850 851 852 853 854 855 856 857 858 859 860 861 |
# File 'lib/getstream_ruby/generated/video_client.rb', line 850 def list_transcriptions(_type, _id) path = '/api/v2/video/call/{type}/{id}/transcriptions' # Replace path parameters path = path.gsub('{type}', _type.to_s) path = path.gsub('{id}', _id.to_s) # Make the API request @client.make_request( :get, path ) end |
#mute_users(_type, _id, mute_users_request) ⇒ Models::MuteUsersResponse
Mutes users in a call
357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 |
# File 'lib/getstream_ruby/generated/video_client.rb', line 357 def mute_users(_type, _id, mute_users_request) path = '/api/v2/video/call/{type}/{id}/mute_users' # Replace path parameters path = path.gsub('{type}', _type.to_s) path = path.gsub('{id}', _id.to_s) # Build request body body = mute_users_request # Make the API request @client.make_request( :post, path, body: body ) end |
#query_aggregate_call_stats(query_aggregate_call_stats_request) ⇒ Models::QueryAggregateCallStatsResponse
1370 1371 1372 1373 1374 1375 1376 1377 1378 1379 1380 1381 |
# File 'lib/getstream_ruby/generated/video_client.rb', line 1370 def query_aggregate_call_stats(query_aggregate_call_stats_request) path = '/api/v2/video/stats' # Build request body body = query_aggregate_call_stats_request # Make the API request @client.make_request( :post, path, body: body ) end |
#query_call_members(query_call_members_request) ⇒ Models::QueryCallMembersResponse
Query call members with filter query
54 55 56 57 58 59 60 61 62 63 64 65 |
# File 'lib/getstream_ruby/generated/video_client.rb', line 54 def query_call_members(query_call_members_request) path = '/api/v2/video/call/members' # Build request body body = query_call_members_request # Make the API request @client.make_request( :post, path, body: body ) end |
#query_call_participant_sessions(_type, _id, session, limit = nil, prev = nil, _next = nil, filter_conditions = nil) ⇒ Models::QueryCallParticipantSessionsResponse
638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 |
# File 'lib/getstream_ruby/generated/video_client.rb', line 638 def query_call_participant_sessions(_type, _id, session, limit = nil, prev = nil, _next = nil, filter_conditions = nil) path = '/api/v2/video/call/{type}/{id}/session/{session}/participant_sessions' # Replace path parameters path = path.gsub('{type}', _type.to_s) path = path.gsub('{id}', _id.to_s) path = path.gsub('{session}', session.to_s) # Build query parameters query_params = {} query_params['limit'] = limit unless limit.nil? query_params['prev'] = prev unless prev.nil? query_params['next'] = _next unless _next.nil? query_params['filter_conditions'] = filter_conditions unless filter_conditions.nil? # Make the API request @client.make_request( :get, path, query_params: query_params ) end |
#query_call_participants(_id, _type, query_call_participants_request, limit = nil) ⇒ Models::QueryCallParticipantsResponse
Returns a list of participants connected to the call
380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 |
# File 'lib/getstream_ruby/generated/video_client.rb', line 380 def query_call_participants(_id, _type, query_call_participants_request, limit = nil) path = '/api/v2/video/call/{type}/{id}/participants' # Replace path parameters path = path.gsub('{id}', _id.to_s) path = path.gsub('{type}', _type.to_s) # Build query parameters query_params = {} query_params['limit'] = limit unless limit.nil? # Build request body body = query_call_participants_request # Make the API request @client.make_request( :post, path, query_params: query_params, body: body ) end |
#query_call_session_participant_stats(call_type, call_id, session, limit = nil, prev = nil, _next = nil, sort = nil, filter_conditions = nil) ⇒ Models::QueryCallSessionParticipantStatsResponse
1050 1051 1052 1053 1054 1055 1056 1057 1058 1059 1060 1061 1062 1063 1064 1065 1066 1067 1068 1069 1070 |
# File 'lib/getstream_ruby/generated/video_client.rb', line 1050 def query_call_session_participant_stats(call_type, call_id, session, limit = nil, prev = nil, _next = nil, sort = nil, filter_conditions = nil) path = '/api/v2/video/call_stats/{call_type}/{call_id}/{session}/participants' # Replace path parameters path = path.gsub('{call_type}', call_type.to_s) path = path.gsub('{call_id}', call_id.to_s) path = path.gsub('{session}', session.to_s) # Build query parameters query_params = {} query_params['limit'] = limit unless limit.nil? query_params['prev'] = prev unless prev.nil? query_params['next'] = _next unless _next.nil? query_params['sort'] = sort unless sort.nil? query_params['filter_conditions'] = filter_conditions unless filter_conditions.nil? # Make the API request @client.make_request( :get, path, query_params: query_params ) end |
#query_call_stats(query_call_stats_request) ⇒ Models::QueryCallStatsResponse
71 72 73 74 75 76 77 78 79 80 81 82 |
# File 'lib/getstream_ruby/generated/video_client.rb', line 71 def query_call_stats(query_call_stats_request) path = '/api/v2/video/call/stats' # Build request body body = query_call_stats_request # Make the API request @client.make_request( :post, path, body: body ) end |
#query_calls(query_calls_request) ⇒ Models::QueryCallsResponse
Query calls with filter query
1109 1110 1111 1112 1113 1114 1115 1116 1117 1118 1119 1120 |
# File 'lib/getstream_ruby/generated/video_client.rb', line 1109 def query_calls(query_calls_request) path = '/api/v2/video/calls' # Build request body body = query_calls_request # Make the API request @client.make_request( :post, path, body: body ) end |
#query_user_feedback(query_user_feedback_request, full = nil) ⇒ Models::QueryUserFeedbackResponse
33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 |
# File 'lib/getstream_ruby/generated/video_client.rb', line 33 def query_user_feedback(query_user_feedback_request, full = nil) path = '/api/v2/video/call/feedback' # Build query parameters query_params = {} query_params['full'] = full unless full.nil? # Build request body body = query_user_feedback_request # Make the API request @client.make_request( :post, path, query_params: query_params, body: body ) end |
#resolve_sip_inbound(resolve_sip_inbound_request) ⇒ Models::ResolveSipInboundResponse
Resolve SIP inbound routing based on trunk number, caller number, and challenge authentication
1353 1354 1355 1356 1357 1358 1359 1360 1361 1362 1363 1364 |
# File 'lib/getstream_ruby/generated/video_client.rb', line 1353 def resolve_sip_inbound(resolve_sip_inbound_request) path = '/api/v2/video/sip/resolve' # Build request body body = resolve_sip_inbound_request # Make the API request @client.make_request( :post, path, body: body ) end |
#ring_call(_type, _id, ring_call_request) ⇒ Models::RingCallResponse
Sends a ring notification to the provided users who are not already in the call. All users should be members of the callSends events:- call.ring
517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 |
# File 'lib/getstream_ruby/generated/video_client.rb', line 517 def ring_call(_type, _id, ring_call_request) path = '/api/v2/video/call/{type}/{id}/ring' # Replace path parameters path = path.gsub('{type}', _type.to_s) path = path.gsub('{id}', _id.to_s) # Build request body body = ring_call_request # Make the API request @client.make_request( :post, path, body: body ) end |
#send_call_event(_type, _id, send_call_event_request) ⇒ Models::SendCallEventResponse
Sends custom event to the callSends events:- custom
229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 |
# File 'lib/getstream_ruby/generated/video_client.rb', line 229 def send_call_event(_type, _id, send_call_event_request) path = '/api/v2/video/call/{type}/{id}/event' # Replace path parameters path = path.gsub('{type}', _type.to_s) path = path.gsub('{id}', _id.to_s) # Build request body body = send_call_event_request # Make the API request @client.make_request( :post, path, body: body ) end |
#send_closed_caption(_type, _id, send_closed_caption_request) ⇒ Models::SendClosedCaptionResponse
Sends a closed caption event to the callSends events:- call.closed_caption
185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 |
# File 'lib/getstream_ruby/generated/video_client.rb', line 185 def send_closed_caption(_type, _id, send_closed_caption_request) path = '/api/v2/video/call/{type}/{id}/closed_captions' # Replace path parameters path = path.gsub('{type}', _type.to_s) path = path.gsub('{id}', _id.to_s) # Build request body body = send_closed_caption_request # Make the API request @client.make_request( :post, path, body: body ) end |
#start_closed_captions(_type, _id, start_closed_captions_request) ⇒ Models::StartClosedCaptionsResponse
Starts closed captions
683 684 685 686 687 688 689 690 691 692 693 694 695 696 697 |
# File 'lib/getstream_ruby/generated/video_client.rb', line 683 def start_closed_captions(_type, _id, start_closed_captions_request) path = '/api/v2/video/call/{type}/{id}/start_closed_captions' # Replace path parameters path = path.gsub('{type}', _type.to_s) path = path.gsub('{id}', _id.to_s) # Build request body body = start_closed_captions_request # Make the API request @client.make_request( :post, path, body: body ) end |
#start_frame_recording(_type, _id, start_frame_recording_request) ⇒ Models::StartFrameRecordingResponse
Starts frame by frame recordingSends events:- call.frame_recording_started
705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 |
# File 'lib/getstream_ruby/generated/video_client.rb', line 705 def start_frame_recording(_type, _id, start_frame_recording_request) path = '/api/v2/video/call/{type}/{id}/start_frame_recording' # Replace path parameters path = path.gsub('{type}', _type.to_s) path = path.gsub('{id}', _id.to_s) # Build request body body = start_frame_recording_request # Make the API request @client.make_request( :post, path, body: body ) end |
#start_hls_broadcasting(_type, _id) ⇒ Models::StartHLSBroadcastingResponse
Starts HLS broadcasting
664 665 666 667 668 669 670 671 672 673 674 675 |
# File 'lib/getstream_ruby/generated/video_client.rb', line 664 def start_hls_broadcasting(_type, _id) path = '/api/v2/video/call/{type}/{id}/start_broadcasting' # Replace path parameters path = path.gsub('{type}', _type.to_s) path = path.gsub('{id}', _id.to_s) # Make the API request @client.make_request( :post, path ) end |
#start_recording(_type, _id, recording_type, start_recording_request) ⇒ Models::StartRecordingResponse
Starts recordingSends events:- call.recording_started
447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 |
# File 'lib/getstream_ruby/generated/video_client.rb', line 447 def start_recording(_type, _id, recording_type, start_recording_request) path = '/api/v2/video/call/{type}/{id}/recordings/{recording_type}/start' # Replace path parameters path = path.gsub('{type}', _type.to_s) path = path.gsub('{id}', _id.to_s) path = path.gsub('{recording_type}', recording_type.to_s) # Build request body body = start_recording_request # Make the API request @client.make_request( :post, path, body: body ) end |
#start_rtmp_broadcasts(_type, _id, start_rtmp_broadcasts_request) ⇒ Models::StartRTMPBroadcastsResponse
Starts RTMP broadcasts for the provided RTMP destinations
539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 |
# File 'lib/getstream_ruby/generated/video_client.rb', line 539 def start_rtmp_broadcasts(_type, _id, start_rtmp_broadcasts_request) path = '/api/v2/video/call/{type}/{id}/rtmp_broadcasts' # Replace path parameters path = path.gsub('{type}', _type.to_s) path = path.gsub('{id}', _id.to_s) # Build request body body = start_rtmp_broadcasts_request # Make the API request @client.make_request( :post, path, body: body ) end |
#start_transcription(_type, _id, start_transcription_request) ⇒ Models::StartTranscriptionResponse
Starts transcription
727 728 729 730 731 732 733 734 735 736 737 738 739 740 741 |
# File 'lib/getstream_ruby/generated/video_client.rb', line 727 def start_transcription(_type, _id, start_transcription_request) path = '/api/v2/video/call/{type}/{id}/start_transcription' # Replace path parameters path = path.gsub('{type}', _type.to_s) path = path.gsub('{id}', _id.to_s) # Build request body body = start_transcription_request # Make the API request @client.make_request( :post, path, body: body ) end |
#stop_all_rtmp_broadcasts(_type, _id) ⇒ Models::StopAllRTMPBroadcastsResponse
Stop all RTMP broadcasts for the provided call
560 561 562 563 564 565 566 567 568 569 570 571 |
# File 'lib/getstream_ruby/generated/video_client.rb', line 560 def stop_all_rtmp_broadcasts(_type, _id) path = '/api/v2/video/call/{type}/{id}/rtmp_broadcasts/stop' # Replace path parameters path = path.gsub('{type}', _type.to_s) path = path.gsub('{id}', _id.to_s) # Make the API request @client.make_request( :post, path ) end |
#stop_closed_captions(_type, _id, stop_closed_captions_request) ⇒ Models::StopClosedCaptionsResponse
Stops closed captionsSends events:- call.transcription_stopped
767 768 769 770 771 772 773 774 775 776 777 778 779 780 781 |
# File 'lib/getstream_ruby/generated/video_client.rb', line 767 def stop_closed_captions(_type, _id, stop_closed_captions_request) path = '/api/v2/video/call/{type}/{id}/stop_closed_captions' # Replace path parameters path = path.gsub('{type}', _type.to_s) path = path.gsub('{id}', _id.to_s) # Build request body body = stop_closed_captions_request # Make the API request @client.make_request( :post, path, body: body ) end |
#stop_frame_recording(_type, _id) ⇒ Models::StopFrameRecordingResponse
Stops frame recordingSends events:- call.frame_recording_stopped
788 789 790 791 792 793 794 795 796 797 798 799 |
# File 'lib/getstream_ruby/generated/video_client.rb', line 788 def stop_frame_recording(_type, _id) path = '/api/v2/video/call/{type}/{id}/stop_frame_recording' # Replace path parameters path = path.gsub('{type}', _type.to_s) path = path.gsub('{id}', _id.to_s) # Make the API request @client.make_request( :post, path ) end |
#stop_hls_broadcasting(_type, _id) ⇒ Models::StopHLSBroadcastingResponse
Stops HLS broadcasting
748 749 750 751 752 753 754 755 756 757 758 759 |
# File 'lib/getstream_ruby/generated/video_client.rb', line 748 def stop_hls_broadcasting(_type, _id) path = '/api/v2/video/call/{type}/{id}/stop_broadcasting' # Replace path parameters path = path.gsub('{type}', _type.to_s) path = path.gsub('{id}', _id.to_s) # Make the API request @client.make_request( :post, path ) end |
#stop_live(_type, _id, stop_live_request) ⇒ Models::StopLiveResponse
Sends events:- call.updated
807 808 809 810 811 812 813 814 815 816 817 818 819 820 821 |
# File 'lib/getstream_ruby/generated/video_client.rb', line 807 def stop_live(_type, _id, stop_live_request) path = '/api/v2/video/call/{type}/{id}/stop_live' # Replace path parameters path = path.gsub('{type}', _type.to_s) path = path.gsub('{id}', _id.to_s) # Build request body body = stop_live_request # Make the API request @client.make_request( :post, path, body: body ) end |
#stop_recording(_type, _id, recording_type, stop_recording_request) ⇒ Models::StopRecordingResponse
Stops recordingSends events:- call.recording_stopped
471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 |
# File 'lib/getstream_ruby/generated/video_client.rb', line 471 def stop_recording(_type, _id, recording_type, stop_recording_request) path = '/api/v2/video/call/{type}/{id}/recordings/{recording_type}/stop' # Replace path parameters path = path.gsub('{type}', _type.to_s) path = path.gsub('{id}', _id.to_s) path = path.gsub('{recording_type}', recording_type.to_s) # Build request body body = stop_recording_request # Make the API request @client.make_request( :post, path, body: body ) end |
#stop_rtmp_broadcast(_type, _id, name, stop_rtmp_broadcasts_request) ⇒ Models::StopRTMPBroadcastsResponse
Stop RTMP broadcasts for the provided RTMP destinations
580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 |
# File 'lib/getstream_ruby/generated/video_client.rb', line 580 def stop_rtmp_broadcast(_type, _id, name, stop_rtmp_broadcasts_request) path = '/api/v2/video/call/{type}/{id}/rtmp_broadcasts/{name}/stop' # Replace path parameters path = path.gsub('{type}', _type.to_s) path = path.gsub('{id}', _id.to_s) path = path.gsub('{name}', name.to_s) # Build request body body = stop_rtmp_broadcasts_request # Make the API request @client.make_request( :post, path, body: body ) end |
#stop_transcription(_type, _id, stop_transcription_request) ⇒ Models::StopTranscriptionResponse
Stops transcriptionSends events:- call.transcription_stopped
829 830 831 832 833 834 835 836 837 838 839 840 841 842 843 |
# File 'lib/getstream_ruby/generated/video_client.rb', line 829 def stop_transcription(_type, _id, stop_transcription_request) path = '/api/v2/video/call/{type}/{id}/stop_transcription' # Replace path parameters path = path.gsub('{type}', _type.to_s) path = path.gsub('{id}', _id.to_s) # Build request body body = stop_transcription_request # Make the API request @client.make_request( :post, path, body: body ) end |
#unblock_user(_type, _id, unblock_user_request) ⇒ Models::UnblockUserResponse
Removes the block for a user on a call. The user will be able to join the call again.Sends events:- call.unblocked_user
869 870 871 872 873 874 875 876 877 878 879 880 881 882 883 |
# File 'lib/getstream_ruby/generated/video_client.rb', line 869 def unblock_user(_type, _id, unblock_user_request) path = '/api/v2/video/call/{type}/{id}/unblock' # Replace path parameters path = path.gsub('{type}', _type.to_s) path = path.gsub('{id}', _id.to_s) # Build request body body = unblock_user_request # Make the API request @client.make_request( :post, path, body: body ) end |
#update_call(_type, _id, update_call_request) ⇒ Models::UpdateCallResponse
Sends events:- call.updated
119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 |
# File 'lib/getstream_ruby/generated/video_client.rb', line 119 def update_call(_type, _id, update_call_request) path = '/api/v2/video/call/{type}/{id}' # Replace path parameters path = path.gsub('{type}', _type.to_s) path = path.gsub('{id}', _id.to_s) # Build request body body = update_call_request # Make the API request @client.make_request( :patch, path, body: body ) end |
#update_call_members(_type, _id, update_call_members_request) ⇒ Models::UpdateCallMembersResponse
Sends events:- call.member_added- call.member_removed- call.member_updated
335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 |
# File 'lib/getstream_ruby/generated/video_client.rb', line 335 def update_call_members(_type, _id, update_call_members_request) path = '/api/v2/video/call/{type}/{id}/members' # Replace path parameters path = path.gsub('{type}', _type.to_s) path = path.gsub('{id}', _id.to_s) # Build request body body = update_call_members_request # Make the API request @client.make_request( :post, path, body: body ) end |
#update_call_type(name, update_call_type_request) ⇒ Models::UpdateCallTypeResponse
1189 1190 1191 1192 1193 1194 1195 1196 1197 1198 1199 1200 1201 1202 |
# File 'lib/getstream_ruby/generated/video_client.rb', line 1189 def update_call_type(name, update_call_type_request) path = '/api/v2/video/calltypes/{name}' # Replace path parameters path = path.gsub('{name}', name.to_s) # Build request body body = update_call_type_request # Make the API request @client.make_request( :put, path, body: body ) end |
#update_sip_inbound_routing_rule(_id, update_sip_inbound_routing_rule_request) ⇒ Models::UpdateSIPInboundRoutingRuleResponse
Update an existing SIP Inbound Routing Rule with new configuration
1268 1269 1270 1271 1272 1273 1274 1275 1276 1277 1278 1279 1280 1281 |
# File 'lib/getstream_ruby/generated/video_client.rb', line 1268 def update_sip_inbound_routing_rule(_id, update_sip_inbound_routing_rule_request) path = '/api/v2/video/sip/inbound_routing_rules/{id}' # Replace path parameters path = path.gsub('{id}', _id.to_s) # Build request body body = update_sip_inbound_routing_rule_request # Make the API request @client.make_request( :put, path, body: body ) end |
#update_sip_trunk(_id, update_sip_trunk_request) ⇒ Models::UpdateSIPTrunkResponse
Update a SIP trunk for the application
1334 1335 1336 1337 1338 1339 1340 1341 1342 1343 1344 1345 1346 1347 |
# File 'lib/getstream_ruby/generated/video_client.rb', line 1334 def update_sip_trunk(_id, update_sip_trunk_request) path = '/api/v2/video/sip/inbound_trunks/{id}' # Replace path parameters path = path.gsub('{id}', _id.to_s) # Build request body body = update_sip_trunk_request # Make the API request @client.make_request( :put, path, body: body ) end |
#update_user_permissions(_type, _id, update_user_permissions_request) ⇒ Models::UpdateUserPermissionsResponse
Updates user permissionsSends events:- call.permissions_updated
913 914 915 916 917 918 919 920 921 922 923 924 925 926 927 |
# File 'lib/getstream_ruby/generated/video_client.rb', line 913 def (_type, _id, ) path = '/api/v2/video/call/{type}/{id}/user_permissions' # Replace path parameters path = path.gsub('{type}', _type.to_s) path = path.gsub('{id}', _id.to_s) # Build request body body = # Make the API request @client.make_request( :post, path, body: body ) end |
#video_pin(_type, _id, pin_request) ⇒ Models::PinResponse
Pins a track for all users in the call.
406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 |
# File 'lib/getstream_ruby/generated/video_client.rb', line 406 def video_pin(_type, _id, pin_request) path = '/api/v2/video/call/{type}/{id}/pin' # Replace path parameters path = path.gsub('{type}', _type.to_s) path = path.gsub('{id}', _id.to_s) # Build request body body = pin_request # Make the API request @client.make_request( :post, path, body: body ) end |
#video_unpin(_type, _id, unpin_request) ⇒ Models::UnpinResponse
Unpins a track for all users in the call.
891 892 893 894 895 896 897 898 899 900 901 902 903 904 905 |
# File 'lib/getstream_ruby/generated/video_client.rb', line 891 def video_unpin(_type, _id, unpin_request) path = '/api/v2/video/call/{type}/{id}/unpin' # Replace path parameters path = path.gsub('{type}', _type.to_s) path = path.gsub('{id}', _id.to_s) # Build request body body = unpin_request # Make the API request @client.make_request( :post, path, body: body ) end |